@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # autogen.sh glue for Grisbi
-# $Id: autogen.sh,v 1.1.2.8 2004/09/30 13:32:12 benj2 Exp $
+# $Id: autogen.sh,v 1.1.2.10 2005/01/07 19:24:18 benj2 Exp $
 #
 # Requires: automake, autoconf, dpkg-dev
 
@@ -10,6 +10,11 @@ PATH_AUTOMAKE=/usr/share/automake
 # test for some distribution...
 # Y'a pas plus simple ?
 
+if test -x /usr/share/automake-1.8
+then
+	PATH_AUTOMAKE=/usr/share/automake-1.8
+fi
+
 if test -x /usr/share/automake-1.7
 then
 	PATH_AUTOMAKE=/usr/share/automake-1.7
@@ -26,7 +31,7 @@ then
 fi
 
 # Refresh GNU autotools toolchain.
-for i in config.guess config.sub missing install-sh mkinstalldirs ; do
+for i in config.guess config.sub missing install-sh mkinstalldirs depcomp ; do
 	test -r $PATH_AUTOMAKE/${i} && {
 		rm -f ${i}
 		cp $PATH_AUTOMAKE/${i} .
