@@ -1,8 +1,8 @@
-/* Ce fichier s'occupe des diffrents paramtres d'affichage rgls
-   dans les paramtres */
+/* Ce fichier s'occupe des différents paramètres d'affichage réglés
+   dans les paramètres */
 /* affichage.c */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
 
@@ -271,7 +271,7 @@ GtkWidget * onglet_display_fonts ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			 FALSE, FALSE, 0 );
 
-    /*     le logo est gris ou non suivant qu'on l'utilise ou pas */
+    /*     le logo est grisé ou non suivant qu'on l'utilise ou pas */
 
     gtk_widget_set_sensitive ( hbox,
 			       etat.utilise_logo );
@@ -330,7 +330,7 @@ GtkWidget * onglet_display_fonts ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			 FALSE, FALSE, 0 );
 
-    /*     le logo est gris ou non suivant qu'on l'utilise ou pas */
+    /*     le logo est grisé ou non suivant qu'on l'utilise ou pas */
 
     anim_button = gtk_button_new ();
     gtk_button_set_relief ( GTK_BUTTON ( anim_button ),
@@ -341,8 +341,8 @@ GtkWidget * onglet_display_fonts ( void )
 
     if (pixbuf_anim)
     {
-	/* 	si l'animation est trop grande, compliqu pour la rduire de taille */
-	/* 	    donc on affiche juste la premire image en pixbuf */
+	/* 	si l'animation est trop grande, compliqué pour la réduire de taille */
+	/* 	    donc on affiche juste la première image en pixbuf */
 
 	if ( gdk_pixbuf_animation_get_width (pixbuf_anim) > 64
 	     ||
@@ -400,7 +400,7 @@ GtkWidget * onglet_display_fonts ( void )
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( check_button ),
 				   etat.utilise_fonte_listes );
 
-    /*     on cre la vbox qui contiendra la font button et le raz */
+    /*     on crée la vbox qui contiendra la font button et le raz */
 
     vbox = gtk_vbox_new ( FALSE,
 			  10 );
@@ -547,7 +547,7 @@ gboolean change_choix_utilise_fonte_liste ( GtkWidget *check_button,
     gtk_widget_set_sensitive ( vbox,
 			       etat.utilise_fonte_listes );
 
-    /*     pour reprendre la fonte de base, on rcupre celle de la liste des tiers, qui n'est pas modifie */
+    /*     pour reprendre la fonte de base, on récupère celle de la liste des tiers, qui n'est pas modifiée */
 
     if ( etat.utilise_fonte_listes )
 	fonte_desc = pango_font_description_from_string(fonte_liste);
@@ -953,8 +953,8 @@ void change_animation ( GtkWidget *widget,
 
     if (pixbuf)
     {
-	/* 	si l'animation est trop grande, compliqu pour la rduire de taille */
-	/* 	    donc on affiche juste la premire image en pixbuf */
+	/* 	si l'animation est trop grande, compliqué pour la réduire de taille */
+	/* 	    donc on affiche juste la première image en pixbuf */
 
 	if ( gdk_pixbuf_animation_get_width (pixbuf) > 64
 	     ||
