@@ -3,7 +3,7 @@
 /*                                                                            */
 /*                                banque.c                                    */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
 /*			2004 Alain Portal (dionysos@grisbi.org)		      */
 /*			http://www.grisbi.org				      */
@@ -99,7 +99,7 @@ gboolean update_bank_menu ()
 
 /* ***************************************************************************************************** */
 /* Fonction ajout_banque */
-/* appele par le bouton ajouter de l'onglet banques des paramtres */
+/* appelée par le bouton ajouter de l'onglet banques des paramètres */
 /* ***************************************************************************************************** */
 
 struct struct_banque * ajout_banque ( GtkWidget *bouton, GtkWidget *clist )
@@ -110,12 +110,12 @@ struct struct_banque * ajout_banque ( GtkWidget *bouton, GtkWidget *clist )
 
     if ( clist && GTK_IS_CLIST(clist) )
     {
-	/* enlve la slection de la liste ( ce qui nettoie les entres ) */
+	/* enlève la sélection de la liste ( ce qui nettoie les entrées ) */
 	gtk_clist_unselect_all ( GTK_CLIST ( clist ));
     }
 
-    /* cre une nouvelle banque au nom de "nouvelle banque" en mettant
-       tous les paramtres  0 et le no  -1 */
+    /* crée une nouvelle banque au nom de "nouvelle banque" en mettant
+       tous les paramètres à 0 et le no à -1 */
     banque = calloc ( 1, sizeof ( struct struct_banque ));
     if (!banque)
     {
@@ -132,13 +132,13 @@ struct struct_banque * ajout_banque ( GtkWidget *bouton, GtkWidget *clist )
     {
 	ligne_insert = gtk_clist_append ( GTK_CLIST ( clist ), ligne );
 
-	/* on associe  la ligne la struct de la banque */
+	/* on associe à la ligne la struct de la banque */
 	gtk_clist_set_row_data ( GTK_CLIST ( clist ), ligne_insert, banque );
 
-	/* on slectionne le nouveau venu */
+	/* on sélectionne le nouveau venu */
 	gtk_clist_select_row ( GTK_CLIST ( clist ), ligne_insert, 0 );
 
-	/* on slectionne le "nouvelle banque" et lui donne le focus */
+	/* on sélectionne le "nouvelle banque" et lui donne le focus */
 	gtk_entry_select_region ( GTK_ENTRY ( nom_banque ), 0, -1 );
 	gtk_widget_grab_focus ( nom_banque );
     }
@@ -168,7 +168,7 @@ void annuler_modif_banque ( GtkWidget *bouton,
 
 /* **************************************************************************************************************************** */
 /* Fonction supprime_banque */
-/* appele lorsqu'on clicke sur le bouton enlever */
+/* appelée lorsqu'on clicke sur le bouton enlever */
 /* **************************************************************************************************************************** */
 void supprime_banque ( GtkWidget *bouton,
 		       GtkWidget *liste )
@@ -206,8 +206,8 @@ void supprime_banque ( GtkWidget *bouton,
 
     if ( resultat )
     {
-	/* La suppression de la banque est confirme, On fait le tour des
-	   comptes pour en modifier le numro de banque associe */
+	/* La suppression de la banque est confirmée, On fait le tour des
+	   comptes pour en modifier le numéro de banque associée */
 	
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -220,12 +220,6 @@ void supprime_banque ( GtkWidget *bouton,
 	    p_tab_nom_de_compte_variable++;
 	}
 
-	/* On dsensitive la hbox_boutons_modif_banque au cas o on
-	   tait en train de modifier la banque */
-
-	gtk_widget_set_sensitive ( hbox_boutons_modif_banque,
-				   FALSE );
-
 	/* On retire la banque de la liste */
 
 	gtk_clist_remove ( GTK_CLIST ( liste ),
@@ -234,8 +228,8 @@ void supprime_banque ( GtkWidget *bouton,
 						banque );
 	free ( banque );
 
-	/* Puis on fait le tour des banques pour recaler leurs numros
-	   et ne pas crer de trous dans la suite des numros */
+	/* Puis on fait le tour des banques pour recaler leurs numéros
+	   et ne pas créer de trous dans la suite des numéros */
 
 	for ( i = bank_nb_to_remove+1 ; i <= nb_banques ; i++ )
 	{
@@ -265,7 +259,7 @@ void supprime_banque ( GtkWidget *bouton,
 
 /* ************************************************************************************************************ */
 /* Fonction creation_menu_banques */
-/* cre un menu qui contient les noms des banques associs  leur no et adr */
+/* crée un menu qui contient les noms des banques associés à leur no et adr */
 /* et le renvoie */
 /* ************************************************************************************************************ */
 
@@ -402,7 +396,7 @@ GtkWidget *onglet_banques ( void )
 		ligne_insert = gtk_clist_append ( GTK_CLIST ( clist_banques_parametres ),
 						  ligne );
 
-		/* on associe  la ligne la struct de la banque */
+		/* on associe à la ligne la struct de la banque */
 
 		gtk_clist_set_row_data ( GTK_CLIST ( clist_banques_parametres ),
 					 ligne_insert,
@@ -525,18 +519,6 @@ void deselection_ligne_banque ( GtkWidget *liste,
     gtk_widget_set_sensitive ( frame, FALSE );
     gtk_widget_set_sensitive ( bouton_supprimer_banque, FALSE );
 }
-
-
-
-/* **************************************************************************************************************************** */
-void modif_detail_banque ( GtkWidget *entree,
-			   gpointer null )
-{
-
-    gtk_widget_set_sensitive ( hbox_boutons_modif_banque,
-			       TRUE );
-
-}
 /* **************************************************************************************************************************** */
 
 
