@@ -1,7 +1,7 @@
-/* fichier qui s'occupe de l'onglet de gestion des catgories */
+/* fichier qui s'occupe de l'onglet de gestion des catégories */
 /*           categories_onglet.c */
 
-/*     Copyright (C) 2000-2003  Cdric Auger */
+/*     Copyright (C) 2000-2003  Cédric Auger */
 /* 			cedric@grisbi.org */
 /* 			http://www.grisbi.org */
 
@@ -74,17 +74,17 @@ gchar *categories_de_base_debit [] = {
     N_("Children : Misc."),
     N_("Children : Studies"),
     N_("Studies : Lessons"),
-    N_("Studies : Scool fees"),
+    N_("Studies : School fees"),
     N_("Studies : Books"),
-    N_("Miscelanious : Gifts"),
-    N_("Financial expenses : Miscelanious"),
+    N_("Miscellaneous : Gifts"),
+    N_("Financial expenses : Miscellaneous"),
     N_("Financial expenses : Bank charges"),
     N_("Financial expenses : Loan/Mortgage"),
     N_("Financial expenses : Charges"),
     N_("Financial expenses : Refunding"),
-    N_("Professionnal expenses : Non refundable"),
-    N_("Professionnal expenses : Refundable"),
-    N_("Taxes : Miscelanious"),
+    N_("Professional expenses : Non refundable"),
+    N_("Professional expenses : Refundable"),
+    N_("Taxes : Miscellaneous"),
     N_("Taxes : Income"),
     N_("Taxes : Land"),
     N_("Housing : Hotel"),
@@ -99,7 +99,7 @@ gchar *categories_de_base_debit [] = {
     N_("Housing : White products"),
     N_("Housing : Equipment"),
     N_("Housing : Gaz"),
-    N_("Housiing : Garden"),
+    N_("Housing : Garden"),
     N_("Housing : House keeper"),
     N_("Housing : Phone"),
     N_("Housing : Mobile Phone"),
@@ -177,7 +177,7 @@ extern GtkWidget *widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FO
 
 /* **************************************************************************************************** */
 /* Fonction onglet_categories : */
-/* cre et renvoie le widget contenu dans l'onglet */
+/* crée et renvoie le widget contenu dans l'onglet */
 /* **************************************************************************************************** */
 
 GtkWidget *onglet_categories ( void )
@@ -200,7 +200,7 @@ GtkWidget *onglet_categories ( void )
     GtkWidget *bouton;
 
 
-    /* cration de la fentre qui sera renvoye */
+    /* création de la fenêtre qui sera renvoyée */
 
     onglet = gtk_hbox_new ( FALSE,
 			    5 );
@@ -209,7 +209,7 @@ GtkWidget *onglet_categories ( void )
     gtk_widget_show ( onglet );
 
 
-    /*   cration de la frame de gauche */
+    /*   création de la frame de gauche */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -265,7 +265,7 @@ GtkWidget *onglet_categories ( void )
     gtk_widget_show ( entree_nom_categ );
 
 
-    /* cration des radio bouton dbit/crdit */
+    /* création des radio bouton débit/crédit */
 
     separateur = gtk_hseparator_new ();
     gtk_box_pack_start ( GTK_BOX ( vbox_frame ),
@@ -323,7 +323,7 @@ GtkWidget *onglet_categories ( void )
 
 
 
-    /*   cration des boutons modifier et annuler */
+    /*   création des boutons modifier et annuler */
 
     hbox = gtk_hbox_new ( TRUE,
 			  5 );
@@ -457,7 +457,7 @@ GtkWidget *onglet_categories ( void )
 
 
 
-    /*   cration de la frame de droite */
+    /*   création de la frame de droite */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -486,7 +486,7 @@ GtkWidget *onglet_categories ( void )
 			 FALSE,
 			 0 );
 
-    /* cration de l'arbre principal */
+    /* création de l'arbre principal */
 
     scroll_window = gtk_scrolled_window_new ( NULL,
 					      NULL );
@@ -565,12 +565,12 @@ GtkWidget *onglet_categories ( void )
     gtk_widget_show ( arbre_categ );
 
 
-    /* on met la fontion de tri alphabtique en prenant en compte les accents */
+    /* on met la fontion de tri alphabétique en prenant en compte les accents */
 
     gtk_clist_set_compare_func ( GTK_CLIST ( arbre_categ ),
 				 (GtkCListCompareFunc) classement_alphabetique_tree );
 
-    /* la 1re fois qu'on affichera les catg, il faudra remplir la liste */
+    /* la 1ère fois qu'on affichera les catég, il faudra remplir la liste */
 
     modif_categ = 1;
 
@@ -605,18 +605,18 @@ void remplit_arbre_categ ( void )
     gtk_clist_clear ( GTK_CLIST ( arbre_categ ));
 
 
-    /*   le devise est choisie dans les paramtres */
+    /*   le devise est choisie dans les paramètres */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
     if ( !devise_compte
 	 ||
-	 devise_compte -> no_devise != no_devise_totaux_tiers )
+	 devise_compte -> no_devise != no_devise_totaux_categ )
 	devise_compte = g_slist_find_custom ( liste_struct_devises,
-					      GINT_TO_POINTER ( no_devise_totaux_tiers ),
+					      GINT_TO_POINTER ( no_devise_totaux_categ ),
 					      ( GCompareFunc ) recherche_devise_par_no) -> data;
 
-    /* calcule les montants des catg et sous categ */
+    /* calcule les montants des catég et sous categ */
 
     calcule_total_montant_categ ();
 
@@ -667,7 +667,7 @@ void remplit_arbre_categ ( void )
 					FALSE,
 					FALSE );
 
-	/* on associe  cette categ  l'adr de sa struct */
+	/* on associe à cette categ à l'adr de sa struct */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 				      ligne,
@@ -724,7 +724,7 @@ void remplit_arbre_categ ( void )
 						       FALSE,
 						       FALSE );
 
-	    /* on associe cette sous_categ  l'adr de sa struct */
+	    /* on associe cette sous_categ à l'adr de sa struct */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 					  ligne_sous_categ,
@@ -744,7 +744,7 @@ void remplit_arbre_categ ( void )
 						       FALSE,
 						       FALSE );
 
-	    /* on associe le fils bidon  -1 */
+	    /* on associe le fils bidon à -1 */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 					  ligne_sous_categ,
@@ -755,7 +755,7 @@ void remplit_arbre_categ ( void )
 	    liste_sous_categ_tmp = liste_sous_categ_tmp -> next;
 	}
 
-	/*       on a fini de saisir les sous catgories, s'il y avait des ops sans sous catg, on les mets ici */
+	/*       on a fini de saisir les sous catégories, s'il y avait des opés sans sous catég, on les mets ici */
 
 	if ( tab_montant_sous_categ[place_categ]
 	     &&
@@ -804,7 +804,7 @@ void remplit_arbre_categ ( void )
 						       FALSE,
 						       FALSE );
 
-	    /* on associe le fils bidon  -1 */
+	    /* on associe le fils bidon à -1 */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 					  ligne_sous_categ,
@@ -815,7 +815,7 @@ void remplit_arbre_categ ( void )
 	liste_categ_tmp = liste_categ_tmp -> next;
     }
 
-    /*   on a fini de mettre les catgories, on met ici les ops sans catg */
+    /*   on a fini de mettre les catégories, on met ici les opés sans catég */
 
     if ( tab_montant_categ[0] )
     {
@@ -891,7 +891,7 @@ void remplit_arbre_categ ( void )
 						   FALSE,
 						   FALSE );
 
-	/* on associe le fils bidon  -1 */
+	/* on associe le fils bidon à -1 */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 				      ligne_sous_categ,
@@ -928,8 +928,8 @@ void remplit_arbre_categ ( void )
 
 /* **************************************************************************************************** */
 /* Fonction ouverture_node_categ */
-/* appel lorsqu'on ouvre une categ, sous categ ou le compte d'une categ */
-/* remplit ce qui doit tre affich */
+/* appeléé lorsqu'on ouvre une categ, sous categ ou le compte d'une categ */
+/* remplit ce qui doit être affiché */
 /* **************************************************************************************************** */
 
 gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node, 
@@ -946,7 +946,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
     if ( !row || row->level == 1 )
 	return(FALSE);
 
-    /*   si le fiston = -1, c'est qu'il n'a pas encore t cr */
+    /*   si le fiston = -1, c'est qu'il n'a pas encore été créé */
     /* dans le cas contraire, on vire */
 
     if ( GPOINTER_TO_INT ( gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_categ ),
@@ -958,16 +958,16 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
     gtk_clist_freeze ( GTK_CLIST ( arbre_categ ));
 
 
-    /* on commence par virer la ligne bidon qui tait attache  ce noeud */
+    /* on commence par virer la ligne bidon qui était attachée à ce noeud */
 
     gtk_ctree_remove_node ( GTK_CTREE ( arbre_categ ),
 			    row -> children );
 
-    /* sparation entre ouverture de sous-categ ( 2 ) et ouverture de compte ( 3 ) */
+    /* séparation entre ouverture de sous-categ ( 2 ) et ouverture de compte ( 3 ) */
 
     if ( row -> level == 2 )
     {
-	/* c'est une ouverture de sous categ, on rcupre sa structure  */
+	/* c'est une ouverture de sous categ, on récupère sa structure  */
 
 	struct struct_categ *categ;
 	struct struct_sous_categ *sous_categ;
@@ -995,7 +995,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
 	    no_sous_categ = 0;
 	}
 
-	/* on va scanner tous les comptes, ds qu'un tiers correspondant au tiers slectionn est trouv */
+	/* on va scanner tous les comptes, dès qu'un tiers correspondant au tiers sélectionné est trouvé */
 	/* on affiche le nom du compte */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -1050,7 +1050,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
 							     FALSE,
 							     FALSE );
 
-		    /* associe le no de compte  la ligne du compte */
+		    /* associe le no de compte à la ligne du compte */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 						  node_insertion,
@@ -1070,7 +1070,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
 							     FALSE,
 							     FALSE );
 
-		    /* on associe le fils bidon  -1 */
+		    /* on associe le fils bidon à -1 */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 						  node_insertion,
@@ -1088,7 +1088,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
     else
     {
 	/* c'est une ouverture d'un compte */
-	/*       cette fois, on fait le tour de toutes les ops du compte pour afficher celles qui correspondent  la categ */
+	/*       cette fois, on fait le tour de toutes les opés du compte pour afficher celles qui correspondent à la categ */
 
 	struct struct_categ *categ;
 	struct struct_sous_categ *sous_categ;
@@ -1191,7 +1191,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
 							 FALSE,
 							 FALSE );
 
-		/* on associe  cette op l'adr de sa struct */
+		/* on associe à cette opé l'adr de sa struct */
 
 		gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 					      node_insertion,
@@ -1374,7 +1374,7 @@ void expand_selected_category ()
 	     gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_categ ),
 					   GTK_CTREE_ROW ( GTK_CTREE_ROW (( GTK_CLIST ( arbre_categ ) -> selection ) -> data ) -> parent ) -> parent ) > 0)))
     {
-	/* passage sur le compte concern */
+	/* passage sur le compte concerné */
 
 	operation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_categ ),
 						  GTK_CTREE_NODE ( ( GTK_CLIST ( arbre_categ ) -> selection ) -> data ) );
@@ -1383,8 +1383,8 @@ void expand_selected_category ()
 	     (gint) operation < nb_comptes ) /* Kludge attack */
 	    return;
 
-	/* si c'est une op de ventilation, on se place sur l'op
-	   ventile correspondante */ 
+	/* si c'est une opé de ventilation, on se place sur l'opé
+	   ventilée correspondante */ 
 	if ( operation -> no_operation_ventilee_associee )
 	{
 	    p_tab_nom_de_compte_variable = p_tab_nom_de_compte + operation -> no_compte;
@@ -1472,8 +1472,8 @@ void clique_sur_modifier_categ ( void )
     GtkCTreeNode *node;
 
 
-    /* si c'est une categ et si c'est une modif du nom, on doit rafficher la liste des categ et les listes des ops, sinon, on change juste la categ et */
-    /* met  jour les listes de categories */
+    /* si c'est une categ et si c'est une modif du nom, on doit réafficher la liste des categ et les listes des opés, sinon, on change juste la categ et */
+    /* met à jour les listes de categories */
     /* si c'est une sous categ, c'est obligmy_atoirement un changement de nom */
 
     if ( gtk_object_get_data ( GTK_OBJECT (  entree_nom_categ ),
@@ -1635,7 +1635,7 @@ void supprimer_categ ( void )
     if ( categ <= 0 )
 	return;
 
-    /* fait le tour des ops pour en trouver une qui a cette catgorie */
+    /* fait le tour des opés pour en trouver une qui a cette catégorie */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
     ope_trouvee = 0;
@@ -1664,7 +1664,7 @@ void supprimer_categ ( void )
 	p_tab_nom_de_compte_variable++;
     }
 
-    /* fait le tour des chances pour en trouver une qui a cette catgorie  */
+    /* fait le tour des échéances pour en trouver une qui a cette catégorie  */
 
     liste_tmp2 = gsliste_echeances;
     echeance_trouvee = 0;
@@ -1794,7 +1794,7 @@ void supprimer_categ ( void )
 	    pointeur = pointeur -> next;
 	}
 
-	/*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+	/*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
 	liste_combofix = g_slist_append ( liste_combofix,
 					  liste_categ_debit );
@@ -1887,7 +1887,7 @@ retour_dialogue:
 	}
 
 
-	/* on fait le tour des ops pour mettre le nouveau numro de categ et sous_categ */
+	/* on fait le tour des opés pour mettre le nouveau numéro de categ et sous_categ */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -1913,7 +1913,7 @@ retour_dialogue:
 	    p_tab_nom_de_compte_variable++;
 	}
 
-	/* fait le tour des chances pour mettre le nouveau numro de categ et sous_categ  */
+	/* fait le tour des échéances pour mettre le nouveau numéro de categ et sous_categ  */
 
 	liste_tmp = gsliste_echeances;
 
@@ -1947,6 +1947,7 @@ retour_dialogue:
 
     liste_struct_categories = g_slist_remove ( liste_struct_categories,
 					       categ );
+    free ( categ );
     nb_enregistrements_categories--;
 
     enleve_selection_ligne_categ();
@@ -1996,7 +1997,7 @@ void supprimer_sous_categ ( void )
 	return;
 
 
-    /* fait le tour des ops pour en trouver une qui a cette sous-catgorie */
+    /* fait le tour des opés pour en trouver une qui a cette sous-catégorie */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
     ope_trouvee = 0;
@@ -2029,7 +2030,7 @@ void supprimer_sous_categ ( void )
     }
 
 
-    /* fait le tour des chances pour en trouver une qui a cette catgorie  */
+    /* fait le tour des échéances pour en trouver une qui a cette catégorie  */
 
     liste_tmp2 = gsliste_echeances;
     echeance_trouvee = 0;
@@ -2161,7 +2162,7 @@ void supprimer_sous_categ ( void )
 	    pointeur = pointeur -> next;
 	}
 
-	/*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+	/*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
 	liste_combofix = g_slist_append ( liste_combofix,
 					  liste_categ_debit );
@@ -2224,7 +2225,7 @@ retour_dialogue:
 		goto retour_dialogue;
 	    }
 
-	    /* rcupre les no de categ et sous categ */
+	    /* récupère les no de categ et sous categ */
 
 	    split_categ = g_strsplit ( gtk_combofix_get_text ( GTK_COMBOFIX ( combofix )),
 				       " : ",
@@ -2254,7 +2255,7 @@ retour_dialogue:
 	}
 
 
-	/* on fait le tour des ops pour mettre le nouveau numro de categ et sous_categ */
+	/* on fait le tour des opés pour mettre le nouveau numéro de categ et sous_categ */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -2282,7 +2283,7 @@ retour_dialogue:
 	    p_tab_nom_de_compte_variable++;
 	}
 
-	/* fait le tour des chances pour mettre le nouveau numro de categ et sous_categ  */
+	/* fait le tour des échéances pour mettre le nouveau numéro de categ et sous_categ  */
 
 	liste_tmp = gsliste_echeances;
 
@@ -2319,7 +2320,7 @@ retour_dialogue:
 
     categ -> liste_sous_categ = g_slist_remove ( categ -> liste_sous_categ,
 						 sous_categ );
-
+    free ( sous_categ );
 
     enleve_selection_ligne_categ();
 
@@ -2336,8 +2337,8 @@ retour_dialogue:
 
 /***********************************************************************************************************/
 /* Routine creation_liste_categories */
-/* appele lors d'un nouveau fichier */
-/* cre la liste des catgories  partir de la liste ci dessus */
+/* appelée lors d'un nouveau fichier */
+/* crée la liste des catégories à partir de la liste ci dessus */
 /* en fait, merge la liste de base avec rien */
 /***********************************************************************************************************/
 
@@ -2359,7 +2360,7 @@ void creation_liste_categories ( void )
 /***********************************************************************************************************/
 /* Routine merge_liste_categories */
 /*   merge la liste de categories existante ( aucune quand vient de creation_liste_categories ) */
-/* avec la liste de base du dbut du fichier */
+/* avec la liste de base du début du fichier */
 /***********************************************************************************************************/
 
 void merge_liste_categories ( void )
@@ -2371,7 +2372,7 @@ void merge_liste_categories ( void )
 
     debit = 0;
 
-    /* rcupration des crdits puis des dbits*/
+    /* récupération des crédits puis des débits*/
 
 retour_recuperation :
 
@@ -2397,7 +2398,7 @@ retour_recuperation :
 
 	if ( !liste_tmp )
 	{
-	    /* la catgorie n'existe pas, on la cre */
+	    /* la catégorie n'existe pas, on la crée */
 
 	    struct struct_sous_categ *sous_categ;
 
@@ -2413,7 +2414,7 @@ retour_recuperation :
 						       categorie );
 	    nb_enregistrements_categories++;
 
-	    /* on cre la sous-catgorie si elle existe */
+	    /* on crée la sous-catégorie si elle existe */
 
 	    if ( split_categ[1] )
 	    {
@@ -2428,7 +2429,7 @@ retour_recuperation :
 	}
 	else
 	{
-	    /*  la catgorie existe, on vrifie si la sous-catg existe */
+	    /*  la catégorie existe, on vérifie si la sous-catég existe */
 
 	    GSList *sous_liste_tmp;
 
@@ -2440,7 +2441,7 @@ retour_recuperation :
 
 	    if ( !sous_liste_tmp )
 	    {
-		/* la sous catgorie n'existe pas, on la cre */
+		/* la sous catégorie n'existe pas, on la crée */
 
 		struct struct_sous_categ *sous_categ;
 
@@ -2454,14 +2455,14 @@ retour_recuperation :
 	    }
 	}
 
-	/* libre le tableau cr */
+	/* libère le tableau créé */
 
 	g_strfreev ( split_categ );
 
 	i++;
     }
 
-    /*       si on a fait les crdits, on fait les dbits */
+    /*       si on a fait les crédits, on fait les débits */
 
     if ( !debit )
     {
@@ -2474,11 +2475,11 @@ retour_recuperation :
 
 
 /***********************************************************************************************************/
-/*  Routine qui cre la liste des catgories pour les combofix du formulaire et de la ventilation */
-/* c'est  dire 3 listes dans 1 liste : */
-/* la premire contient les catgories de dbit */
-/* la seconde contient les catgories de crdit */
-/* la troisime contient les catgories spciales ( virement, retrait, ventilation ) */
+/*  Routine qui crée la liste des catégories pour les combofix du formulaire et de la ventilation */
+/* c'est à dire 3 listes dans 1 liste : */
+/* la première contient les catégories de débit */
+/* la seconde contient les catégories de crédit */
+/* la troisième contient les catégories spéciales ( virement, retrait, ventilation ) */
 /* la ventilation n'apparait pas dans les ventilations */
 /***********************************************************************************************************/
 
@@ -2538,7 +2539,7 @@ void creation_liste_categ_combofix ( void )
     }
 
 
-    /*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+    /*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
     liste_categories_combofix = g_slist_append ( liste_categories_combofix,
 						 liste_categ_debit );
@@ -2548,7 +2549,7 @@ void creation_liste_categ_combofix ( void )
 
 
 
-    /*   on ajoute les listes des crdits / dbits  la liste du combofix des  chances  */
+    /*   on ajoute les listes des crédits / débits à la liste du combofix des  échéances  */
 
     liste_categories_ventilation_combofix = g_slist_append ( liste_categories_ventilation_combofix,
 							     liste_categ_debit );
@@ -2556,7 +2557,7 @@ void creation_liste_categ_combofix ( void )
 							     liste_categ_credit );
 
 
-    /* cration des catgories spciales : les virements et la ventilation pour le formulaire */
+    /* création des catégories spéciales : les virements et la ventilation pour le formulaire */
 
     liste_categ_special = NULL;
 
@@ -2581,7 +2582,7 @@ void creation_liste_categ_combofix ( void )
     liste_categories_combofix = g_slist_append ( liste_categories_combofix,
 						 liste_categ_special );
 
-    /* on saute le texte Opration ventile */
+    /* on saute le texte Opération ventilée */
 
     liste_categ_special = liste_categ_special -> next;
 
@@ -2596,8 +2597,8 @@ void creation_liste_categ_combofix ( void )
 
 /***********************************************************************************************************/
 /* Fonction mise_a_jour_categ */
-/* recre les listes de catgories des combofix */
-/* et remet les combofix  jour */
+/* recrée les listes de catégories des combofix */
+/* et remet les combofix à jour */
 /***********************************************************************************************************/
 
 void mise_a_jour_categ ( void )
@@ -2638,8 +2639,8 @@ void mise_a_jour_categ ( void )
 
 /***********************************************************************************************************/
 /* Fonction ajoute_nouvelle_categorie */
-/* appele pour ajouter une nouvelle catg  la liste des catg */
-/* entre : la nouvelle catg */
+/* appelée pour ajouter une nouvelle catég à la liste des catég */
+/* entrée : la nouvelle catég */
 /* retour : l'adr de la struct */
 /***********************************************************************************************************/
 
@@ -2668,8 +2669,8 @@ struct struct_categ *ajoute_nouvelle_categorie ( gchar *categorie )
 
 /***********************************************************************************************************/
 /* Fonction ajoute_nouvelle_sous_categorie */
-/* appele pour ajouter une nouvelle sous catg  une catg */
-/* entre : la nouvelle sous catg et l'adr de la struct de la catg correspondante */
+/* appelée pour ajouter une nouvelle sous catég à une catég */
+/* entrée : la nouvelle sous catég et l'adr de la struct de la catég correspondante */
 /* retour : l'adr de la struct */
 /***********************************************************************************************************/
 
@@ -2695,7 +2696,7 @@ struct struct_sous_categ *ajoute_nouvelle_sous_categorie ( gchar *sous_categorie
 
 
 /* **************************************************************************************************** */
-/* cre un tableau de categ et de sous categ aussi gds que le nb de tiers */
+/* crée un tableau de categ et de sous categ aussi gds que le nb de tiers */
 /* et les renvoie dans un tab de 2 pointeurs */
 /* **************************************************************************************************** */
 
@@ -2703,9 +2704,9 @@ void calcule_total_montant_categ ( void )
 {
     gint i;
 
-    /* on cre les tableaux de montant */
+    /* on crée les tableaux de montant */
 
-    /* le +1 pour reserver le [0] pour aucune catgorie */
+    /* le +1 pour reserver le [0] pour aucune catégorie */
 
     tab_montant_categ = calloc ( nb_enregistrements_categories + 1,
 				 sizeof ( gfloat ));
@@ -2734,22 +2735,22 @@ void calcule_total_montant_categ ( void )
 
 	    operation = liste_tmp -> data;
 
-	    /* on commence par calculer le montant dans la devise choisie dans les paramtres */
+	    /* on commence par calculer le montant dans la devise choisie dans les paramètres */
 
 	    montant = calcule_montant_devise_renvoi ( operation -> montant,
-						      no_devise_totaux_tiers,
+						      no_devise_totaux_categ,
 						      operation -> devise,
 						      operation -> une_devise_compte_egale_x_devise_ope,
 						      operation -> taux_change,
 						      operation -> frais_change );
 
-	    /* on traite ensuite l'opration */
+	    /* on traite ensuite l'opération */
 
 	    if ( operation -> categorie )
 	    {
 		struct struct_categ *categorie;
 
-		/* il y a une catgorie */
+		/* il y a une catégorie */
 
 		categorie = g_slist_find_custom ( liste_struct_categories,
 						  GINT_TO_POINTER ( operation -> categorie ),
@@ -2760,7 +2761,7 @@ void calcule_total_montant_categ ( void )
 		place_categ = g_slist_index ( liste_struct_categories,
 					      categorie );
 
-		/* cre la place pour les sous catg de cette categ si ce n'est dj fait */
+		/* crée la place pour les sous catég de cette categ si ce n'est déjà fait */
 
 		if ( !tab_montant_sous_categ[place_categ] )
 		{
@@ -2768,7 +2769,7 @@ void calcule_total_montant_categ ( void )
 
 		    nb_sous_categ = g_slist_length ( categorie -> liste_sous_categ );
 
-		    /* on rserve nb_sous_categ + 1 pour aucune sous categ qui sera en [0] */
+		    /* on réserve nb_sous_categ + 1 pour aucune sous categ qui sera en [0] */
 
 		    tab_montant_sous_categ[place_categ] = calloc ( nb_sous_categ + 1,
 								   sizeof ( float ));
@@ -2779,7 +2780,7 @@ void calcule_total_montant_categ ( void )
 		tab_montant_categ[place_categ+1] = tab_montant_categ[place_categ+1] + montant;
 		nb_ecritures_par_categ[place_categ+1]++;
 
-		/* on ajoute maintenant le montant  la sous categ si elle existe */
+		/* on ajoute maintenant le montant à la sous categ si elle existe */
 
 		if ( operation -> sous_categorie )
 		{
@@ -2802,7 +2803,7 @@ void calcule_total_montant_categ ( void )
 		}
 	    }
 	    else
-		/* il n'y a pas de catgorie */
+		/* il n'y a pas de catégorie */
 		/* on met le montant dans tab_montant_categ[0} si e n'est ni un virement ni une ventil */
 		if ( !operation -> relation_no_operation
 		     &&
@@ -2850,7 +2851,7 @@ gchar *calcule_total_montant_categ_par_compte ( gint categ, gint sous_categ, gin
 	    gdouble montant;
 
 	    montant = calcule_montant_devise_renvoi ( operation -> montant,
-						      no_devise_totaux_tiers,
+						      no_devise_totaux_categ,
 						      operation -> devise,
 						      operation -> une_devise_compte_egale_x_devise_ope,
 						      operation -> taux_change,
@@ -2865,7 +2866,7 @@ gchar *calcule_total_montant_categ_par_compte ( gint categ, gint sous_categ, gin
     if ( retour_int )
 	return ( g_strdup_printf ( _("%4.2f %s"),
 				   retour_int,
-				   devise_name_by_no ( no_devise_totaux_tiers ) ));
+				   devise_name_by_no ( no_devise_totaux_categ ) ));
     else
 	return ( NULL );
 }
@@ -2894,12 +2895,12 @@ void appui_sur_ajout_categorie ( void )
 	return;
       }
 
-    /* on l'ajoute  la liste des ops */
+    /* on l'ajoute à la liste des opés */
 
     nouvelle_categorie = ajoute_nouvelle_categorie ( nom_categorie );
 
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour éviter de toute la réafficher */
 
     text[0] = nouvelle_categorie -> nom_categ;
     text[1] = NULL;
@@ -2918,7 +2919,7 @@ void appui_sur_ajout_categorie ( void )
 				    FALSE,
 				    FALSE );
 
-    /* on associe  ce categorie  l'adr de sa struct */
+    /* on associe à ce categorie à l'adr de sa struct */
 
     gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 				  ligne,
@@ -2949,14 +2950,14 @@ void appui_sur_ajout_sous_categorie ( void )
 						 COLON(_("Enter name for new sub-category")) )))
 	return;
 
-    /* rcupre le node parent */
+    /* récupère le node parent */
 
     node_parent = GTK_CLIST ( arbre_categ ) -> selection -> data;
 
     while ( GTK_CTREE_ROW ( node_parent ) -> level != 1 )
 	node_parent = GTK_CTREE_ROW ( node_parent ) -> parent;
 
-    /* on rcupre l'categorie parente */
+    /* on récupère l'categorie parente */
 
     categorie = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_categ ),
 					      node_parent );
@@ -2973,13 +2974,13 @@ void appui_sur_ajout_sous_categorie ( void )
 	return;
       }
 
-    /* on l'ajoute  la liste des ops */
+    /* on l'ajoute à la liste des opés */
 
     nouvelle_sous_categorie = ajoute_nouvelle_sous_categorie ( nom_sous_categorie,
 							       categorie );
 
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour éviter de toute la réafficher */
 
     text[0] = nouvelle_sous_categorie -> nom_sous_categ;
     text[1] = NULL;
@@ -2998,7 +2999,7 @@ void appui_sur_ajout_sous_categorie ( void )
 				    FALSE,
 				    FALSE );
 
-    /* on associe  ce categorie  l'adr de sa struct */
+    /* on associe à ce categorie à l'adr de sa struct */
 
     gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_categ ),
 				  ligne,
@@ -3038,7 +3039,7 @@ void exporter_categ ( void )
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
-	    /* vrification que c'est possible */
+	    /* vérification que c'est possible */
 
 	    if ( !strlen ( nom_categ ))
 		return;
@@ -3107,7 +3108,7 @@ void importer_categ ( void )
 
     gtk_widget_destroy ( GTK_WIDGET (fenetre_nom  ));
 
-    /* vrification que c'est possible */
+    /* vérification que c'est possible */
 
     if ( !strlen ( nom_categ ))
 	return;
@@ -3127,13 +3128,13 @@ void importer_categ ( void )
 			 GTK_SIGNAL_FUNC ( gtk_signal_emit_stop_by_name ),
 			 "destroy" );
 
-    /* pour viter un warning lors de la compil */
+    /* pour éviter un warning lors de la compil */
 
     bouton_merge_remplace = NULL;
 
     if ( no_derniere_operation )
     {
-	/*       il y a dj des oprations dans le fichier, on ne peut que fusionner */
+	/*       il y a déjà des opérations dans le fichier, on ne peut que fusionner */
 
 	label = gtk_label_new ( _("File already contains transactions, the two categories lists will be merged." ));
 	gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ),
