@@ -3,7 +3,7 @@
 /*                                                                            */
 /*                         comptes_traitements.c                              */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
 /*			2004 Alain Portal (dionysos@grisbi.org)		      */
 /*			http://www.grisbi.org				      */
@@ -57,7 +57,7 @@ gint noname_account_number = 0;
 
 
 /* ************************************************************************** */
-/* Routine appele lorsque l'on cre un nouveau compte                        */
+/* Routine appelée lorsque l'on crée un nouveau compte                        */
 /* ************************************************************************** */
 void  nouveau_compte ( void )
 {
@@ -77,24 +77,24 @@ void  nouveau_compte ( void )
 
     no_compte = initialisation_nouveau_compte ( type_de_compte );
 
-    /* si la cration s'est mal place, on se barre */
+    /* si la création s'est mal placée, on se barre */
 
     if ( no_compte == -1 )
 	return;
 
-    /* on cre la liste des ops */
+    /* on crée la liste des opés */
 
     ajoute_nouvelle_liste_operation( NO_COMPTE );
 
-    /* on recre les combofix des catgories */
+    /* on recrée les combofix des catégories */
 
     mise_a_jour_categ();
 
-    /* on met  jour l'option menu des formulaires des chances et des ops */
+    /* on met à jour l'option menu des formulaires des échéances et des opés */
 
     update_options_menus_comptes ();
 
-    /* mise  jour de l'accueil */
+    /* mise à jour de l'accueil */
 
     update_liste_comptes_accueil ();
 
@@ -104,16 +104,16 @@ void  nouveau_compte ( void )
     gtk_widget_set_sensitive ( bouton_supprimer_compte,
 			       TRUE );
 
-    /* cre le nouveau bouton du compte et l'ajoute  la liste des comptes */
+    /* crée le nouveau bouton du compte et l'ajoute à la liste des comptes */
 
     reaffiche_liste_comptes ();
 
-    /* on cre le nouveau compte dans les proprits des comptes */
+    /* on crée le nouveau compte dans les propriétés des comptes */
 
     compte_courant_onglet = nb_comptes - 1;
     reaffiche_liste_comptes_onglet ();
 
-    /* on se met sur l'onglet de proprits du compte */
+    /* on se met sur l'onglet de propriétés du compte */
 
     gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general ),
 			    3 );
@@ -123,8 +123,8 @@ void  nouveau_compte ( void )
 /* ************************************************************************** */
 
 /* ************************************************************************** */
-/* Cette fonction cre un nouveau compte, l'initialise, l'ajoute aux comptes  */
-/* et renvoie le no du compte cr                                            */
+/* Cette fonction crée un nouveau compte, l'initialise, l'ajoute aux comptes  */
+/* et renvoie le no du compte créé                                            */
 /* renvoie -1 s'il y a un pb                                                  */
 /* ************************************************************************** */
 gint initialisation_nouveau_compte ( gint type_de_compte )
@@ -150,7 +150,7 @@ gint initialisation_nouveau_compte ( gint type_de_compte )
 
     noname_account_number++;
 
-    /* insre ses paramtres ( comme c'est un appel  calloc, tout ce qui est  0 est dj initialis )*/
+    /* insère ses paramètres ( comme c'est un appel à calloc, tout ce qui est à 0 est déjà initialisé )*/
 
     NOM_DU_COMPTE = g_strdup_printf ( _("No name %d"), noname_account_number );
     OPERATION_SELECTIONNEE = GINT_TO_POINTER ( -1 );
@@ -165,12 +165,12 @@ gint initialisation_nouveau_compte ( gint type_de_compte )
     nb_comptes++;
 
 
-    /* on cre les types par dfaut */
+    /* on crée les types par défaut */
 
     creation_types_par_defaut ( NO_COMPTE,
 				0);
 
-    /* on met le compte  la fin dans le classement des comptes */
+    /* on met le compte à la fin dans le classement des comptes */
 
     ordre_comptes = g_slist_append ( ordre_comptes,
 				     GINT_TO_POINTER ( NO_COMPTE ) );
@@ -214,7 +214,7 @@ void supprimer_compte ( void )
     gtk_notebook_remove_page ( GTK_NOTEBOOK ( notebook_listes_operations ),
 			       compte_modifie + 1 );
 
-    /*       suppression des chances */
+    /*       suppression des échéances */
     while ( ( pointeur_liste = 
 	      g_slist_find_custom ( gsliste_echeances,
 				    GINT_TO_POINTER ( compte_modifie ),
@@ -239,7 +239,7 @@ void supprimer_compte ( void )
 				     GINT_TO_POINTER ( compte_modifie ));
 
 
-    /* modifie les numros des comptes suprieurs au compte supprim
+    /* modifie les numéros des comptes supérieurs au compte supprimé
        dans l'ordre des comptes */
     pointeur_liste = ordre_comptes;
 
@@ -271,7 +271,7 @@ void supprimer_compte ( void )
     g_slist_free ( LISTE_OPERATIONS );
     nom_compte_supprime = g_strdup ( NOM_DU_COMPTE );
 
-    /* on dcale en mmoire les comptes situs aprs */
+    /* on décale en mémoire les comptes situés après */
     for ( i = compte_modifie ; i < nb_comptes ; i++ )
     {
 	NO_COMPTE = NO_COMPTE -1;
@@ -281,8 +281,8 @@ void supprimer_compte ( void )
 
     nb_comptes--;
 
-    /* recherche les chances pour les comptes plas aprs le compe supprim */
-    /* pour leur diminuer leur numro de compte de 1 */
+    /* recherche les échéances pour les comptes plaçés après le compe supprimé */
+    /* pour leur diminuer leur numéro de compte de 1 */
     pointeur_liste = gsliste_echeances;
 
     while ( pointeur_liste )
@@ -295,11 +295,11 @@ void supprimer_compte ( void )
 	pointeur_liste = pointeur_liste -> next;
     }
 
-    /*   fait le tour des ops de tous les comptes, */
-    /*     pour les ops des comptes >  celui supprim, on descend le
+    /*   fait le tour des opés de tous les comptes, */
+    /*     pour les opés des comptes > à celui supprimé, on descend le
 	   no de compte */
-    /*     pour les virements vers le compte supprim, met
-	   relation_no_compte  -1 */
+    /*     pour les virements vers le compte supprimé, met
+	   relation_no_compte à -1 */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -334,29 +334,29 @@ void supprimer_compte ( void )
 	p_tab_nom_de_compte_variable++;
     }
 
-    /* le compte courant de l'onglet de comptes est diminu de 1 ou reste */
-    /*  0 s'il l'tait */
+    /* le compte courant de l'onglet de comptes est diminué de 1 ou reste */
+    /* à 0 s'il l'était */
 
     if ( compte_courant_onglet )
 	compte_courant_onglet--;
 
     /* retire le bouton du compte dans la liste des comptes */
-    /*   pour cela, on efface vbox_liste_comptes et on le recre */
+    /*   pour cela, on efface vbox_liste_comptes et on le recrée */
 
     reaffiche_liste_comptes();
     reaffiche_liste_comptes_onglet ();
 
-    /* on recre les combofix des tiers et des catgories */
+    /* on recrée les combofix des tiers et des catégories */
 
     mise_a_jour_tiers();
     mise_a_jour_categ();
     mise_a_jour_imputation();
 
-    /* on met  jour l'option menu du formulaire des chances */
+    /* on met à jour l'option menu du formulaire des échéances */
 
     update_options_menus_comptes ();
 
-    /* raffiche la liste si necessaire */
+    /* réaffiche la liste si necessaire */
 
     page_en_cours = gtk_notebook_get_current_page (GTK_NOTEBOOK(notebook_general));
 
@@ -485,7 +485,7 @@ void changement_choix_compte_echeancier ( GtkWidget *item )
 
     if ( gtk_widget_get_style ( widget_formulaire_echeancier[SCHEDULER_FORM_CREDIT] ) == style_entree_formulaire[ENCLAIR] )
     {
-	/*       il y a qque chose dans le crdit, on met le menu des types crdit */
+	/*       il y a qque chose dans le crédit, on met le menu des types crédit */
 
 	if ( (menu = creation_menu_types ( 2,
 					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( item),
@@ -503,7 +503,7 @@ void changement_choix_compte_echeancier ( GtkWidget *item )
     }
     else
     {
-	/*       il y a qque chose dans le dbit ou c'est par dfaut, on met le menu des types dbit */
+	/*       il y a qque chose dans le débit ou c'est par défaut, on met le menu des types débit */
 
 	if ( (menu = creation_menu_types ( 1,
 					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT (item ),
@@ -533,7 +533,7 @@ void creation_types_par_defaut ( gint no_compte,
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte + no_compte;
 
 
-    /* si des types d'op existaient dj, on les vire */
+    /* si des types d'opé existaient déjà, on les vire */
 
     if ( TYPES_OPES )
 	g_slist_free ( TYPES_OPES );
@@ -544,10 +544,10 @@ void creation_types_par_defaut ( gint no_compte,
 
     if ( !TYPE_DE_COMPTE )
     {
-	/* c'est un compte bancaire, on ajoute virement, prlvement, chque et cb */
-	/* 	  modification par rapport  avant, les nouveaux n: */
-	/* 	    1=virement, 2=dpot, 3=cb, 4=prlvement, 5=chque */
-	/* les modifs pour chaque ops se feront  leur chargement */
+	/* c'est un compte bancaire, on ajoute virement, prélèvement, chèque et cb */
+	/* 	  modification par rapport à avant, les nouveaux n°: */
+	/* 	    1=virement, 2=dépot, 3=cb, 4=prélèvement, 5=chèque */
+	/* les modifs pour chaque opés se feront à leur chargement */
 
 	struct struct_type_ope *type_ope;
 
@@ -615,7 +615,7 @@ void creation_types_par_defaut ( gint no_compte,
 	TYPE_DEFAUT_DEBIT = 3;
 	TYPE_DEFAUT_CREDIT = 2;
 
-	/* on cre le tri pour compte bancaire qui sera 1 2 3 4 5 */
+	/* on crée le tri pour compte bancaire qui sera 1 2 3 4 5 */
 
 	LISTE_TRI = g_slist_append ( LISTE_TRI,
 				     GINT_TO_POINTER ( 1 ));
@@ -651,7 +651,7 @@ void creation_types_par_defaut ( gint no_compte,
 	    TYPE_DEFAUT_DEBIT = 1;
 	    TYPE_DEFAUT_CREDIT = 1;
 
-	    /* on cre le tri pour compte passif qui sera 1 */
+	    /* on crée le tri pour compte passif qui sera 1 */
 
 	    LISTE_TRI = g_slist_append ( LISTE_TRI,
 					 GINT_TO_POINTER ( 1 ));
@@ -663,9 +663,9 @@ void creation_types_par_defaut ( gint no_compte,
 /* ************************************************************************** */
 
 /* ************************************************************************** */
-/* Cette fonction est appele lors de la cration d'un nouveau compte.        */
-/* elle renvoie le type demand pour pouvoir mettre ensuite les types par     */
-/* dfaut.                                                                    */
+/* Cette fonction est appelée lors de la création d'un nouveau compte.        */
+/* elle renvoie le type demandé pour pouvoir mettre ensuite les types par     */
+/* défaut.                                                                    */
 /* ************************************************************************** */
 gint demande_type_nouveau_compte ( void )
 {
@@ -681,7 +681,7 @@ gint demande_type_nouveau_compte ( void )
 				       make_hint ( _("Choose account type"),
 						   _("If you choose to continue, an account will be created with default payment methods chosen according to your choice.\nYou will be able to change account type later." ) ) );
 
-    /* cration de la ligne du type de compte */
+    /* création de la ligne du type de compte */
     hbox = gtk_hbox_new ( FALSE, 0 );
     gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG(dialog) -> vbox ), hbox,
 			 FALSE, FALSE, 6 );
@@ -717,9 +717,9 @@ gint demande_type_nouveau_compte ( void )
 
 
 /* ************************************************************************** */
-/* cette fonction est appele pour mettre un option menu de compte sur le */
-/* compte donn en argument */
-/* elle renvoie le no  mettre dans history */
+/* cette fonction est appelée pour mettre un option menu de compte sur le */
+/* compte donné en argument */
+/* elle renvoie le no à mettre dans history */
 /* ************************************************************************** */
 gint recherche_compte_dans_option_menu ( GtkWidget *option_menu,
 					 gint no_compte )
@@ -753,7 +753,7 @@ gint recherche_compte_dans_option_menu ( GtkWidget *option_menu,
 
 void update_options_menus_comptes ( void )
 {
-    /*     on met  jour l'option menu de l'chancier */
+    /*     on met à jour l'option menu de l'échéancier */
 
     gtk_option_menu_set_menu ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_ACCOUNT] ),
 			       creation_option_menu_comptes_nonclos (GTK_SIGNAL_FUNC(changement_choix_compte_echeancier),
