@@ -1,9 +1,9 @@
 #ifndef _CONSTANTS_H
 #define _CONSTANTS_H 1
-/* Fichier de dfinition de constantes constant.h */
+/* Fichier de définition de constantes constant.h */
 
-/* Constantes qui dfinisent le numro de colonne dans la liste des oprations
-   dans l'onglet oprations */
+/* Constantes qui définisent le numéro de colonne dans la liste des opérations
+   dans l'onglet opérations */
 #define TRANSACTION_COL_NB_CHECK 0
 #define TRANSACTION_COL_NB_DATE 1
 #define TRANSACTION_COL_NB_PARTY 2
@@ -15,8 +15,8 @@
 
 #define TRANSACTION_LIST_ROWS_NB 4
 
-/* Constantes qui dfinisent le numro de widget dans le formulaire
-   de saisie des oprations */
+/* Constantes qui définisent le numéro de widget dans le formulaire
+   de saisie des opérations */
 # define TRANSACTION_FORM_OP_NB 0
 # define TRANSACTION_FORM_DATE 1
 # define TRANSACTION_FORM_PARTY 2
@@ -38,8 +38,8 @@
 # define TRANSACTION_FORM_MODE 18
 # define TRANSACTION_FORM_WIDGET_NB 19	 /* must be the last of the list */
 
-/* Constantes qui dfinisent le numro de widget dans le formulaire
-   de ventilation des oprations */
+/* Constantes qui définisent le numéro de widget dans le formulaire
+   de ventilation des opérations */
 # define TRANSACTION_BREAKDOWN_FORM_CATEGORY 0
 # define TRANSACTION_BREAKDOWN_FORM_NOTES 1
 # define TRANSACTION_BREAKDOWN_FORM_DEBIT 2
@@ -50,8 +50,8 @@
 # define TRANSACTION_BREAKDOWN_FORM_VOUCHER 7
 # define TRANSACTION_BREAKDOWN_FORM_TOTAL_WIDGET 8	 /* must be the last of the list */
 
-/* Constantes qui dfinisent le numro de widget dans le formulaire
-   de saisie des chances */
+/* Constantes qui définisent le numéro de widget dans le formulaire
+   de saisie des échéances */
 # define SCHEDULER_FORM_DATE 0
 # define SCHEDULER_FORM_PARTY 1
 # define SCHEDULER_FORM_DEBIT 2
@@ -73,8 +73,8 @@
 # define SCHEDULER_FORM_FREQ_CUSTOM_MENU 18
 # define SCHEDULER_FORM_TOTAL_WIDGET 19	 /* must be the last of the list */
 
-/* Constantes qui dfinisent le numro de widget dans le formulaire
-   de ventilation des oprations planifies */
+/* Constantes qui définisent le numéro de widget dans le formulaire
+   de ventilation des opérations planifiées */
 # define SCHEDULER_BREAKDOWN_FORM_CATEGORY 0
 # define SCHEDULER_BREAKDOWN_FORM_NOTES 1
 # define SCHEDULER_BREAKDOWN_FORM_DEBIT 2
