@@ -1,7 +1,7 @@
 /* Fichier devises.c */
 /* s'occupe de tout ce qui concerne les devises */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2003 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
 
@@ -329,7 +329,7 @@ void update_currency_widgets()
 									   ( GCompareFunc ) recherche_devise_par_no )));
 
 
-    /* on recre les boutons de devises dans la conf de l'tat */
+    /* on recrée les boutons de devises dans la conf de l'état */
 
     if ( onglet_config_etat )
     {
@@ -380,7 +380,7 @@ void creation_devises_de_base ( void )
     devise -> nom_devise= g_strdup ( _("Euro") );
     devise -> code_iso4217_devise = g_strdup ("EUR");
     /* Do not translate, this is UTF-8 babe !*/
-    devise -> code_devise = g_strdup ( g_strdup ("€") ); 
+    devise -> code_devise = g_strdup ("€"); 
     devise -> passage_euro = 0;
     devise -> date_dernier_change = NULL;
     devise -> une_devise_1_egale_x_devise_2 = 0;
@@ -657,8 +657,8 @@ GtkWidget * new_currency_list ()
 
 /***********************************************************************************************************/
 /* Fonction ajout_devise */
-/* appele pour crer une nouvelle devise */
-/* soit c'est la clist des paramtres */
+/* appelée pour créer une nouvelle devise */
+/* soit c'est la clist des paramètres */
 /* soit il est NULL, quand il provient de l'import */
 /***********************************************************************************************************/
 
@@ -786,7 +786,7 @@ reprise_dialog:
 
 
 		/* 	  si le widget n'est pas nul, c'est une clist, c'est que l'appel vient du menu de configuration, */
-		/* on met la liste  jour et on ajoute la devise  liste_struct_devises */
+		/* on met la liste à jour et on ajoute la devise à liste_struct_devises */
 
 		devise -> no_devise = ++no_derniere_devise;
 		liste_struct_devises = g_slist_append ( liste_struct_devises,
@@ -969,6 +969,7 @@ void retrait_devise ( GtkWidget *bouton,
     gtk_clist_remove ( GTK_CLIST ( liste ), ligne_selection_devise );
 
     liste_struct_devises = g_slist_remove ( liste_struct_devises, devise );
+    free ( devise );
     nb_devises--;
 
 }
@@ -1116,10 +1117,10 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 			 FALSE, FALSE, 5 );
 
     entree_frais = gtk_entry_new ();
-    gtk_entry_set_activates_default ( GTK_ENTRY ( entree_frais ),
-				      TRUE );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), entree_frais,
-			 TRUE, TRUE, 5 );
+    gtk_entry_set_activates_default ( GTK_ENTRY ( entree_frais ), TRUE );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), entree_frais, TRUE, TRUE, 5 );
+    g_object_set_data ( G_OBJECT (option_menu_devise_1), "change", entree_frais );
+    g_object_set_data ( G_OBJECT (option_menu_devise_2), "change", entree_frais );
 
     label = gtk_label_new ( devise_compte -> nom_devise );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
@@ -1145,6 +1146,8 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 	    gtk_option_menu_set_history ( GTK_OPTION_MENU ( option_menu_devise_2 ),
 					  1 );
 	}
+	if ( ! une_devise_compte_egale_x_devise_ope ) 
+	    taux_change = 1 / taux_change;
 	gtk_entry_set_text ( GTK_ENTRY ( entree ),
 			     g_strdup_printf ( "%f", taux_change ));
 	gtk_entry_set_text ( GTK_ENTRY ( entree_frais ),
@@ -1168,7 +1171,9 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 	    if ( devise_compte -> date_dernier_change )
 		gtk_entry_set_text ( GTK_ENTRY ( entree ),
 				     g_strdup_printf ( "%f",
-						       devise_compte -> change ));
+						       (devise_compte -> une_devise_1_egale_x_devise_2 ? 
+							1/devise_compte -> change :
+							devise_compte -> change ) ));
 	}
 	else
 	    if ( devise -> no_devise_en_rapport == devise_compte -> no_devise )
@@ -1183,7 +1188,9 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 		if ( devise -> date_dernier_change )
 		    gtk_entry_set_text ( GTK_ENTRY ( entree ),
 					 g_strdup_printf ( "%f",
-							   devise -> change ));
+							   (devise_compte -> une_devise_1_egale_x_devise_2 ? 
+							    devise -> change :
+							    1/devise -> change ) ));
 	    }
 	    else
 	    {
@@ -1215,8 +1222,6 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 	if ( devise_tmp -> no_devise != devise -> no_devise )
 	    taux_de_change[0] = -taux_de_change[0];
 
-	gtk_widget_destroy ( GTK_WIDGET ( dialog ));
-
 	update_exchange_rate_cache ( devise_compte, devise, 
 				     taux_de_change[0], taux_de_change[1] );
 
@@ -1226,6 +1231,8 @@ void demande_taux_de_change ( struct struct_devise *devise_compte,
 	taux_de_change[0] = 0;
 	taux_de_change[1] = 0;
     }
+
+    gtk_widget_destroy ( GTK_WIDGET ( dialog ));
 }
 /***********************************************************************************************************/
 
@@ -1258,6 +1265,11 @@ gboolean devise_selectionnee ( GtkWidget *menu_shell, gint origine )
 					  (gpointer) !origine );
 	if (associate)
 	    gtk_option_menu_set_history ( GTK_OPTION_MENU(associate), 1 - position );
+
+/* 	entry = g_object_get_data ( G_OBJECT(menu_shell), "entry" ); */
+/* 	if ( entry ) */
+/* 	    gtk_signal_func */
+
 	g_signal_handlers_unblock_by_func ( G_OBJECT(associate),
 					    G_CALLBACK (devise_selectionnee), 
 					    (gpointer) !origine );
@@ -1598,6 +1610,85 @@ GtkWidget *onglet_devises ( void )
 
 
 
+/**
+ * Creates a new GtkOptionMenu with a pointer to an integerthat will
+ * be modified according to the entry's value.
+ *
+ * \param value A pointer to a string
+ * \param hook An optional function to execute as a handler
+ *
+ * \return A newly allocated option menu.
+ */
+GtkWidget * new_currency_option_menu ( gint * value, GCallback hook )
+{
+    GtkWidget * currency_list, *currency_menu;
+
+    currency_list = gtk_option_menu_new ();
+    currency_menu = creation_option_menu_devises ( 0, liste_struct_devises );
+    gtk_option_menu_set_menu ( GTK_OPTION_MENU ( currency_list ), currency_menu );
+    if (value && *value)
+	gtk_option_menu_set_history ( GTK_OPTION_MENU(currency_list), *value - 1 );
+
+    g_signal_connect ( GTK_OBJECT (currency_list), "changed", (GCallback) set_int_from_menu, value );
+    g_signal_connect ( GTK_OBJECT (currency_list), "changed", (GCallback) hook, value );
+    g_object_set_data ( G_OBJECT ( currency_list ), "pointer", value);
+
+    return currency_list;
+}
+
+
+
+/**
+ *
+ *
+ */
+GtkWidget *tab_display_totals ( void )
+{
+    GtkWidget *vbox_pref, *currency_list, *table, *label;
+
+    vbox_pref = new_vbox_with_title_and_icon ( _("Totals currencies"),
+					       "currencies.png" );
+
+    table = gtk_table_new ( 2, 2, FALSE );
+    gtk_table_set_col_spacings ( GTK_TABLE ( table ), 5 );
+    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
+
+    label = gtk_label_new ( COLON ( _("Currency for third parties tree") ) );
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
+    gtk_table_attach ( GTK_TABLE ( table ), label, 
+		       0, 1, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    currency_list = new_currency_option_menu ( &no_devise_totaux_tiers, 
+					       remplit_arbre_tiers );
+    gtk_table_attach ( GTK_TABLE ( table ), currency_list,
+		       1, 2, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+
+    label = gtk_label_new ( COLON ( _("Currency for categories tree") ) );
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
+    gtk_table_attach ( GTK_TABLE ( table ), label,
+		       0, 1, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    currency_list = new_currency_option_menu ( &no_devise_totaux_categ, 
+					       remplit_arbre_categ );
+    gtk_table_attach ( GTK_TABLE ( table ), currency_list,
+		       1, 2, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+
+    label = gtk_label_new ( COLON ( _("Currency for budgetary lines tree") ) );
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
+    gtk_table_attach ( GTK_TABLE ( table ), label,
+		       0, 1, 2, 3, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    currency_list = new_currency_option_menu ( &no_devise_totaux_ib, 
+					       remplit_arbre_imputation );
+    gtk_table_attach ( GTK_TABLE ( table ), currency_list,
+		       1, 2, 2, 3, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), table, TRUE, TRUE, 0);
+
+    return ( vbox_pref );
+}
+
+
 
 /* **************************************************************************************************************************** */
 /* Fonction selection_ligne_devise */
@@ -1748,7 +1839,7 @@ gboolean change_passera_euro ( GtkWidget *bouton,
 	/*       gtk_entry_set_text ( GTK_ENTRY ( entree_conversion ), */
 	/* 			   g_strdup_printf ( "%f", */
 	/* 					     devise -> change )); */
-	spin_button_set_value ( entree_conversion, &(devise->change) );
+	spin_button_set_value_double ( entree_conversion, &(devise->change) );
 
 	/* on rend le tout sensitif */
 
@@ -1794,7 +1885,7 @@ gboolean change_passera_euro ( GtkWidget *bouton,
 
 	    gtk_label_set_text ( GTK_LABEL ( label_date_dernier_change ),
 				 g_strconcat (_("Last exchange rate"), ": ", date, NULL ));
-	    spin_button_set_value ( entree_conversion, &(devise->change) );
+	    spin_button_set_value_double ( entree_conversion, &(devise->change) );
 	}
 	else
 	{
@@ -1802,7 +1893,7 @@ gboolean change_passera_euro ( GtkWidget *bouton,
 				 _("No exchange rate defined")  );
 	    /* mise en place du change courant */
 
-	    spin_button_set_value ( entree_conversion, &(devise->change) );
+	    spin_button_set_value_double ( entree_conversion, &(devise->change) );
 	    /* 	  gtk_entry_set_text ( GTK_ENTRY ( entree_conversion ), "" ); */
 	}
 
@@ -1941,7 +2032,7 @@ gboolean changement_devise_associee ( GtkWidget *menu_devises,
 	devise -> no_devise_en_rapport = devise_associee -> no_devise;
 
 	create_change_menus(devise); 
-	spin_button_set_value ( entree_conversion, &(devise->change));
+	spin_button_set_value_double ( entree_conversion, &(devise->change));
     }
     else
     {
@@ -1953,7 +2044,7 @@ gboolean changement_devise_associee ( GtkWidget *menu_devises,
 	gtk_option_menu_set_menu ( GTK_OPTION_MENU ( devise_2 ),
 				   menu );
 
-	spin_button_set_value ( entree_conversion, 0 );
+	spin_button_set_value_double ( entree_conversion, 0 );
 	/*       gtk_entry_set_text ( GTK_ENTRY ( entree_conversion ), */
 	/* 			   "" ); */
 	gtk_widget_set_sensitive ( hbox_ligne_change,
@@ -2038,7 +2129,7 @@ gdouble calcule_montant_devise_renvoi ( gdouble montant_init,
 					gdouble taux_change,
 					gdouble frais_change )
 {
-    gdouble montant;
+    gdouble montant = 0;
 
     /* tout d'abord, si les 2 devises sont les mêmes, on renvoie le montant directement */
 
@@ -2069,20 +2160,35 @@ gdouble calcule_montant_devise_renvoi ( gdouble montant_init,
 
     /* on a maintenant les 2 devises, on peut faire les calculs */
 
-    if ( devise_compte -> passage_euro
+    if ( devise_compte && devise_compte -> passage_euro
 	 &&
 	 !strcmp ( devise_operation -> nom_devise, _("Euro") ) )
 	montant = montant_init * devise_compte -> change;
     else
-	if ( devise_operation -> passage_euro
+	if ( devise_operation && devise_operation -> passage_euro
 	     &&
 	     !strcmp ( devise_compte -> nom_devise, _("Euro") ))
 	    montant = montant_init / devise_operation -> change;
 	else
-	    if ( une_devise_compte_egale_x_devise_ope )
-		montant = montant_init / taux_change - frais_change;
+	    if ( taux_change )
+	    {
+		if ( une_devise_compte_egale_x_devise_ope )
+		    montant = montant_init / taux_change - frais_change;
+		else
+		    montant = montant_init * taux_change - frais_change;
+	    }
 	    else
-		montant = montant_init * taux_change - frais_change;
+	    {
+		if ( devise_operation &&
+		     devise_operation -> no_devise_en_rapport == no_devise_renvoi &&
+		     devise_operation -> change )
+		{
+		    if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+			montant = montant_init * devise_operation -> change - frais_change;
+		    else
+			montant = montant_init / devise_operation -> change - frais_change;
+		} 
+	    }
 
     montant = ( rint (montant * 100 )) / 100;
 
@@ -2109,7 +2215,7 @@ gchar * devise_name ( struct struct_devise * devise )
 
 
 /* renvoie le nom de la devise correspondante au no */
-/* ou null si pas trouve */
+/* ou null si pas trouvée */
 
 gchar * devise_name_by_no ( gint no_devise )
 {
