@@ -1,8 +1,8 @@
 /* ************************************************************************** */
-/* Fichier qui permet l'quilibrage des comptes                               */
+/* Fichier qui permet l'équilibrage des comptes                               */
 /* 			equilibrage.c                                         */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003 Benjamin Drieu (bdrieu@april.org)		      */
 /*			2004 Alain Portal (dionysos@grisbi.org) 	      */
 /*			http://www.grisbi.org   			      */
@@ -83,7 +83,7 @@ GtkWidget *creation_fenetre_equilibrage ( void )
     gtk_widget_show ( fenetre_equilibrage );
 
 
-    /* on met le nom du compte  quilibrer en haut */
+    /* on met le nom du compte à équilibrer en haut */
 
     label_equilibrage_compte = gtk_label_new ( "" );
     gtk_label_set_justify ( GTK_LABEL ( label_equilibrage_compte ),
@@ -105,11 +105,11 @@ GtkWidget *creation_fenetre_equilibrage ( void )
     gtk_widget_show ( separateur );
 
 
-    /* on cre le tooltips */
+    /* on crée le tooltips */
 
     tips = gtk_tooltips_new ();
 
-    /* sous le nom, on met le no de rapprochement, c'est une entre car il est modifiable */
+    /* sous le nom, on met le no de rapprochement, c'est une entrée car il est modifiable */
 
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( fenetre_equilibrage ),
@@ -150,8 +150,8 @@ GtkWidget *creation_fenetre_equilibrage ( void )
 			 0);
     gtk_widget_show ( separateur );
 
-    /* on met un premier tab en haut contenant dates et soldes des relevs
-       avec possibilit de modif du courant */
+    /* on met un premier tab en haut contenant dates et soldes des relevés
+       avec possibilité de modif du courant */
 
     table = gtk_table_new ( 3,
 			    5,
@@ -278,7 +278,7 @@ GtkWidget *creation_fenetre_equilibrage ( void )
     gtk_widget_show ( separateur );
 
 
-    /* la 2me table contient le solde init, final, du pointage et l'cart */
+    /* la 2ème table contient le solde init, final, du pointage et l'écart */
 
     table = gtk_table_new ( 5,
 			    2,
@@ -447,17 +447,17 @@ void equilibrage ( void )
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
-    /* efface le label proprits du compte */
+    /* efface le label propriétés du compte */
 
     gtk_widget_hide ( label_proprietes_operations_compte );
 
-    /* calcule le montant des oprations pointes */
+    /* calcule le montant des opérations pointées */
 
     calcule_total_pointe_compte ( compte_courant );
 
 
-    /* rcupre l'ancien no de rapprochement et essaie d'incrmenter la partie
-       numrique. Si ne russit pas, remet juste le nom de l'ancien */
+    /* récupère l'ancien no de rapprochement et essaie d'incrémenter la partie
+       numérique. Si ne réussit pas, remet juste le nom de l'ancien */
 
     if ( DERNIER_NO_RAPPROCHEMENT )
     {
@@ -477,7 +477,7 @@ void equilibrage ( void )
 	    rapprochement = liste_tmp -> data;
 
 
-	    /* on va crer une nouvelle chaine contenant la partie numrique */
+	    /* on va créer une nouvelle chaine contenant la partie numérique */
 
 	    new_rap = g_strdup ( rapprochement -> nom_rapprochement );
 	    pointeur_fin = new_rap + (strlen ( new_rap ) - 1) * sizeof (gchar);
@@ -488,7 +488,7 @@ void equilibrage ( void )
 
 	    if ( pointeur_mobile != pointeur_fin )
 	    {
-		/* la fin du no de rapprochement est numrique */
+		/* la fin du no de rapprochement est numérique */
 
 		gchar *rempl_zero;
 		gchar *partie_num;
@@ -502,12 +502,12 @@ void equilibrage ( void )
 
 		longueur = strlen ( partie_num );
 
-		/* on incrmente la partie numrique */
+		/* on incrémente la partie numérique */
 
 		partie_num = itoa ( my_atoi ( partie_num ) + 1 );
 
-		/* si la nouvelle partie numrique est plus petite que l'ancienne, */
-		/* c'est que des 0 ont t shunts, on va les rajouter ici */
+		/* si la nouvelle partie numérique est plus petite que l'ancienne, */
+		/* c'est que des 0 ont été shuntés, on va les rajouter ici */
 
 		nouvelle_longueur = strlen ( partie_num );
 
@@ -544,7 +544,7 @@ void equilibrage ( void )
 	gtk_entry_set_text ( GTK_ENTRY ( entree_no_rapprochement ),
 			     "" );
 
-    /* rcupre l'ancienne date et l'augmente d'1 mois et le met dans entree_nouvelle_date_equilibrage */
+    /* récupère l'ancienne date et l'augmente d'1 mois et le met dans entree_nouvelle_date_equilibrage */
 
     if ( DATE_DERNIER_RELEVE )
     {
@@ -607,14 +607,14 @@ void equilibrage ( void )
 				   TRUE );
 
 
-    /* affiche la liste en op simplifies */
+    /* affiche la liste en opé simplifiées */
 
     ancien_nb_lignes_ope = NB_LIGNES_OPE;
 
     if ( NB_LIGNES_OPE != 1 )
 	gtk_button_clicked ( GTK_BUTTON ( bouton_ope_1_lignes ));
 
-    /* on vire les oprations rapproches */
+    /* on vire les opérations rapprochées */
 
     etat.valeur_r_avant_rapprochement = AFFICHAGE_R;
 
@@ -622,7 +622,7 @@ void equilibrage ( void )
 			  3 );
 
 
-    /* classe la liste des ops en fonction des types ou non */
+    /* classe la liste des opés en fonction des types ou non */
 
     if ( TRI && LISTE_TRI )
 	LISTE_OPERATIONS = g_slist_sort ( LISTE_OPERATIONS,
@@ -635,7 +635,7 @@ void equilibrage ( void )
 			    2 );
 
 
-    /* la liste des op prend le focus */
+    /* la liste des opé prend le focus */
 
     gtk_widget_grab_focus ( GTK_WIDGET ( CLIST_OPERATIONS ));
 }
@@ -644,7 +644,7 @@ void equilibrage ( void )
 /******************************************************************************/
 gboolean sortie_entree_date_equilibrage ( GtkWidget *entree )
 {
-    /* si l'entre contenant la date est vide, alors on met la date du jour */
+    /* si l'entrée contenant la date est vide, alors on met la date du jour */
 
     if ( strlen ( g_strstrip ( (gchar*) gtk_entry_get_text ( GTK_ENTRY ( entree )))) == 0  )
 	gtk_entry_set_text ( GTK_ENTRY ( entree ), gsb_today() );
@@ -692,7 +692,7 @@ gboolean modif_entree_solde_final_equilibrage ( void )
     gtk_label_set_text ( GTK_LABEL ( label_equilibrage_final ),
 			 (char *) gtk_entry_get_text ( GTK_ENTRY ( entree_nouveau_montant_equilibrage )) );
 
-    /*     s'il n'y a rien dans l'entre du montant de l'eq, on efface, l'cart */
+    /*     s'il n'y a rien dans l'entrée du montant de l'eq, on efface, l'écart */
 
     if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entree_nouveau_montant_equilibrage ))))
 	gtk_widget_show ( label_equilibrage_ecart );
@@ -724,7 +724,7 @@ gboolean modif_entree_solde_final_equilibrage ( void )
 /******************************************************************************/
 
 /******************************************************************************/
-/* on annule l'quilibrage */
+/* on annule l'équilibrage */
 /******************************************************************************/
 gboolean annuler_equilibrage ( GtkWidget *bouton_ann,
 			       gpointer data)
@@ -771,7 +771,7 @@ gboolean annuler_equilibrage ( GtkWidget *bouton_ann,
 /******************************************************************************/
 
 /******************************************************************************/
-/* fonction appele quand il y a un click dans la colonne des P, et si l'quilibrage */
+/* fonction appelée quand il y a un click dans la colonne des P, et si l'équilibrage */
 /* est en cours */
 /******************************************************************************/
 void pointe_equilibrage ( int p_ligne )
@@ -840,12 +840,12 @@ void pointe_equilibrage ( int p_ligne )
     }
 
 
-    /* si c'est une opration ventile, on recherche les oprations filles
-       pour leur mettre le mme pointage que la mre */
+    /* si c'est une opération ventilée, on recherche les opérations filles
+       pour leur mettre le même pointage que la mère */
 
     if ( operation -> operation_ventilee )
     {
-	/* p_tab est dj point sur le compte courant */
+	/* p_tab est déjà pointé sur le compte courant */
 
 	GSList *liste_tmp;
 
@@ -886,7 +886,7 @@ void pointe_equilibrage ( int p_ligne )
 				   FALSE );
     }
 
-    /* met le label du solde point */
+    /* met le label du solde pointé */
 
     gtk_label_set_text ( GTK_LABEL ( solde_label_pointe ),
 			 g_strdup_printf ( _("Checked balance: %4.2f %s"),
@@ -894,8 +894,8 @@ void pointe_equilibrage ( int p_ligne )
 					   devise_name_by_no ( DEVISE )));
 
     modification_fichier( TRUE );
-    /* ALAIN-FIXME : solution batarde me semble-t'il pour actualiser le solde point
-       sur la fentre d'accueil aprs que l'on ait point l'opration */
+    /* ALAIN-FIXME : solution batarde me semble-t'il pour actualiser le solde pointé
+       sur la fenêtre d'accueil après que l'on ait pointé l'opération */
 
     update_liste_comptes_accueil ();
 }
@@ -924,7 +924,7 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
 
-    /* rcupration de la date */
+    /* récupération de la date */
 
     text = (char *) gtk_entry_get_text ( GTK_ENTRY ( entree_nouvelle_date_equilibrage ) );
 
@@ -972,8 +972,8 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 					   date_releve_annee ));
 
 
-    /*   rcupration du no de rapprochement, */
-    /*     s'il n'existe pas,on le cre */
+    /*   récupération du no de rapprochement, */
+    /*     s'il n'existe pas,on le crée */
 
     if ( strlen ( g_strstrip ( (char *) gtk_entry_get_text ( GTK_ENTRY ( entree_no_rapprochement )))))
     {
@@ -989,7 +989,7 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 
 	if ( liste_tmp )
 	{
-	    /* le rapprochement existe dj */
+	    /* le rapprochement existe déjà */
 
 	    rapprochement = liste_tmp -> data;
 	    DERNIER_NO_RAPPROCHEMENT = rapprochement -> no_rapprochement;
@@ -1013,7 +1013,7 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 
 
 
-    /* met tous les P  R */
+    /* met tous les P à R */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
@@ -1036,7 +1036,7 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 
 
 
-    /* on raffiche la liste */
+    /* on réaffiche la liste */
 
     modification_fichier( TRUE );
 
@@ -1076,7 +1076,7 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 
     gtk_widget_show ( label_proprietes_operations_compte );
 
-    /*   on redonne le focus  la liste */
+    /*   on redonne le focus à la liste */
 
     gtk_widget_grab_focus ( GTK_WIDGET ( CLIST_OPERATIONS ) );
 
@@ -1104,7 +1104,7 @@ void calcule_total_pointe_compte ( gint no_compte )
 
 	operation = pointeur_liste_ope -> data;
 
-	/* on ne prend en compte l'op que si c'est pas une op de ventil */
+	/* on ne prend en compte l'opé que si c'est pas une opé de ventil */
 
 	if ( operation -> pointe == 1
 	     &&
@@ -1151,7 +1151,7 @@ gboolean clavier_equilibrage ( GtkWidget *widget,
 
     switch ( event -> keyval )
     {
-	case GDK_Return :		/* touches entre */
+	case GDK_Return :		/* touches entrée */
 	case GDK_KP_Enter :
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( widget ),
@@ -1225,12 +1225,14 @@ gboolean clavier_equilibrage ( GtkWidget *widget,
 void fill_reconciliation_tree ()
 {
     GtkTreeIter account_iter, payment_method_iter;
-    gint i;
+    GSList *pUserAccountsList = NULL;
 
-    p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
+    pUserAccountsList = g_slist_copy ( ordre_comptes );
 
-    for ( i=0 ; i<nb_comptes ; i++ )
+    do
     {
+	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( pUserAccountsList -> data );
+
 	GSList * liste_tmp;
 
 	gtk_tree_store_append (reconcile_model, &account_iter, NULL);
@@ -1307,9 +1309,9 @@ void fill_reconciliation_tree ()
 		gtk_tree_path_free ( treepath );
 	    }
 	}
-
-	p_tab_nom_de_compte_variable++;
     }
+    while ( (  pUserAccountsList = pUserAccountsList -> next ) );
+    g_slist_free ( pUserAccountsList );
 }
 
 
@@ -1561,7 +1563,7 @@ void reconcile_include_neutral_toggled ( GtkCellRendererToggle *cell,
     }
     else
     {
-	/* on efface tous les nombres ngatifs de la liste */
+	/* on efface tous les nombres négatifs de la liste */
 
 	liste_tmp = LISTE_TRI;
 
@@ -1609,7 +1611,7 @@ GtkWidget * tab_display_reconciliation ( void )
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			 TRUE, TRUE, 0 );
 
-    /* mise en place de la liste qui contient les types classs */
+    /* mise en place de la liste qui contient les types classés */
     scrolled_window = gtk_scrolled_window_new ( NULL, NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), scrolled_window,
 			 TRUE, TRUE, 0);
@@ -1684,7 +1686,7 @@ GtkWidget * tab_display_reconciliation ( void )
 
     fill_reconciliation_tree();
 
-    /* on place ici les flches sur le ct de la liste */
+    /* on place ici les flèches sur le côté de la liste */
     vbox_fleches_tri = gtk_vbutton_box_new ();
     gtk_box_pack_start ( GTK_BOX ( hbox ), vbox_fleches_tri,
 			 FALSE, FALSE, 0);
