@@ -1,7 +1,7 @@
-/*  Fichier qui s'occupe du calcul des tats */
+/*  Fichier qui s'occupe du calcul des états */
 /*      etats.c */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
 /* 			http://www.grisbi.org				      */
 
@@ -51,14 +51,14 @@ void affichage_etat ( struct struct_etat *etat,
 	affichage = &gtktable_affichage;
 
 
-    /*   selection des oprations */
-    /* on va mettre l'adresse des ops slectionnes dans une liste */
+    /*   selection des opérations */
+    /* on va mettre l'adresse des opés sélectionnées dans une liste */
 
     liste_opes_selectionnees = recupere_opes_etat ( etat );
 
 
-    /*    ce niveau, on a rcupr toutes les ops qui entreront dans */
-    /* l'tat ; reste plus qu' les classer et les afficher */
+    /*   à ce niveau, on a récupéré toutes les opés qui entreront dans */
+    /* l'état ; reste plus qu'à les classer et les afficher */
     /* on classe la liste et l'affiche en fonction du choix du type de classement */
 
     etat_affichage_output = affichage;
@@ -70,10 +70,10 @@ void affichage_etat ( struct struct_etat *etat,
 
 
 /*****************************************************************************************************/
-/* cette fontion prend en argument l'adr d'un tat, fait le tour de tous les comptes et */
-/* slectionne les oprations qui appartiennent  cet tat. elle renvoie une liste des */
-/* adr de ces oprations */
-/* elle est appele pour l'affichage d'un tat ou pour la rcupration des tiers d'un tat */
+/* cette fontion prend en argument l'adr d'un état, fait le tour de tous les comptes et */
+/* sélectionne les opérations qui appartiennent à cet état. elle renvoie une liste des */
+/* adr de ces opérations */
+/* elle est appelée pour l'affichage d'un état ou pour la récupération des tiers d'un état */
 /*****************************************************************************************************/
 
 GSList *recupere_opes_etat ( struct struct_etat *etat )
@@ -85,8 +85,8 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
     liste_operations_etat = NULL;
 
-    /* si on utilise l'exercice courant ou prcdent, on cherche ici */
-    /* le numro de l'exercice correspondant */
+    /* si on utilise l'exercice courant ou précédent, on cherche ici */
+    /* le numéro de l'exercice correspondant */
 
     no_exercice_recherche = 0;
 
@@ -127,7 +127,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 	}
 
 
-	/* si on veut l'exo prcdent, c'est ici */
+	/* si on veut l'exo précédent, c'est ici */
 
 	switch ( etat -> utilise_detail_exo )
 	{
@@ -139,7 +139,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		break;
 
 	    case 2:
-		/* on recherche l'exo prcdent */
+		/* on recherche l'exo précédent */
 
 		liste_tmp = liste_struct_exercices;
 
@@ -151,7 +151,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 		    if ( exo_courant )
 		    {
-			/* si l'exo est avant exo_courant et aprs exo_precedent, c'est le nouvel exo_precedent */
+			/* si l'exo est avant exo_courant et après exo_precedent, c'est le nouvel exo_precedent */
 
 			if ( g_date_compare ( exo -> date_fin,
 					      exo_courant -> date_debut ) <= 0 )
@@ -168,8 +168,8 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		    }
 		    else
 		    {
-			/* 		      il n'y a pas d'exo courant, donc si l'exo est en date infrieur  la date du jour, */
-			/* et aprs l'exo_precedent, c'est le nouvel exo prcdent */
+			/* 		      il n'y a pas d'exo courant, donc si l'exo est en date inférieur à la date du jour, */
+			/* et après l'exo_precedent, c'est le nouvel exo précédent */
 
 			if ( g_date_compare ( exo -> date_fin,
 					      date_jour ) <= 0 )
@@ -197,10 +197,10 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
     }
 
 
-    /*   si on a utilis "le plus grand" dans la recherche de texte, c'est ici qu'on recherche */
+    /*   si on a utilisé "le plus grand" dans la recherche de texte, c'est ici qu'on recherche */
     /*     les plus grands no de chq, de rappr et de pc dans les comptes choisis */
 
-    /* commence par rechercher si on a utilis "le plus grand" */
+    /* commence par rechercher si on a utilisé "le plus grand" */
 
     liste_tmp = etat -> liste_struct_comparaison_textes;
 
@@ -222,7 +222,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 	    for ( i=0 ; i<nb_comptes ; i++ )
 	    {
-		/* on commence par vrifier que le compte fait partie de l'tat */
+		/* on commence par vérifier que le compte fait partie de l'état */
 
 		p_tab_nom_de_compte_variable = p_tab_nom_de_compte + i;
 
@@ -233,7 +233,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		{
 		    GSList *pointeur_tmp;
 
-		    /* on fait le tour de la liste des ops en recherchant le plus grand ds les 3 variables */
+		    /* on fait le tour de la liste des opés en recherchant le plus grand ds les 3 variables */
 
 		    pointeur_tmp = LISTE_OPERATIONS;
 
@@ -243,9 +243,9 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 			operation = pointeur_tmp -> data;
 
-			/* commence par le cheque, il faut que le type op soit  incrmentation auto */
+			/* commence par le cheque, il faut que le type opé soit à incrémentation auto */
 			/* et le no le plus grand */
-			/* on ne recherche le type d'op que si l'op a un contenu du type et que celui ci */
+			/* on ne recherche le type d'opé que si l'opé a un contenu du type et que celui ci */
 			/* est > que dernier_chq */
 
 			if ( operation -> contenu_type 
@@ -267,7 +267,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			}
 
 
-			/* on rcupre maintenant la plus grande pc */
+			/* on récupère maintenant la plus grande pc */
 
 			if ( operation -> no_piece_comptable
 			     &&
@@ -275,7 +275,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    dernier_pc = my_atoi ( operation -> no_piece_comptable );
 
 
-			/* on rcupre maintenant le dernier relev */
+			/* on récupère maintenant le dernier relevé */
 
 			if ( operation -> no_rapprochement > dernier_no_rappr )
 			    dernier_no_rappr = operation -> no_rapprochement;
@@ -293,7 +293,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
     for ( i=0 ; i<nb_comptes ; i++ )
     {
-	/* on commence par vrifier que le compte fait partie de l'tat */
+	/* on commence par vérifier que le compte fait partie de l'état */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + i;
 
@@ -302,10 +302,10 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 	     g_slist_index ( etat -> no_comptes,
 			     GINT_TO_POINTER ( i )) != -1 )
 	{
-	    /* 	  le compte est bon, passe  la suite de la slection */
+	    /* 	  le compte est bon, passe à la suite de la sélection */
 
 
-	    /* on va faire le tour de toutes les ops du compte */
+	    /* on va faire le tour de toutes les opés du compte */
 
 	    GSList *pointeur_tmp;
 
@@ -317,7 +317,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 		operation = pointeur_tmp -> data;
 
-		/* si c'est une op ventile, dpend de la conf */
+		/* si c'est une opé ventilée, dépend de la conf */
 
 		if ( operation -> operation_ventilee
 		     &&
@@ -329,7 +329,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		     etat -> pas_detailler_ventilation )
 		    goto operation_refusee;
 
-		/* on vrifie ensuite si un texte est recherch */
+		/* on vérifie ensuite si un texte est recherché */
 
 		if ( etat -> utilise_texte )
 		{
@@ -347,13 +347,13 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			comp_textes = liste_tmp -> data;
 
 
-			/* on commence par rcuprer le texte du champs recherch */
+			/* on commence par récupérer le texte du champs recherché */
 
 			texte = recupere_texte_test_etat ( operation,
 							   comp_textes -> champ );
 
-			/*  ce niveau, texte est soit null, soit contient le texte dans lequel on effectue la recherche */
-			/* on vrifie maintenant en fontion de l'oprateur */
+			/* à ce niveau, texte est soit null, soit contient le texte dans lequel on effectue la recherche */
+			/* on vérifie maintenant en fontion de l'opérateur */
 			/* si c'est un chq ou une pc et que utilise_txt, on utilise leur no */
 
 			if ( ( comp_textes -> champ == 8
@@ -374,13 +374,13 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    ope_dans_test = verifie_texte_test_etat ( comp_textes,
 								      texte );
 
-			/*  ce niveau, ope_dans_test=1 si l'op a pass ce test */
-			/* il faut qu'on fasse le lien avec la ligne prcdente */
+			/* à ce niveau, ope_dans_test=1 si l'opé a passé ce test */
+			/* il faut qu'on fasse le lien avec la ligne précédente */
 
 			switch ( comp_textes -> lien_struct_precedente )
 			{
 			    case -1:
-				/* 1re ligne  */
+				/* 1ère ligne  */
 
 				garde_ope = ope_dans_test;
 				break;
@@ -406,14 +406,14 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			liste_tmp = liste_tmp -> next;
 		    }
 
-		    /* on ne garde l'opration que si garde_ope = 1 */
+		    /* on ne garde l'opération que si garde_ope = 1 */
 
 		    if ( !garde_ope )
 			goto operation_refusee;
 		}
 
 
-		/* on vrifie les R */
+		/* on vérifie les R */
 
 		if ( etat -> afficher_r )
 		{
@@ -428,7 +428,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		}
 
 
-		/*    vrification du montant nul */
+		/*    vérification du montant nul */
 
 		if ( etat -> exclure_montants_nuls
 		     &&
@@ -436,7 +436,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		    goto operation_refusee;
 
 
-		/* vrification des montants */
+		/* vérification des montants */
 
 		if ( etat -> utilise_montant )
 		{
@@ -462,7 +462,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 								  operation -> taux_change,
 								  operation -> frais_change );
 
-			/* on vrifie maintenant en fonction de la ligne de test si on garde cette op */
+			/* on vérifie maintenant en fonction de la ligne de test si on garde cette opé */
 
 			ope_dans_premier_test = compare_montants_etat ( montant,
 									comp_montants -> montant_1,
@@ -473,7 +473,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 									   comp_montants -> montant_2,
 									   comp_montants -> comparateur_2 );
 			else
-			    /* pour viter les warning lors de la compil */
+			    /* pour éviter les warning lors de la compil */
 			    ope_dans_second_test = 0;
 
 			switch ( comp_montants -> lien_1_2 )
@@ -505,14 +505,14 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 				ope_dans_test = 0;
 			}
 
-			/*  ce niveau, ope_dans_test=1 si l'op a pass ce test */
-			/* il faut qu'on fasse le lien avec la ligne prcdente */
+			/* à ce niveau, ope_dans_test=1 si l'opé a passé ce test */
+			/* il faut qu'on fasse le lien avec la ligne précédente */
 
 
 			switch ( comp_montants -> lien_struct_precedente )
 			{
 			    case -1:
-				/* 1re ligne  */
+				/* 1ère ligne  */
 
 				garde_ope = ope_dans_test;
 				break;
@@ -538,7 +538,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			liste_tmp = liste_tmp -> next;
 		    }
 
-		    /* on ne garde l'opration que si garde_ope = 1 */
+		    /* on ne garde l'opération que si garde_ope = 1 */
 
 		    if ( !garde_ope )
 			goto operation_refusee;
@@ -547,7 +547,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 
 
-		/* 	      on vrifie les virements */
+		/* 	      on vérifie les virements */
 
 		if ( operation -> relation_no_operation )
 		{
@@ -556,7 +556,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 		    if ( etat -> type_virement == 1 )
 		    {
-			/* on inclue l'op que si le compte de virement */
+			/* on inclue l'opé que si le compte de virement */
 			/* est un compte de passif ou d'actif */
 
 			p_tab_nom_de_compte_variable = p_tab_nom_de_compte + operation -> relation_no_compte;
@@ -572,10 +572,10 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		    {
 			if ( etat -> type_virement == 2 )
 			{
-			    /* on inclut l'op que si le compte de virement n'est */
-			    /* pas prsent dans l'tat */
+			    /* on inclut l'opé que si le compte de virement n'est */
+			    /* pas présent dans l'état */
 
-			    /*    si on ne dtaille pas les comptes, on ne cherche pas, l'op est refuse */
+			    /*    si on ne détaille pas les comptes, on ne cherche pas, l'opé est refusée */
 			    if ( etat -> utilise_detail_comptes )
 			    {
 				if ( g_slist_index ( etat -> no_comptes,
@@ -587,7 +587,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			}
 			else
 			{
-			    /* on inclut l'op que si le compte de virement est dans la liste */
+			    /* on inclut l'opé que si le compte de virement est dans la liste */
 
 			    if ( g_slist_index ( etat -> no_comptes_virements,
 						 GINT_TO_POINTER ( operation -> relation_no_compte )) == -1 )
@@ -598,7 +598,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		}
 		else
 		{
-		    /* 		  l'op n'est pas un virement, si on doit exclure les non virement, c'est ici */
+		    /* 		  l'opé n'est pas un virement, si on doit exclure les non virement, c'est ici */
 
 		    if ( etat -> type_virement
 			 &&
@@ -607,8 +607,8 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		}
 
 
-		/* on va maintenant vrifier que les catg sont bonnes */
-		/* si on exclut les ops sans categ, on vrifie que c'est pas un virement ni une ventilation */
+		/* on va maintenant vérifier que les catég sont bonnes */
+		/* si on exclut les opés sans categ, on vérifie que c'est pas un virement ni une ventilation */
 
 		if ((( etat -> utilise_detail_categ
 		       &&
@@ -625,7 +625,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		    goto operation_refusee;
 
 
-		/* vrification de l'imputation budgtaire */
+		/* vérification de l'imputation budgétaire */
 
 		if ( etat -> exclure_ope_sans_ib && !operation -> imputation )
 		    goto operation_refusee;
@@ -637,7 +637,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 		    goto operation_refusee;
 
 
-		/* vrification du tiers */
+		/* vérification du tiers */
 
 		if ( etat -> utilise_detail_tiers
 		     &&
@@ -645,14 +645,16 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 				     GINT_TO_POINTER ( operation -> tiers )) == -1 )
 		    goto operation_refusee;
 
-		/* vrification du type d'op */
+		/* vérification du type d'opé */
 
-		if ( etat -> utilise_mode_paiement &&
-		     operation -> type_ope)
+		if ( etat -> utilise_mode_paiement )
 		{
 		    struct struct_type_ope *type_ope;
 		    GSList *liste_tmp;
 
+		    if ( ! operation -> type_ope )
+			goto operation_refusee;
+
 		    /* normalement p_tab... est sur le compte en cours */
 
 		    liste_tmp = g_slist_find_custom ( TYPES_OPES,
@@ -670,7 +672,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			goto operation_refusee;
 		}
 
-		/* vrifie la plage de date */
+		/* vérifie la plage de date */
 
 		if ( etat -> exo_date )
 		{
@@ -727,7 +729,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    break;
 
 			case 2:
-			    /* cumul  ce jour */
+			    /* cumul à ce jour */
 
 			    if ( g_date_compare ( date_jour,
 						  operation -> date ) < 0 )
@@ -744,7 +746,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    break;
 
 			case 4:
-			    /* anne en cours */
+			    /* année en cours */
 
 			    if ( g_date_year ( date_jour ) != g_date_year ( operation -> date ))
 				goto operation_refusee;
@@ -773,7 +775,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    break;
 
 			case 7:
-			    /* mois prcdent */
+			    /* mois précédent */
 
 			    g_date_subtract_months ( date_jour,
 						     1 );
@@ -785,7 +787,7 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 			    break;
 
 			case 8:
-			    /* anne prcdente */
+			    /* année précédente */
 
 			    g_date_subtract_years ( date_jour,
 						    1 );
@@ -877,7 +879,7 @@ operation_refusee:
 
 
 /*****************************************************************************************************/
-/* rcupre le texte pour faire le test sur les textes */
+/* récupère le texte pour faire le test sur les textes */
 /*****************************************************************************************************/
 
 gchar *recupere_texte_test_etat ( struct structure_operation *operation,
@@ -1056,7 +1058,7 @@ gchar *recupere_texte_test_etat ( struct structure_operation *operation,
 
 
 /*****************************************************************************************************/
-/* vrifie si l'op passe le test du texte */
+/* vérifie si l'opé passe le test du texte */
 /*****************************************************************************************************/
 
 gint verifie_texte_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
@@ -1152,7 +1154,7 @@ gint verifie_texte_test_etat ( struct struct_comparaison_textes_etat *comp_texte
 
 
 /*****************************************************************************************************/
-/* vrifie si l'op passe le test du chq */
+/* vérifie si l'opé passe le test du chq */
 /*****************************************************************************************************/
 
 gint verifie_chq_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
@@ -1162,12 +1164,12 @@ gint verifie_chq_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
     gint ope_dans_premier_test;
     gint ope_dans_second_test;
 
-    /* pour viter les warnings lors de la compil */
+    /* pour éviter les warnings lors de la compil */
 
     ope_dans_premier_test = 0;
     ope_dans_second_test = 0;
 
-    /*   si on cherche le plus grand, on met la valeur recherche  la place de montant_1 */
+    /*   si on cherche le plus grand, on met la valeur recherchée à la place de montant_1 */
 
     if ( comp_textes -> comparateur_1 != 6 )
 	ope_dans_premier_test = compare_cheques_etat ( my_atoi ( no_chq ),
@@ -1197,7 +1199,7 @@ gint verifie_chq_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
 
 	    case 10:
 		/* rappr */
-		/* no_chq contient le nom du rapprochement de l'op, or pour le plus grand, on cherche */
+		/* no_chq contient le nom du rapprochement de l'opé, or pour le plus grand, on cherche */
 		/* le no du rapprochement, on le cherche ici */
 
 		rapprochement = g_slist_find_custom ( liste_no_rapprochements,
@@ -1250,7 +1252,7 @@ gint verifie_chq_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
 	}
     }
     else
-	/* pour viter les warning lors de la compil */
+	/* pour éviter les warning lors de la compil */
 	ope_dans_second_test = 0;
 
     switch ( comp_textes -> lien_1_2 )
@@ -1290,8 +1292,8 @@ gint verifie_chq_test_etat ( struct struct_comparaison_textes_etat *comp_textes,
 
 
 /*****************************************************************************************************/
-/* compare les 2 no de chq en fonction du comparateur donn en argument */
-/* renvoie 1 si l'op passe le test, 0 sinon */
+/* compare les 2 no de chq en fonction du comparateur donné en argument */
+/* renvoie 1 si l'opé passe le test, 0 sinon */
 /*****************************************************************************************************/
 
 gint compare_cheques_etat ( gint chq_ope,
@@ -1363,8 +1365,8 @@ gint compare_cheques_etat ( gint chq_ope,
 
 
 /*****************************************************************************************************/
-/* compare les 2 montants en fonction du comparateur donn en argument */
-/* renvoie 1 si l'op passe le test, 0 sinon */
+/* compare les 2 montants en fonction du comparateur donné en argument */
+/* renvoie 1 si l'opé passe le test, 0 sinon */
 /*****************************************************************************************************/
 
 gint compare_montants_etat ( gdouble montant_ope,
@@ -1447,7 +1449,7 @@ gint compare_montants_etat ( gdouble montant_ope,
 	    break;
 
 	case 9:
-	    /* ngatif  */
+	    /* négatif  */
 
 	    if ( montant_ope_int < 0 )
 		retour = 1;
@@ -1464,7 +1466,7 @@ gint compare_montants_etat ( gdouble montant_ope,
 
 
 /*****************************************************************************************************/
-/* Fonction de rafraichissement de l'tat */
+/* Fonction de rafraichissement de l'état */
 /*****************************************************************************************************/
 void rafraichissement_etat ( struct struct_etat *etat )
 {
@@ -1473,7 +1475,7 @@ void rafraichissement_etat ( struct struct_etat *etat )
 
 
 /*****************************************************************************************************/
-/* Fonction d'impression de l'tat */
+/* Fonction d'impression de l'état */
 /*****************************************************************************************************/
 void impression_etat ( struct struct_etat *etat )
 {
@@ -1524,8 +1526,8 @@ gint classement_liste_opes_etat ( struct structure_operation *operation_1,
 
 classement_suivant:
 
-    /*   si pointeur est nul, on a fait le tour du classement, les ops sont identiques */
-    /* si elles sont affiches, on classe classement demand puis par no d'op si identiques */
+    /*   si pointeur est nul, on a fait le tour du classement, les opés sont identiques */
+    /* si elles sont affichées, on classe classement demandé puis par no d'opé si identiques */
     /* sinon on repart en mettant -1 */
 
     if ( !pointeur )
@@ -1536,7 +1538,7 @@ classement_suivant:
 
     switch ( GPOINTER_TO_INT ( pointeur -> data ))
     {
-	/* classement des catgories */
+	/* classement des catégories */
 
 	case 1:
 
@@ -1545,9 +1547,9 @@ classement_suivant:
 		if ( operation_1 -> categorie != operation_2 -> categorie )
 		    return ( operation_1 -> categorie - operation_2 -> categorie );
 
-		/*     si  les catgories sont nulles, on doit dpartager entre virements, pas */
-		/* de categ ou op ventile */
-		/* on met en 1er les ops sans categ, ensuite les ventilations et enfin les virements */
+		/*     si  les catégories sont nulles, on doit départager entre virements, pas */
+		/* de categ ou opé ventilée */
+		/* on met en 1er les opés sans categ, ensuite les ventilations et enfin les virements */
 
 		if ( !operation_1 -> categorie )
 		{
@@ -1575,14 +1577,14 @@ classement_suivant:
 		}
 	    }
 
-	    /*       les catgories sont identiques, passe au classement suivant */
+	    /*       les catégories sont identiques, passe au classement suivant */
 
 	    pointeur = pointeur -> next;
 	    goto classement_suivant;
 
 	    break;
 
-	    /* classement des sous catgories */
+	    /* classement des sous catégories */
 
 	case 2:
 
@@ -1594,7 +1596,7 @@ classement_suivant:
 		    return ( operation_1 -> sous_categorie - operation_2 -> sous_categorie );
 	    }
 
-	    /*       les ss-catgories sont identiques, passe au classement suivant */
+	    /*       les ss-catégories sont identiques, passe au classement suivant */
 
 	    pointeur = pointeur -> next;
 	    goto classement_suivant;
@@ -1678,9 +1680,9 @@ classement_suivant:
 
 
 /*****************************************************************************************************/
-/* cette fonction est appele quand l'op a t class dans sa categ, ib, compte ou tiers */
-/* et qu'elle doit tre affiche ; on classe en fonction de la demande de la conf ( date, no, tiers ...) */
-/* si les 2 ops sont quivalentes  ce niveau, on classe par no d'op */
+/* cette fonction est appelée quand l'opé a été classé dans sa categ, ib, compte ou tiers */
+/* et qu'elle doit être affichée ; on classe en fonction de la demande de la conf ( date, no, tiers ...) */
+/* si les 2 opés sont équivalentes à ce niveau, on classe par no d'opé */
 /*****************************************************************************************************/
 
 gint classement_ope_perso_etat ( struct structure_operation *operation_1,
@@ -1698,7 +1700,7 @@ gint classement_ope_perso_etat ( struct structure_operation *operation_1,
 	    break;
 
 	case 1:
-	    /* no op  */
+	    /* no opé  */
 
 	    retour = operation_1 -> no_operation - operation_2 -> no_operation;
 	    break;
@@ -1826,7 +1828,7 @@ gint classement_ope_perso_etat ( struct structure_operation *operation_1,
 	    break;
 
 	case 5:
-	    /* note si une des 2 ops n'a pas de notes, elle va en 2me */
+	    /* note si une des 2 opés n'a pas de notes, elle va en 2ème */
 
 	    if ( operation_1 -> notes
 		 &&
@@ -1846,8 +1848,8 @@ gint classement_ope_perso_etat ( struct structure_operation *operation_1,
 		retour = operation_2 -> type_ope - operation_1 -> type_ope;
 	    else
 	    {
-		/* les ops peuvent provenir de 2 comptes diffrents, il faut donc trouver les 2 types dans les */
-		/* listes diffrentes */
+		/* les opés peuvent provenir de 2 comptes différents, il faut donc trouver les 2 types dans les */
+		/* listes différentes */
 
 		struct struct_type_ope *type_1;
 		struct struct_type_ope *type_2;
@@ -1966,7 +1968,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
     GList *pointeur_glist;
 
 
-    /*   soit on spare en revenus et dpenses, soit non */
+    /*   soit on sépare en revenus et dépenses, soit non */
 
     liste_ope_revenus = NULL;
     liste_ope_depenses = NULL;
@@ -1975,10 +1977,10 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 
     if ( etat_courant -> separer_revenus_depenses )
     {
-	/* on commence par sparer la liste revenus et de dpenses */
-	/*   si le classement racine est la catgorie, on spare par catgorie */
-	/* de revenu ou de dpense */
-	/* si c'est un autre, on spare par montant positif ou ngatif */
+	/* on commence par séparer la liste revenus et de dépenses */
+	/*   si le classement racine est la catégorie, on sépare par catégorie */
+	/* de revenu ou de dépense */
+	/* si c'est un autre, on sépare par montant positif ou négatif */
 
 	while ( pointeur_tmp )
 	{
@@ -1988,8 +1990,8 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 
 	    if ( GPOINTER_TO_INT ( pointeur_glist -> data ) == 1 )
 	    {
-		/* le classement racine est la catgorie */
-		/* s'il n'y a pas de catg, c'est un virement ou une ventilation */
+		/* le classement racine est la catégorie */
+		/* s'il n'y a pas de catég, c'est un virement ou une ventilation */
 		/*       dans ce cas, on classe en fonction du montant */
 
 		if ( operation -> categorie )
@@ -2019,7 +2021,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 	    }
 	    else
 	    {
-		/* le classement racine n'est pas la catg, on spare en fonction du montant */
+		/* le classement racine n'est pas la catég, on sépare en fonction du montant */
 
 		if ( operation -> montant < 0 )
 		    liste_ope_depenses = g_slist_append ( liste_ope_depenses,
@@ -2032,12 +2034,12 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 	}
     }
     else
-	/*     on ne veut pas sparer en revenus et dpenses, on garde juste la liste d'op telle quelle */
+	/*     on ne veut pas séparer en revenus et dépenses, on garde juste la liste d'opé telle quelle */
 
 	liste_ope_revenus = ope_selectionnees;
 
 
-    /* on va maintenant classer ces 2 listes dans l'ordre adquat */
+    /* on va maintenant classer ces 2 listes dans l'ordre adéquat */
 
     liste_ope_depenses = g_slist_sort ( liste_ope_depenses,
 					(GCompareFunc) classement_liste_opes_etat );
@@ -2045,17 +2047,17 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 				       (GCompareFunc) classement_liste_opes_etat );
 
 
-    /* calcul du dcalage pour chaque classement */
+    /* calcul du décalage pour chaque classement */
     /* c'est une chaine vide qu'on ajoute devant le nom du */
     /*   classement ( tiers, ib ...) */
 
-    /* on met 2 espaces par dcalage */
-    /*   normalement, pointeur_glist est dj positionn */
+    /* on met 2 espaces par décalage */
+    /*   normalement, pointeur_glist est déjà positionné */
 
     decalage_base = "";
 
-    /*   pour viter le warning lors de la compilation, on met */
-    /* toutes les var char  "" */
+    /*   pour éviter le warning lors de la compilation, on met */
+    /* toutes les var char à "" */
 
     decalage_categ = "";
     decalage_sous_categ = "";
@@ -2068,7 +2070,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
     {
 	switch ( GPOINTER_TO_INT ( pointeur_glist -> data ))
 	{
-	    /* dcalage de la catgorie */
+	    /* décalage de la catégorie */
 
 	    case 1:
 		if ( etat_courant -> utilise_categ )
@@ -2082,7 +2084,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 		}
 		break;
 
-		/* dcalage de la ss-catgorie */
+		/* décalage de la ss-catégorie */
 
 	    case 2:
 		if ( etat_courant -> utilise_categ
@@ -2098,7 +2100,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 		}
 		break;
 
-		/* dcalage de l'ib */
+		/* décalage de l'ib */
 
 	    case 3:
 		if ( etat_courant -> utilise_ib )
@@ -2112,7 +2114,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 		}
 		break;
 
-		/* dcalage de la ss-ib */
+		/* décalage de la ss-ib */
 
 	    case 4:
 		if ( etat_courant -> utilise_ib
@@ -2128,7 +2130,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 		}
 		break;
 
-		/* dcalage du compte */
+		/* décalage du compte */
 
 	    case 5:
 		if ( etat_courant -> regroupe_ope_par_compte )
@@ -2142,7 +2144,7 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 		}
 		break;
 
-		/* dcalage du tiers */
+		/* décalage du tiers */
 
 	    case 6:
 		if ( etat_courant -> utilise_tiers )
@@ -2168,9 +2170,9 @@ pas_decalage:
 
 
     /*   calcul du nb de colonnes : */
-    /* 1re pour les titres de structure */
-    /* la dernire pour les montants */
-    /* et entre les 2 pour l'affichage des ops -> variable */
+    /* 1ère pour les titres de structure */
+    /* la dernière pour les montants */
+    /* et entre les 2 pour l'affichage des opés -> variable */
 
     nb_colonnes = 0;
 
@@ -2189,7 +2191,7 @@ pas_decalage:
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_rappr_ope;
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_exo_ope;
 
-	/* on ajoute les sparations */
+	/* on ajoute les séparations */
 
 	nb_colonnes = 2 * nb_colonnes - 1;
     }
@@ -2208,7 +2210,7 @@ pas_decalage:
 	return;
 
 
-    /* on commence  remplir le tableau */
+    /* on commence à remplir le tableau */
 
     /* on met le titre */
 
@@ -2216,10 +2218,10 @@ pas_decalage:
     nb_ope_general_etat = 0;
     ligne = etat_affiche_affiche_titre ( 0 );
 
-    /* sparation */
+    /* séparation */
     ligne = etat_affiche_affiche_separateur (ligne);
 
-    /*   si ncessaire, on met les titres des colonnes */
+    /*   si nécessaire, on met les titres des colonnes */
 
     if ( etat_courant -> afficher_opes
 	 &&
@@ -2284,17 +2286,17 @@ pas_decalage:
 	debut_affichage_etat = 1;
 	devise_compte_en_cours_etat = NULL;
 
-	/* on met ici le pointeur sur les revenus ou sur les dpenses */
-	/* en vrifiant qu'il y en a */
+	/* on met ici le pointeur sur les revenus ou sur les dépenses */
+	/* en vérifiant qu'il y en a */
 
 	if ( i )
 	{
 	    /* c'est le second passage */
-	    /* on met le pointeur sur les dpenses */
+	    /* on met le pointeur sur les dépenses */
 
 	    if ( liste_ope_depenses )
 	    {
-		/* sparation */
+		/* séparation */
 		ligne = etat_affiche_affiche_separateur (ligne);
 		pointeur_tmp = liste_ope_depenses;
 
@@ -2307,11 +2309,11 @@ pas_decalage:
 	{
 	    /* c'est le premier passage */
 	    /* on met le pointeur sur les revenus */
-	    /* si on n'a pas demand de sparer les dbits et crdits, on ne met pas de titre */
+	    /* si on n'a pas demandé de séparer les débits et crédits, on ne met pas de titre */
 
 	    if ( etat_courant -> separer_revenus_depenses )
 	    {
-		/* on spare les revenus des dbits */
+		/* on sépare les revenus des débits */
 
 		if ( liste_ope_revenus )
 		{
@@ -2321,12 +2323,12 @@ pas_decalage:
 		}
 		else
 		{
-		    /* il n'y a pas de revenus, on saute directement aux dpenses */
+		    /* il n'y a pas de revenus, on saute directement aux dépenses */
 
 		    i++;
 		    pointeur_tmp = liste_ope_depenses;
 
-		    /* 	      s'il n'y a pas de dpenses non plus, on sort de la boucle */
+		    /* 	      s'il n'y a pas de dépenses non plus, on sort de la boucle */
 
 		    if ( !liste_ope_depenses )
 			continue;
@@ -2336,8 +2338,8 @@ pas_decalage:
 	    }
 	    else
 	    {
-		/* 	      on ne spare pas les dbits et les crdits, donc pas de titre, juste */
-		/* une vrification qu'il y a des oprations */
+		/* 	      on ne sépare pas les débits et les crédits, donc pas de titre, juste */
+		/* une vérification qu'il y a des opérations */
 
 		if ( liste_ope_revenus )
 		    pointeur_tmp = liste_ope_revenus;
@@ -2347,7 +2349,7 @@ pas_decalage:
 	}
 
 
-	/* on commence la boucle qui fait le tour de chaque op */
+	/* on commence la boucle qui fait le tour de chaque opé */
 
 	while ( pointeur_tmp )
 	{
@@ -2407,13 +2409,13 @@ pas_decalage:
 	    }
 
 
-	    /* on affiche si ncessaire le total de la priode */
+	    /* on affiche si nécessaire le total de la période */
 
 	    ligne = etat_affiche_affiche_total_periode ( operation,
 							 ligne,
 							 0 );
 
-	    /* on affiche si ncessaire le total de  l'exercice */
+	    /* on affiche si nécessaire le total de  l'exercice */
 
 	    ligne = etat_affiche_affiche_total_exercice ( operation,
 							 ligne,
@@ -2424,7 +2426,7 @@ pas_decalage:
 	    ligne = etat_affiche_affichage_ligne_ope ( operation,
 						       ligne );
 
-	    /* on ajoute les montants que pour ceux affichs */
+	    /* on ajoute les montants que pour ceux affichés */
 
 	    /* calcule le montant de la categ */
 
@@ -2548,10 +2550,10 @@ pas_decalage:
 		    montant = operation -> montant;
 		else
 		{
-		    /* ce n'est pas la devise du compte, si le compte passe  l'euro et que la devise est l'euro, */
+		    /* ce n'est pas la devise du compte, si le compte passe à l'euro et que la devise est l'euro, */
 		    /* utilise la conversion du compte, */
-		    /* si c'est une devise qui passe  l'euro et que la devise du compte est l'euro, utilise la conversion du compte */
-		    /* sinon utilise la conversion stocke dans l'op */
+		    /* si c'est une devise qui passe à l'euro et que la devise du compte est l'euro, utilise la conversion du compte */
+		    /* sinon utilise la conversion stockée dans l'opé */
 
 		    devise_operation = g_slist_find_custom ( liste_struct_devises,
 							     GINT_TO_POINTER ( operation -> devise ),
@@ -2685,15 +2687,15 @@ pas_decalage:
 	}
 
 
-	/*    la fin, on affiche les totaux des dernires lignes */
+	/*   à la fin, on affiche les totaux des dernières lignes */
 
-	/* on affiche le total de la priode en le forant */
+	/* on affiche le total de la période en le forçant */
 
 	ligne = etat_affiche_affiche_total_periode ( NULL,
 						     ligne,
 						     1 );
 
-	/* on affiche le total de l'exercice en le forant */
+	/* on affiche le total de l'exercice en le forçant */
 
 	ligne = etat_affiche_affiche_total_exercice ( NULL,
 						     ligne,
@@ -2734,7 +2736,7 @@ pas_decalage:
 	}
 
 	/* on affiche le total de la partie en cours */
-	/* si les revenus et dpenses ne sont pas mlangs */
+	/* si les revenus et dépenses ne sont pas mélangés */
 
 	if ( etat_courant -> separer_revenus_depenses )
 	    ligne = etat_affiche_affiche_total_partiel ( total_partie,
@@ -2743,7 +2745,7 @@ pas_decalage:
 
     }
 
-    /* on affiche maintenant le total gnral */
+    /* on affiche maintenant le total général */
 
     ligne = etat_affiche_affiche_total_general ( total_general,
 						 ligne );
@@ -2755,15 +2757,15 @@ pas_decalage:
 
 
 /*****************************************************************************************************/
-/* met tous les anciens_x_etat sous jaccents  l'origine  -1 */
+/* met tous les anciens_x_etat sous jaccents à l'origine à -1 */
 /*****************************************************************************************************/
 
 void denote_struct_sous_jaccentes ( gint origine )
 {
     GList *pointeur_glist;
 
-    /* on peut partir du bout de la liste pour revenir vers la structure demande */
-    /* gros vulgaire copier coller de la fonction prcdente */
+    /* on peut partir du bout de la liste pour revenir vers la structure demandée */
+    /* gros vulgaire copier coller de la fonction précédente */
 
     pointeur_glist = g_list_last ( etat_courant -> type_classement );
 
