@@ -20,3 +20,5 @@ void etape_finale_affichage_etat ( GSList *ope_selectionnees,
 void denote_struct_sous_jaccentes ( gint origine );
 void impression_etat ( struct struct_etat *etat );
 void impression_etat_courant ( );
+void export_etat_vers_html ( struct struct_etat *etat );
+void export_etat_courant_vers_html ( );
