@@ -1,4 +1,4 @@
-/*  Fichier qui s'occupe d'afficher les tats via une impression latex */
+/*  Fichier qui s'occupe d'afficher les états via une impression latex */
 /*      etats_latex.c */
 
 /*     Copyright (C)	2004 Benjamin Drieu (bdrieu@april.org)		      */
@@ -413,6 +413,14 @@ void latex_safe ( gchar * text )
 		    fprintf ( latex_out, "%c", *text );
 		break;
 
+	    case '':
+		if ( *(text+1) == '' && *(text+2) == '' )
+		{
+		    fprintf ( latex_out, "\\officialeuro" );
+		    text+=2;
+		}
+		break;		    
+		
 	    case '&':
 	    case '%':
 	    case '\\':
