@@ -1,7 +1,7 @@
 /* Ce fichier s'occupe de la gestion des exercices */
 /* exercice.c */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2003 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
 
@@ -172,7 +172,7 @@ GtkWidget *onglet_exercices ( void )
 	    ligne_insert = gtk_clist_append ( GTK_CLIST (clist_exercices_parametres),
 					      ligne );
 
-	    /* on associe  la ligne la struct de la exercice */
+	    /* on associe à la ligne la struct de la exercice */
 	    gtk_clist_set_row_data ( GTK_CLIST ( clist_exercices_parametres ),
 				     ligne_insert,
 				     exercice );
@@ -291,7 +291,7 @@ GtkWidget *onglet_exercices ( void )
 
 /* ***************************************************************************************************** */
 /* Fonction ajout_exercice */
-/* appele par le bouton ajouter de l'onglet exercices des paramtres */
+/* appelée par le bouton ajouter de l'onglet exercices des paramètres */
 /* ***************************************************************************************************** */
 
 void ajout_exercice ( GtkWidget *bouton,
@@ -301,11 +301,11 @@ void ajout_exercice ( GtkWidget *bouton,
     gchar *ligne[1];
     gint ligne_insert;
 
-    /* Enlve la slection de la liste ( ce qui nettoie les entres ) */
+    /* Enlève la sélection de la liste ( ce qui nettoie les entrées ) */
     gtk_clist_unselect_all ( GTK_CLIST ( clist ));
 
-    /* cre un nouvelle exercice au nom de "nouvel exercice" en mettant
-       tous les paramtres  0 et le no  -1 */
+    /* crée un nouvelle exercice au nom de "nouvel exercice" en mettant
+       tous les paramètres à 0 et le no à -1 */
     exercice = calloc ( 1, sizeof ( struct struct_exercice ));
     exercice -> no_exercice = -1;
     exercice -> nom_exercice = g_strdup ( _("New financial year") );
@@ -318,13 +318,13 @@ void ajout_exercice ( GtkWidget *bouton,
 
     ligne_insert = gtk_clist_append ( GTK_CLIST ( clist ), ligne );
 
-    /* on associe  la ligne la struct de la exercice */
+    /* on associe à la ligne la struct de la exercice */
     gtk_clist_set_row_data ( GTK_CLIST ( clist ), ligne_insert, exercice );
 
-    /* on slectionne le nouveau venu */
+    /* on sélectionne le nouveau venu */
     gtk_clist_select_row ( GTK_CLIST ( clist ), ligne_insert, 0 );
 
-    /* on slectionne le "nouvel exercice" et lui donne le focus */
+    /* on sélectionne le "nouvel exercice" et lui donne le focus */
     gtk_entry_select_region ( GTK_ENTRY ( nom_exercice ), 0, -1 );
     gtk_widget_grab_focus ( nom_exercice );
 
@@ -335,7 +335,7 @@ void ajout_exercice ( GtkWidget *bouton,
 
 /* **************************************************************************************************************************** */
 /* Fonction supprime_exercice */
-/* appele lorsqu'on clicke sur le bouton annuler dans les paramtres */
+/* appelée lorsqu'on clicke sur le bouton annuler dans les paramètres */
 /* **************************************************************************************************************************** */
 
 void supprime_exercice ( GtkWidget *bouton, GtkWidget *liste )
@@ -366,8 +366,9 @@ void supprime_exercice ( GtkWidget *bouton, GtkWidget *liste )
     gtk_clist_remove ( GTK_CLIST(liste), ligne_selection_exercice );
     liste_struct_exercices = g_slist_remove ( liste_struct_exercices,
 					      exercice );
-    nb_exercices--;
     free ( exercice );
+    nb_exercices--;
+
     if ( ligne_selection_exercice > 0 )
 	gtk_clist_select_row ( GTK_CLIST(liste), ligne_selection_exercice-1, 0 );
     else
@@ -438,7 +439,7 @@ void deselection_ligne_exercice ( GtkWidget *liste,
 
 /* ***************************************************************************************************** */
 /* Fonction applique_modif_exercice */
-/* appele par le bouton appliquer qui devient sensitif lorsqu'on modifie la exercice des paramtres */
+/* appelée par le bouton appliquer qui devient sensitif lorsqu'on modifie la exercice des paramètres */
 /* ***************************************************************************************************** */
 
 void applique_modif_exercice ( GtkWidget *liste )
@@ -522,10 +523,10 @@ void applique_modif_exercice ( GtkWidget *liste )
 
 //* ************************************************************************************************************ */
 /* Fonction creation_menu_exercices */
-/* cre un menu qui contient les noms des exercices associs  leur no et adr */
+/* crée un menu qui contient les noms des exercices associés à leur no et adr */
 /* et le renvoie */
-/* origine = 0 si a vient des oprations */
-/* origine = 1 si a vient de l'chancier ; dans ce cas on rajoute automatique */
+/* origine = 0 si ça vient des opérations */
+/* origine = 1 si ça vient de l'échéancier ; dans ce cas on rajoute automatique */
 /* ************************************************************************************************************ */
 
 GtkWidget *creation_menu_exercices ( gint origine )
@@ -538,7 +539,7 @@ GtkWidget *creation_menu_exercices ( gint origine )
     gtk_widget_show ( menu );
 
 
-    /* si a vient de l'chancier, le 1er est automatique */
+    /* si ça vient de l'échéancier, le 1er est automatique */
     /* on lui associe -2 */
 
     if ( origine )
@@ -570,7 +571,7 @@ GtkWidget *creation_menu_exercices ( gint origine )
     gtk_widget_show ( menu_item );
 
 
-    /* le second est non affich */
+    /* le second est non affiché */
     /* on lui associe -1 */
 
     menu_item = gtk_menu_item_new_with_label ( _("Not displayed") );
@@ -618,8 +619,8 @@ GtkWidget *creation_menu_exercices ( gint origine )
 
 /* ************************************************************************************************************** */
 /* Fonction cherche_no_menu_exercice */
-/*   argument : le numro de l'exercice demand */
-/* renvoie la place demande dans l'option menu du formulaire */
+/*   argument : le numéro de l'exercice demandé */
+/* renvoie la place demandée dans l'option menu du formulaire */
 /* pour mettre l'history */
 /* ************************************************************************************************************** */
 
@@ -641,12 +642,12 @@ gint cherche_no_menu_exercice ( gint no_demande,
 	trouve = GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( liste_tmp -> data ),
 							 "no_exercice" ));
 
-	/*       si trouve = no demand, c'est bon, on se barre */
+	/*       si trouve = no demandé, c'est bon, on se barre */
 
 	if ( trouve == no_demande )
 	    return ( i );
 
-	/*  si on est sur la position du non affich, on le sauve */
+	/*  si on est sur la position du non affiché, on le sauve */
 
 	if ( trouve == -1 )
 	    non_affiche = i;
@@ -655,7 +656,7 @@ gint cherche_no_menu_exercice ( gint no_demande,
 	liste_tmp = liste_tmp -> next;
     }
 
-    /*   l'exo n'est pas affich, on retourne la position de non affich */
+    /*   l'exo n'est pas affiché, on retourne la position de non affiché */
 
     return ( non_affiche );
 }
@@ -665,7 +666,7 @@ gint cherche_no_menu_exercice ( gint no_demande,
 /* ************************************************************************************************************** */
 /* fonction affiche_exercice_par_date */
 /* met automatiquement l'option menu de l'exercice par rapport */
-/*  la date dans le formulaire */
+/* à la date dans le formulaire */
 /* ************************************************************************************************************** */
 
 void affiche_exercice_par_date ( GtkWidget *entree_date,
@@ -727,7 +728,7 @@ void affiche_exercice_par_date ( GtkWidget *entree_date,
 	liste_tmp = liste_tmp -> next;
     }
 
-    /*       si rien trouv, met  aucun */
+    /*       si rien trouvé, met à aucun */
 
     if ( !trouve )
 	gtk_option_menu_set_history ( GTK_OPTION_MENU ( option_menu_exercice ),
@@ -739,7 +740,7 @@ void affiche_exercice_par_date ( GtkWidget *entree_date,
 
 /* ************************************************************************************************************** */
 /* fonction association_automatique */
-/* recherche les ops sans exercice, et les associe si possible avec un des exercice cr */
+/* recherche les opés sans exercice, et les associe si possible avec un des exercice créé */
 /* ************************************************************************************************************** */
 
 void association_automatique ( void )
@@ -823,7 +824,7 @@ void association_automatique ( void )
 
 /* ************************************************************************************************************** */
 /* fonction recherche_exo_correspondant */
-/* renvoie l'exercice correspondant la date donne en argument */
+/* renvoie l'exercice correspondant la date donnée en argument */
 /* si aucun ne correspond, on renvoie 0 */
 /* ************************************************************************************************************** */
 
@@ -849,7 +850,7 @@ gint recherche_exo_correspondant ( GDate *date )
 	liste_tmp = liste_tmp -> next;
     }
 
-    /*   on n'a pas trouv l'exo, on retourne 0 */
+    /*   on n'a pas trouvé l'exo, on retourne 0 */
 
     return ( 0 );
 
@@ -859,8 +860,8 @@ gint recherche_exo_correspondant ( GDate *date )
 
 
 /* ************************************************************************************************************** */
-/* renvoie le nom de l'exercice donn en argument */
-/* ou bien null si non trouv */
+/* renvoie le nom de l'exercice donné en argument */
+/* ou bien null si non trouvé */
 /* ************************************************************************************************************** */
 
 gchar *exercice_name_by_no ( gint no_exo )
