@@ -1,7 +1,7 @@
-/* ce fichier se charge de toutes les oprations relatives  la
-   configuration sauvegarde */
+/* ce fichier se charge de toutes les opérations relatives à la
+   configuration sauvegardée */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2004 Axel Rousseau (axel584@axel584.org) */
 /*			2004 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
@@ -75,7 +75,7 @@ void charge_configuration ( void )
 
     doc = utf8_xmlParseFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC, NULL ) );
 
-    /* vrifications d'usage */
+    /* vérifications d'usage */
     root = xmlDocGetRootElement(doc);
 
     if ( !root
@@ -297,7 +297,7 @@ void charge_configuration ( void )
 		if ( !strcmp ( node_affichage -> name, "Caracteristiques_par_compte" ) ) {
 		    etat.retient_affichage_par_compte = my_atoi( xmlNodeGetContent ( node_affichage));
 		}
-		// boucler pour avoir les tailles des diffrentes colonnes
+		// boucler pour avoir les tailles des différentes colonnes
 		if ( !strcmp ( node_affichage -> name, "taille_largeur_colonne" ) ) {
 		    //int numero_colonne;
 		    //int largeur_colonne;
@@ -385,7 +385,7 @@ void charge_configuration ( void )
 
 /******************************************************************************************************************/
 /* Fonction charge_configuration */
-/* appele  l'ouverture de grisbi, charge les prfrences */
+/* appelée à l'ouverture de grisbi, charge les préférences */
 /******************************************************************************************************************/
 
 void charge_configuration_ancien ( void )
@@ -396,7 +396,7 @@ void charge_configuration_ancien ( void )
 
     etat.fichier_animation_attente = g_strdup ( ANIM_PATH );
 
-    /* modif -> vire gnome, donc fait tout  la main */
+    /* modif -> vire gnome, donc fait tout à la main */
 
     fichier_conf = g_strconcat ( my_get_grisbirc_dir(),
 				 "/.gnome/Grisbi",
@@ -567,19 +567,19 @@ void raz_configuration ( void )
     largeur_window = 0;
     hauteur_window = 0;
 
-    etat.r_modifiable = 0;       /* on ne peux modifier les op releves */
+    etat.r_modifiable = 0;       /* on ne peux modifier les opé relevées */
     etat.dernier_fichier_auto = 1;   /*  on n'ouvre pas directement le dernier fichier */
     buffer_dernier_fichier = g_strdup ( "" );
     etat.sauvegarde_auto = 0;    /* on ne sauvegarde pas automatiquement */
-    etat.entree = 1;    /* la touche entree provoque l'enregistrement de l'opration */
-    decalage_echeance = 3;     /* nb de jours avant l'chance pour prvenir */
-    etat.formulaire_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 op */
-    etat.formulaire_echeancier_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 op */
+    etat.entree = 1;    /* la touche entree provoque l'enregistrement de l'opération */
+    decalage_echeance = 3;     /* nb de jours avant l'échéance pour prévenir */
+    etat.formulaire_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 opé */
+    etat.formulaire_echeancier_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 opé */
     etat.affichage_exercice_automatique = 1;        /* l'exercice est choisi en fonction de la date */
     fonte_liste = NULL;
-    etat.force_enregistrement = 0;     /* par dfaut, on ne force pas l'enregistrement */
-    etat.affiche_tous_les_types = 0;   /* par dfaut, on n'affiche ds le formulaire que les types du dbit ou crdit */
-    etat.classement_par_date = 1;  /* par dfaut, on tri la liste des ops par les dates */
+    etat.force_enregistrement = 0;     /* par défaut, on ne force pas l'enregistrement */
+    etat.affiche_tous_les_types = 0;   /* par défaut, on n'affiche ds le formulaire que les types du débit ou crédit */
+    etat.classement_par_date = 1;  /* par défaut, on tri la liste des opés par les dates */
     etat.affiche_boutons_valider_annuler = 1;
     etat.classement_par_date = 1;
     dernier_chemin_de_travail = g_strconcat ( my_get_gsb_file_default_dir(),
@@ -588,14 +588,14 @@ void raz_configuration ( void )
     nb_derniers_fichiers_ouverts = 0;
     nb_max_derniers_fichiers_ouverts = 3;
     tab_noms_derniers_fichiers_ouverts = NULL;
-    compression_fichier = 0;     /* pas de compression par dfaut */
+    compression_fichier = 0;     /* pas de compression par défaut */
     compression_backup = 0;
     etat.largeur_auto_colonnes = 1;
     etat.retient_affichage_par_compte = 0;
     etat.fichier_animation_attente = g_strdup ( ANIM_PATH );
 
-	/* Messages */
-	etat.display_message_lock_active = 0;
+    /* Messages */
+    etat.display_message_lock_active = 0;
     /* On Windows, the chmod feature does not work: FAT does not have right access permission notions , 
      * on NTFS it to complicated to implement => the feature is removed from the Windows version :
      * for that the corresponding parameter check box is not displayed and the paramater is forced to not display msg */
@@ -629,7 +629,7 @@ void raz_configuration ( void )
 
 /* ***************************************************************************************************** */
 /* Fonction sauve_configurationXML */
-/* Appele  chaque changement de configuration */
+/* Appelée à chaque changement de configuration */
 /* ***************************************************************************************************** */
 
 void sauve_configuration(void)
@@ -652,7 +652,7 @@ void sauve_configuration(void)
 
     doc->children = xmlNewDocNode ( doc,NULL, "Configuration",NULL );
 
-    /*   sauvegarde de la gomtrie */
+    /*   sauvegarde de la géométrie */
     if ( GTK_WIDGET ( window) -> window ) 
     {
 	gtk_window_get_size (GTK_WINDOW ( window ),
@@ -670,7 +670,7 @@ void sauve_configuration(void)
     xmlNewChild ( node,NULL, "Height",
 		  itoa(hauteur_window));
 
-    /* sauvegarde de l'onglet gnral */
+    /* sauvegarde de l'onglet général */
     node = xmlNewChild ( doc->children,NULL, "General",NULL );
     xmlNewChild ( node,NULL, "Modification_operations_rapprochees",
 		  itoa(etat.r_modifiable));
@@ -688,13 +688,13 @@ void sauve_configuration(void)
     xmlNewChild ( node,NULL, "Fonte_des_listes",fonte_liste);
     xmlNewChild ( node,NULL, "Animation_attente",etat.fichier_animation_attente);
 
-/*     on modifie la chaine si a contient &, il semblerait que la libxml n'apprcie pas... */
+/*     on modifie la chaine si ça contient &, il semblerait que la libxml n'apprécie pas... */
     
     xmlNewChild ( node,NULL, "Navigateur_web",my_strdelimit ( etat.browser_command,
 							      "&",
 							      "\\e" ));
 
-/*     on ne fait la sauvegarde que si les colonnes existent (compte non ferm) */
+/*     on ne fait la sauvegarde que si les colonnes existent (compte non fermé) */
 	
     if ( nb_comptes )
     {
@@ -731,7 +731,7 @@ void sauve_configuration(void)
 	xmlSetProp ( node_2, "No", itoa (i));
     }
 
-    /* sauvegarde de l'onglet chances */
+    /* sauvegarde de l'onglet échéances */
     node = xmlNewChild ( doc->children,NULL, "Echeances",NULL );
     xmlNewChild ( node,NULL, "Delai_rappel_echeances",
 		  itoa(decalage_echeance));
@@ -797,7 +797,7 @@ void sauve_configuration(void)
     resultat = utf8_xmlSaveFormatFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC,
 						 NULL), doc, 1 );
 
-    /* on libre la memoire */
+    /* on libère la memoire */
     xmlFreeDoc ( doc );
     if ( resultat == -1 ) 
     {
