@@ -1,8 +1,8 @@
 /* ************************************************************************** */
-/* Ce fichier comprend toutes les oprations concernant le traitement	      */
+/* Ce fichier comprend toutes les opérations concernant le traitement	      */
 /* des fichiers								      */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
@@ -71,18 +71,18 @@ void nouveau_fichier ( void )
 
     no_compte = initialisation_nouveau_compte ( type_de_compte );
 
-    /* si la cration s'est mal passe, on se barre */
+    /* si la création s'est mal passée, on se barre */
 
     if ( no_compte == -1 )
 	return;
 
     p_tab_nom_de_compte_courant = p_tab_nom_de_compte;
 
-    /* dgrise les menus ncessaire */
+    /* dégrise les menus nécessaire */
 
     init_variables ( TRUE );
 
-    /*   la taille des colonnes est automatique au dpart, on y met les rapports de base */
+    /*   la taille des colonnes est automatique au départ, on y met les rapports de base */
 
     etat.largeur_auto_colonnes = 1;
     rapport_largeur_colonnes[0] = 11;
@@ -94,13 +94,13 @@ void nouveau_fichier ( void )
     rapport_largeur_colonnes[6] = 11;
 
 
-    /* cration des listes d'origine */
+    /* création des listes d'origine */
 
     creation_devises_de_base();
     creation_liste_categories ();
     creation_liste_categ_combofix ();
 
-    /* on cre le notebook principal */
+    /* on crée le notebook principal */
 
     gtk_box_pack_start ( GTK_BOX ( window_vbox_principale),
 			 creation_fenetre_principale(),
@@ -108,7 +108,7 @@ void nouveau_fichier ( void )
 			 TRUE,
 			 0 );
 
-    /* remplit les listes des ops */
+    /* remplit les listes des opés */
 
     creation_listes_operations ();
 
@@ -119,7 +119,7 @@ void nouveau_fichier ( void )
 
     gtk_widget_show ( notebook_general );
 
-    /*     ncessaire pour viter un non affichage de l'acceuil dans certains cas */
+    /*     nécessaire pour éviter un non affichage de l'acceuil dans certains cas */
 
     while ( g_main_iteration (FALSE));
 
@@ -127,7 +127,7 @@ void nouveau_fichier ( void )
 
     changement_compte ( GINT_TO_POINTER ( compte_courant ) );
 
-    /* on se met sur l'onglet de proprits du compte */
+    /* on se met sur l'onglet de propriétés du compte */
 
     gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general ),
 			    3 );
@@ -185,8 +185,8 @@ void ouverture_fichier_par_menu ( gpointer null,
 void fichier_selectionne ( GtkWidget *selection_fichier)
 {
 
-    /*   on cache la fenetre de slection et ferme le fichier en cours */
-    /*     si lors de la fermeture, on a voulu enregistrer mais a n'a pas march => return */
+    /*   on cache la fenetre de sélection et ferme le fichier en cours */
+    /*     si lors de la fermeture, on a voulu enregistrer mais ça n'a pas marché => return */
 
     gtk_widget_hide ( selection_fichier );
 
@@ -207,7 +207,7 @@ void fichier_selectionne ( GtkWidget *selection_fichier)
 
     gtk_widget_hide ( selection_fichier );
 
-    /* on met le rpertoire courant dans la variable correspondante */
+    /* on met le répertoire courant dans la variable correspondante */
 
     dernier_chemin_de_travail = file_selection_get_last_directory( GTK_FILE_SELECTION (selection_fichier),TRUE);
 
@@ -220,7 +220,7 @@ void fichier_selectionne ( GtkWidget *selection_fichier)
 /* ************************************************************************************************************ */
 /* Fonction ouverture_confirmee */
 /* ouvre le fichier dont le nom est dans nom_fichier_comptes */
-/* ne se procuppe pas d'un ancien fichier ou d'une initialisation de variables */
+/* ne se préocuppe pas d'un ancien fichier ou d'une initialisation de variables */
 /* ************************************************************************************************************ */
 
 void ouverture_confirmee ( void )
@@ -228,14 +228,14 @@ void ouverture_confirmee ( void )
     gint i;
 
     mise_en_route_attente ( _("Load an accounts file") );
-    /*   si nb_comptes est diffrent de 0, c'est que l'on veut tout redessiner car on a chang la fonte */
-    /*  si charge oprations renvoie FALSE, c'est qu'il y a eu un pb et un message est dj affich */
+    /*   si nb_comptes est différent de 0, c'est que l'on veut tout redessiner car on a changé la fonte */
+    /*  si charge opérations renvoie FALSE, c'est qu'il y a eu un pb et un message est déjà affiché */
 
     if ( !nb_comptes )
     {
 	if ( !charge_operations () )
 	{
-	    /* 	  le chargement du fichier a plant, si l'option sauvegarde  l'ouverture est active, on */
+	    /* 	  le chargement du fichier a planté, si l'option sauvegarde à l'ouverture est activée, on */
 	    /* propose de charger l'ancien fichier */
 
 	    annulation_attente ();
@@ -246,7 +246,7 @@ void ouverture_confirmee ( void )
 		gint result;
 		gchar **parametres;
 
-		/* on cre le nom de la sauvegarde */
+		/* on crée le nom de la sauvegarde */
 
 		nom = nom_fichier_comptes;
 		i=0;
@@ -272,13 +272,13 @@ void ouverture_confirmee ( void )
 
 		if ( charge_operations () )
 		{
-		    /* on a russi a charger la sauvegarde */
+		    /* on a réussi a charger la sauvegarde */
 		    dialogue ( _("Grisbi was unable to load file.  However, Grisbi loaded a backup file instead.\nHowever, all changes made since this backup were possibly lost."));
 		    nom_fichier_comptes = nom;
 		}
 		else
 		{
-		    /* le chargement de la sauvegarde a chou */
+		    /* le chargement de la sauvegarde a échoué */
 
 		    nom_fichier_comptes = nom;
 		    annulation_attente ();
@@ -294,7 +294,7 @@ void ouverture_confirmee ( void )
 	}
 	else
 	{
-	    /* 	si on veut faire une sauvegarde auto  chaque ouverture, c'est ici */
+	    /* 	si on veut faire une sauvegarde auto à chaque ouverture, c'est ici */
 
 	    if ( etat.sauvegarde_demarrage )
 	    {
@@ -306,7 +306,7 @@ void ouverture_confirmee ( void )
 
 		i=0;
 
-		/* 	      on rcupre uniquement le nom du fichier, pas le chemin */
+		/* 	      on récupère uniquement le nom du fichier, pas le chemin */
 
 		parametres = g_strsplit ( nom_fichier_comptes,
 					  C_DIRECTORY_SEPARATOR,
@@ -351,13 +351,13 @@ void ouverture_confirmee ( void )
 
     affiche_titre_fenetre();
 
-    /* dgrise les menus ncessaire */
+    /* dégrise les menus nécessaire */
 
     init_variables ( TRUE );
 
-    /*     on met  jour les valeurs affichage_mini */
-    /* 	si  ce niveau les soldes sont dj < au mini, c'est que le dialogue a dj */
-    /* 	t affich */
+    /*     on met à jour les valeurs affichage_mini */
+    /* 	si à ce niveau les soldes sont déjà < au mini, c'est que le dialogue a déjà */
+    /* 	été affiché */
 
     for ( i=0 ; i<nb_comptes ; i++ )
     {
@@ -367,11 +367,11 @@ void ouverture_confirmee ( void )
 	MESSAGE_SOUS_MINI_VOULU = SOLDE_COURANT < SOLDE_MINI_VOULU;
     }
 
-    /* on cre le notebook principal */
+    /* on crée le notebook principal */
 
     creation_fenetre_principale();
 
-    /* remplit les listes des ops */
+    /* remplit les listes des opés */
 
     creation_listes_operations ();
 
@@ -380,9 +380,9 @@ void ouverture_confirmee ( void )
     gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general ),
 			    0 );
 
-    /* remplit les chances  l'accueil */
+    /* remplit les échéances à l'accueil */
 
-    /* on initialise les variables echeances_a_saisir et echeances_saisies utilises dans l'accueil */
+    /* on initialise les variables echeances_a_saisir et echeances_saisies utilisées dans l'accueil */
 
     echeances_saisies = NULL;
 
@@ -406,11 +406,11 @@ void ouverture_confirmee ( void )
 
 
 /* ************************************************************************************************************ */
-/* Fonction appel lorsqu'on veut enregistrer le fichier ( fin de prog, fermeture fichier ... ) */
+/* Fonction appelé lorsqu'on veut enregistrer le fichier ( fin de prog, fermeture fichier ... ) */
 /* enregistre automatiquement ou demande */
 /* si origine = -1 : provient de la fonction fermeture_grisbi */
 /* si origine = -2 : provient de enregistrer sous */
-/* retour : TRUE si tout va bien, cad on ne veut pas enregistrer ou c'est enregistr */
+/* retour : TRUE si tout va bien, cad on ne veut pas enregistrer ou c'est enregistré */
 /* ************************************************************************************************************ */
 
 gboolean enregistrement_fichier ( gint origine )
@@ -489,7 +489,7 @@ gboolean enregistrement_fichier ( gint origine )
 
 		gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
-		/* vrification que c'est possible */
+		/* vérification que c'est possible */
 
 		if ( !strlen ( nom_fichier_comptes ))
 		{
@@ -553,7 +553,7 @@ gboolean enregistrement_fichier ( gint origine )
 	etat.force_enregistrement = etat_force;
     }
 
-    /*   on marque l'ancien fichier comme ferm s'il tait ferm  l'ouverture */
+    /*   on marque l'ancien fichier comme fermé s'il était fermé à l'ouverture */
 
     if ( result
 	 &&
@@ -570,7 +570,7 @@ gboolean enregistrement_fichier ( gint origine )
 	nom_fichier_comptes = nom_tmp;
     }
 
-    /*     si on a enregistr le fichier le fichier courant, celui ci peut tre considr comme ferm  l'ouverture maintenant */
+    /*     si on a enregistré le fichier le fichier courant, celui ci peut être considéré comme fermé à l'ouverture maintenant */
 
     if ( result )
     {
@@ -607,13 +607,13 @@ gboolean fermer_fichier ( void )
 
     sauve_configuration ();
 
-    /* si l'enregistrement s'est mal pass, on se barre */
+    /* si l'enregistrement s'est mal passé, on se barre */
 
     if ( !enregistrement_fichier (-1) )
 	return ( FALSE );
 
 
-    /* si le fichier n'tait pas dj ouvert, met  0 l'ouverture */
+    /* si le fichier n'était pas déjà ouvert, met à 0 l'ouverture */
 
     if ( !etat.fichier_deja_ouvert
 	 &&
@@ -632,7 +632,7 @@ gboolean fermer_fichier ( void )
 
 
 
-    /* libre les oprations de tous les comptes */
+    /* libère les opérations de tous les comptes */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -648,7 +648,7 @@ gboolean fermer_fichier ( void )
 
     free ( p_tab_nom_de_compte );
 
-    /* libre les chances */
+    /* libère les échéances */
 
     g_slist_free ( gsliste_echeances );
     g_slist_free ( echeances_a_saisir );
@@ -677,7 +677,7 @@ gboolean fermer_fichier ( void )
 
 
 /* ************************************************************************************************************ */
-/* Fonction appele une fois qu'on a nomm le fichier de compte */
+/* Fonction appelée une fois qu'on a nommé le fichier de compte */
 /* met juste le titre dans la fenetre principale */
 /* ************************************************************************************************************ */
 void affiche_titre_fenetre ( void )
@@ -719,7 +719,7 @@ void affiche_titre_fenetre ( void )
 
 /* ************************************************************************************************************ */
 /* Fonction enregistrement_backup */
-/* appele si necessaire au dbut de l'enregistrement */
+/* appelée si necessaire au début de l'enregistrement */
 /* ************************************************************************************************************ */
 
 gboolean enregistrement_backup ( void )
@@ -765,8 +765,8 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 
     /* ALAIN-FIXME */
     /* si on n'a pas un chemin absolu, on n'enregistre pas ce fichier
-       dans la liste. Du moins jusqu' ce que quelqu'un trouve un moyen
-       pour rcuprer le chemein absolu */
+       dans la liste. Du moins jusqu'à ce que quelqu'un trouve un moyen
+       pour récupérer le chemein absolu */
 
     if ( !g_path_is_absolute ( nom_fichier_comptes ) )
     {
@@ -781,7 +781,7 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 	return;
     }
 
-    /* on commence par vrifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts noms */
+    /* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts noms */
 
     position = 0;
 
@@ -789,7 +789,7 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 	if ( !strcmp ( path_fichier,
 		       tab_noms_derniers_fichiers_ouverts[i] ))
 	{
-	    /* 	si ce fichier est dj le dernier ouvert, on laisse tomber */
+	    /* 	si ce fichier est déjà le dernier ouvert, on laisse tomber */
 
 	    if ( !i )
 		return;
@@ -801,7 +801,7 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 
     if ( position )
     {
-	/*       le fichier a t trouv, on fait juste une rotation */
+	/*       le fichier a été trouvé, on fait juste une rotation */
 
 	for ( i=position ; i>0 ; i-- )
 	    tab_noms_derniers_fichiers_ouverts[i] = tab_noms_derniers_fichiers_ouverts[i-1];
@@ -815,9 +815,9 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 	return;
     }
 
-    /*   le fichier est nouveau, on dcale tout d'un cran et on met le nouveau  0 */
+    /*   le fichier est nouveau, on décale tout d'un cran et on met le nouveau à 0 */
 
-    /*   si on est dj au max, c'est juste un dcalage avec perte du dernier */
+    /*   si on est déjà au max, c'est juste un décalage avec perte du dernier */
     /* on garde le ptit dernier dans le cas contraire */
 
     if ( nb_derniers_fichiers_ouverts )
