@@ -59,6 +59,7 @@ GSList * make_split_list_from_xml_transaction_node ( xmlNodePtr, gdouble * );
 /*START_EXTERN*/
 extern GSList *liste_comptes_importes;
 extern gchar * tempname;
+extern gpointer ** p_tab_nom_de_compte;
 /*END_EXTERN*/
 
 /* Structures */
@@ -496,6 +497,8 @@ gdouble gnucash_value ( gchar * value )
   
   number = my_atoi ( tab_value[0] );
   mantisse = my_atoi ( tab_value[1] );
+  
+  g_strfreev ( tab_value );    
 
   return number / mantisse;
 }
@@ -663,10 +666,8 @@ struct struct_ope_importation * new_transaction_from_split ( struct gnucash_spli
       contra_transaction -> date = date;
       contra_transaction -> p_r = split -> p_r;
 
-      transaction -> categ = g_strconcat ( _("Transfer"), " : ",
-					   split -> contra_account, NULL);
-      contra_transaction -> categ = g_strconcat ( _("Transfer"), " : ",
-						  split -> account, NULL);
+      transaction -> categ = g_strconcat ( "[", split -> contra_account, "]", NULL );
+      contra_transaction -> categ = g_strconcat ( "[", split -> account, "]", NULL );
 
       contra_account = find_imported_account_by_name ( split -> contra_account );
       if ( contra_account )
