@@ -1,6 +1,6 @@
 /* ComboFix Widget
  *
- *     Copyright (C)	2001 Cdric Auger (cedric@grisbi.org) 
+ *     Copyright (C)	2001 Cédric Auger (cedric@grisbi.org) 
  *			2003 Benjamin Drieu (bdrieu@april.org) 
  * 			http://www.grisbi.org
  *
@@ -131,7 +131,7 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
     GtkWidget *vbox;
     GtkWidget *frame;
 
-    /*   cration de la vbox ( permet d'viter que le combofix s'agrandisse si on agrandit la fenetre )*/
+    /*   création de la vbox ( permet d'éviter que le combofix s'agrandisse si on agrandit la fenetre )*/
 
     vbox = gtk_vbox_new ( FALSE,
 			  0 );
@@ -142,7 +142,7 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
     gtk_widget_show ( vbox );
 
 
-    /*   cration de la hbox */
+    /*   création de la hbox */
 
     hbox = gtk_hbox_new ( FALSE,
 			  0 );
@@ -155,7 +155,7 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
     gtk_widget_show ( hbox );
 
 
-    /* cration de l'entre */
+    /* création de l'entrée */
 
     combofix->entry = gtk_entry_new();
 
@@ -190,7 +190,7 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
 			 0 );
     gtk_widget_show ( combofix->entry );
 
-    /*   cration de l'arrow */
+    /*   création de l'arrow */
 
     combofix -> arrow = gtk_button_new ();
     gtk_button_set_relief ( GTK_BUTTON ( combofix -> arrow ),
@@ -213,8 +213,8 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
     gtk_widget_show_all ( combofix->arrow);
 
 
-    /* cration du menu attach au widget */
-    /* on ne cre que pour l'instant la window popup et la boite qui contiendra la liste, une scrolledWindow */
+    /* création du menu attaché au widget */
+    /* on ne crée que pour l'instant la window popup et la boite qui contiendra la liste, une scrolledWindow */
 
     combofix->popup = gtk_window_new ( GTK_WINDOW_POPUP );
     gtk_window_set_policy ( GTK_WINDOW ( combofix->popup ),
@@ -240,7 +240,7 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
     combofix -> label_selectionne = -1;
 
 
-    /* pour l'instant, met la liste  0 */
+    /* pour l'instant, met la liste à 0 */
 
     combofix -> liste = NULL;
 
@@ -253,14 +253,14 @@ static void gtk_combofix_init ( GtkComboFix *combofix )
 /* **************************************************************************************************** */
 /* gtk_combofix_new : */
 /* arguments :             */
-/* liste :                      liste de noms ( \t en dbut de chaine pour une sous catgorie ) */
-/* force_text :            TRUE ( le texte doit correspondre  la liste ) / FALSE */
-/* affiche_liste :         TRUE ( la liste sera affiche en tapant le mot ) / FALSE */
-/* classement_auto : TRUE ( la liste est toujours classe par ordre alphabtique ) / FALSE  */
-/* lignes_max : contient le nb maximal de lignes affiches de la liste, si 0=les affiche toutes, */
-/* s'il est dpass, n'affiche rien */
+/* liste :                      liste de noms ( \t en début de chaine pour une sous catégorie ) */
+/* force_text :            TRUE ( le texte doit correspondre à la liste ) / FALSE */
+/* affiche_liste :         TRUE ( la liste sera affichée en tapant le mot ) / FALSE */
+/* classement_auto : TRUE ( la liste est toujours classée par ordre alphabétique ) / FALSE  */
+/* lignes_max : contient le nb maximal de lignes affichées de la liste, si 0=les affiche toutes, */
+/* s'il est dépassé, n'affiche rien */
 /*                                                                                                               */
-/* retour : le widget gtk_combofix ( une hbox contenant l'entre et d'une arrow ) */
+/* retour : le widget gtk_combofix ( une hbox contenant l'entrée et d'une arrow ) */
 /* **************************************************************************************************** */
 
 GtkWidget *gtk_combofix_new ( GSList *liste,
@@ -310,12 +310,12 @@ GtkWidget *gtk_combofix_new ( GSList *liste,
 			GTK_SHADOW_ETCHED_OUT);
 
 
-    /* cration de la liste des compltions : systme de catgories - sous catgories */
-    /* toutes catgorie est mise dans la liste */
-    /*   les sous-catg sont mises sous la forme catg : sous-catg */
-    /* on trie  la fin la liste par ordre alphabtique pour que lors d'une compltion, c'est le 1er qui sorte */
+    /* création de la liste des complétions : système de catégories - sous catégories */
+    /* toutes catégorie est mise dans la liste */
+    /*   les sous-catég sont mises sous la forme catég : sous-catég */
+    /* on trie à la fin la liste par ordre alphabétique pour que lors d'une complétion, c'est le 1er qui sorte */
 
-    /* protge de l'erreur si on met une sous categ en 1er */
+    /* protège de l'erreur si on met une sous categ en 1er */
 
     derniere_categ = "";
 
@@ -352,15 +352,15 @@ GtkWidget *gtk_combofix_new ( GSList *liste,
 /* **************************************************************************************************** */
 /* gtk_combofix_new_complex : */
 /* arguments :                             */
-/* liste :                      liste de liste de noms ( \t en dbut de chaine pour une sous catgorie ) */
-/*                               chaque liste sera spare d'une ligne */
-/* force_text :            TRUE ( le texte doit correspondre  la liste ) / FALSE */
-/* affiche_liste :         TRUE ( la liste sera affiche en tapant le mot ) / FALSE */
-/* classement_auto : TRUE ( la liste est toujours classe par ordre alphabtique ) / FALSE  */
-/* lignes_max : contient le nb maximal de lignes affiches de la liste, si 0=les affiche toutes, */
-/* s'il est dpass, n'affiche rien */
+/* liste :                      liste de liste de noms ( \t en début de chaine pour une sous catégorie ) */
+/*                               chaque liste sera séparée d'une ligne */
+/* force_text :            TRUE ( le texte doit correspondre à la liste ) / FALSE */
+/* affiche_liste :         TRUE ( la liste sera affichée en tapant le mot ) / FALSE */
+/* classement_auto : TRUE ( la liste est toujours classée par ordre alphabétique ) / FALSE  */
+/* lignes_max : contient le nb maximal de lignes affichées de la liste, si 0=les affiche toutes, */
+/* s'il est dépassé, n'affiche rien */
 /*                                                                                                                                    */
-/* retour : le widget gtk_combofix ( une hbox contenant l'entre et d'une arrow ) */
+/* retour : le widget gtk_combofix ( une hbox contenant l'entrée et d'une arrow ) */
 /* **************************************************************************************************** */
 
 GtkWidget *gtk_combofix_new_complex ( GSList *liste,
@@ -419,11 +419,11 @@ GtkWidget *gtk_combofix_new_complex ( GSList *liste,
 			GTK_ARROW_UP,
 			GTK_SHADOW_ETCHED_OUT);
 
-    /* cration de la liste des compltions : systme de catgories - sous catgories */
-    /* toutes catgorie est mise dans la liste */
-    /*   les sous-catg sont mises sous la forme catg : sous-catg */
+    /* création de la liste des complétions : système de catégories - sous catégories */
+    /* toutes catégorie est mise dans la liste */
+    /*   les sous-catég sont mises sous la forme catég : sous-catég */
 
-    /* protge de l'erreur si on met une sous categ en 1er */
+    /* protège de l'erreur si on met une sous categ en 1er */
 
     derniere_categ = "";
 
@@ -469,46 +469,46 @@ GtkWidget *gtk_combofix_new_complex ( GSList *liste,
 static gint classe_alphabetique ( gchar *string_1,
 				  gchar *string_2 )
 {
-    /*   comme la fonction g_strcasecmp met les accents derrire, on magouille pour les prendre en compte */
+    /*   comme la fonction g_strcasecmp met les accents derrière, on magouille pour les prendre en compte */
 
     string_1 = g_strdup ( string_1 );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "éÉèÈêÊ",
 			      'e' );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "çÇ",
 			      'c' );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "àÀ",
 			      'a' );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "ùûÙÛ",
 			      'u' );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "ôÔ",
 			      'o' );
     string_1 = g_strdelimit ( string_1,
-			      "",
+			      "îÎ",
 			      'i' );
 
     string_2 = g_strdup ( string_2 );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "éÉèÈêÊ",
 			      'e' );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "çÇ",
 			      'c' );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "àÀ",
 			      'a' );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "ùûÙÛ",
 			      'u' );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "ôÔ",
 			      'o' );
     string_2 = g_strdelimit ( string_2,
-			      "",
+			      "îÎ",
 			      'i' );
 
 
@@ -522,13 +522,13 @@ static gint classe_alphabetique ( gchar *string_1,
 
 /* **************************************************************************************************** */
 /* Fonction : change_arrow : */
-/* appele lors de click sur la flche */
+/* appelée lors de click sur la flèche */
 /* **************************************************************************************************** */
 
 static gboolean change_arrow ( GtkWidget *bouton,
 			       GtkComboFix *combofix )
 {
-    /* ncessaire de mettre le grab_focus en premier pour le fonctionnement avec grisbi */
+    /* nécessaire de mettre le grab_focus en premier pour le fonctionnement avec grisbi */
 
     gtk_widget_grab_focus ( combofix -> entry );
 
@@ -561,8 +561,8 @@ static gboolean change_arrow ( GtkWidget *bouton,
 
 
 /* **************************************************************************************************** */
-/* fonction appele  la fin lorsqu'une lettre est tape */
-/* ou lorsque du texte est effac : dans ce cas entree = NULL */
+/* fonction appelée à la fin lorsqu'une lettre est tapée */
+/* ou lorsque du texte est effacé : dans ce cas entree = NULL */
 /* **************************************************************************************************** */
 
 static gboolean affiche_proposition ( GtkWidget *entree,
@@ -591,13 +591,13 @@ static gboolean affiche_proposition ( GtkWidget *entree,
     couleur_bleue.green = COULEUR_GREEN;
     couleur_bleue.blue = COULEUR_BLUE;
 
-    /*   pour viter un warning lors de la compil : */
+    /*   pour éviter un warning lors de la compil : */
 
     categorie = "";
 
 
     /*   si la liste de mot est nulle, soit force_text n'est pas mis, et on vire, soit il est mis, */
-    /* et on vide l'entre avant de virer */
+    /* et on vide l'entrée avant de virer */
 
     if ( !combofix->liste  )
     {
@@ -619,7 +619,7 @@ static gboolean affiche_proposition ( GtkWidget *entree,
 	return TRUE;
     }
 
-    /* recherche de la compltion */
+    /* recherche de la complétion */
 
 recherche_completion:
 
@@ -658,8 +658,8 @@ recherche_completion:
     else
 	completion = "";
 
-    /* commence par vrifier l'entre si force_text = 1 */
-    /* si le mot n'existe pas dans la liste autorise, efface ce qui a t ajout */
+    /* commence par vérifier l'entrée si force_text = 1 */
+    /* si le mot n'existe pas dans la liste autorisée, efface ce qui a été ajouté */
 
     if ( combofix -> force_text
 	 &&
@@ -690,8 +690,8 @@ recherche_completion:
     }
 
 
-    /*   si on voulait juste une compltion sans popup, on la fait et on s'en va */
-    /* ne fait pas la compltion si c'est du texte effac */
+    /*   si on voulait juste une complétion sans popup, on la fait et on s'en va */
+    /* ne fait pas la complétion si c'est du texte effacé */
 
     if ( entree && !combofix -> affiche_liste && completion )
     {
@@ -700,7 +700,7 @@ recherche_completion:
 	    gtk_combofix_set_text ( combofix,
 				    completion );
 
-	    /*  l'affichage de la slection se fera plus tard ( une fois l'objet dessin ) */
+	    /*  l'affichage de la sélection se fera plus tard ( une fois l'objet dessiné ) */
 
 	    rafraichir_selection = 1;
 	}
@@ -708,11 +708,11 @@ recherche_completion:
     }
 
 
-    /* on commence  rcuprer toutes les lignes qu'on va inclure dans la box */
-    /* si le nb de lignes est >  lignes_max, on n'affiche pas */
+    /* on commence à récupérer toutes les lignes qu'on va inclure dans la box */
+    /* si le nb de lignes est > à lignes_max, on n'affiche pas */
 
 
-    /* si on a click sur l'arrow, on affiche toute la liste */
+    /* si on a clické sur l'arrow, on affiche toute la liste */
 
     if ( entree == GINT_TO_POINTER ( -1 ) )
 	chaine = texte;
@@ -730,7 +730,7 @@ recherche_completion:
 	    GSList *sous_liste_tmp;
 	    GSList *sous_liste_affichee;
 
-	    /* protection si pas de catg  une sous-categ */
+	    /* protection si pas de catég à une sous-categ */
 
 	    categorie = "";
 
@@ -743,16 +743,16 @@ recherche_completion:
 
 		string = g_strdup ( sous_liste_tmp -> data );
 
-		/* la comparaison est diffrente selon que ce soit une catg ou une sous catg : */
-		/*  pour une catg, on la compare directement avec l'entre */
-		/* pour une sous-catg, on compare categ : sous-categ avec l'entre */
+		/* la comparaison est différente selon que ce soit une catég ou une sous catég : */
+		/*  pour une catég, on la compare directement avec l'entrée */
+		/* pour une sous-catég, on compare categ : sous-categ avec l'entrée */
 
 		if ( string[0] != '\t' )
 		{
 		    gchar *string_tot;
 
-		    /* c'est une catgorie */
-		    /* sauvegarde de la catgorie pour tester les sous-catgories */
+		    /* c'est une catégorie */
+		    /* sauvegarde de la catégorie pour tester les sous-catégories */
 
 		    categorie = string;
 		    string_tot = g_strconcat ( string,
@@ -767,7 +767,7 @@ recherche_completion:
 					  strlen ( string_tot )))
 
 		    {
-			/* cette catgorie devra tre affiche */
+			/* cette catégorie devra être affichée */
 
 			sous_liste_affichee = g_slist_append ( sous_liste_affichee,
 							       string );
@@ -783,7 +783,7 @@ recherche_completion:
 							NULL ),
 					  strlen ( chaine )))
 		    {
-			/* cette sous-catg devra tre affiche */
+			/* cette sous-catég devra être affichée */
 
 			sous_liste_affichee = g_slist_append ( sous_liste_affichee,
 							       string );
@@ -808,7 +808,7 @@ recherche_completion:
 	    }
 
 	    /* on a fait le tour de la sous-liste du combofix complex */
-	    /* on ajoute la sous-liste des textes  afficher dans liste_affichee */
+	    /* on ajoute la sous-liste des textes à afficher dans liste_affichee */
 
 	    liste_affichee = g_slist_append ( liste_affichee,
 					      sous_liste_affichee );
@@ -820,21 +820,21 @@ recherche_completion:
 	{
 	    gchar *string;
 
-	    /* protection si pas de catg  une sous-categ */
+	    /* protection si pas de catég à une sous-categ */
 
 	    categorie = "";
 
 	    string = liste_tmp -> data;
 
-	    /* la comparaison est diffrente selon que ce soit une catg ou une sous catg : */
-	    /*  pour une catg, on la compare directement avec l'entre */
-	    /* pour une sous-catg, on compare categ : sous-categ avec l'entre */
+	    /* la comparaison est différente selon que ce soit une catég ou une sous catég : */
+	    /*  pour une catég, on la compare directement avec l'entrée */
+	    /* pour une sous-catég, on compare categ : sous-categ avec l'entrée */
 
 	    if ( string[0] != '\t' )
 	    {
 		gchar *string_tot;
 
-		/* sauvegarde de la catgorie pour tester les sous-catgories */
+		/* sauvegarde de la catégorie pour tester les sous-catégories */
 
 		categorie = string;
 		string_tot = g_strconcat ( string,
@@ -887,7 +887,7 @@ recherche_completion:
 	}
 
 
-    /*   si on est cens trier, c'est ici, o on ne trie que les lignes qu'on va afficher */
+    /*   si on est censé trier, c'est ici, où on ne trie que les lignes qu'on va afficher */
 
 
     if ( combofix -> auto_sort )
@@ -911,8 +911,8 @@ recherche_completion:
     }
 
 
-    /* on cre la nouvelle box si necessaire en fonction du contenu de l'entre */
-    /* et la compltion */
+    /* on crée la nouvelle box si necessaire en fonction du contenu de l'entrée */
+    /* et la complétion */
 
     scrolled_window = gtk_scrolled_window_new ( FALSE,
 						FALSE );
@@ -961,18 +961,18 @@ recherche_completion:
 
 		if ( string[0] != '\t' )
 		{
-		    /* c'est une catgorie, on la met dans la liste */
+		    /* c'est une catégorie, on la met dans la liste */
 
 
-		    /* on met la catg dans la variable qui sera utilise dans l'affichage de la sous catg */
+		    /* on met la catég dans la variable qui sera utilisée dans l'affichage de la sous catég */
 
 		    categorie = string;
 
-		    /* permet d'viter d'avoir une barre en haut */
+		    /* permet d'éviter d'avoir une barre en haut */
 
 		    menu_rempli_ok = 1;
 
-		    /* on met une sparation si ncessaire */
+		    /* on met une séparation si nécessaire */
 
 		    if ( menu_rempli )
 		    {
@@ -987,7 +987,7 @@ recherche_completion:
 			menu_rempli = 0;
 		    }
 
-		    /* cration de l'event_box */
+		    /* création de l'event_box */
 
 		    event_box = gtk_event_box_new ();
 		    gtk_widget_set_style ( event_box,
@@ -1004,7 +1004,7 @@ recherche_completion:
 					 GTK_SIGNAL_FUNC ( click_sur_label ),
 					 combofix );
 
-		    /* cration du label */
+		    /* création du label */
 
 		    label = gtk_label_new ( string );
 
@@ -1029,7 +1029,7 @@ recherche_completion:
 		{
 		    /* c'est une sous-categ, on la met dans la liste avec un espace devant */
 
-		    /* cration de l'event_box */
+		    /* création de l'event_box */
 
 		    event_box = gtk_event_box_new ();
 		    gtk_widget_set_style ( event_box,
@@ -1096,11 +1096,11 @@ recherche_completion:
 	    {
 		/* c'est une categ, on l'affiche */
 
-		/* on met la catg dans la variable qui sera utilise dans l'affichage de la sous catg */
+		/* on met la catég dans la variable qui sera utilisée dans l'affichage de la sous catég */
 
 		categorie = string;
 
-		/* cration de l'event_box */
+		/* création de l'event_box */
 
 		event_box = gtk_event_box_new ();
 		gtk_widget_set_style ( event_box,
@@ -1118,7 +1118,7 @@ recherche_completion:
 				     combofix );
 
 
-		/* cration du label */
+		/* création du label */
 
 		label = gtk_label_new ( string );
 
@@ -1142,7 +1142,7 @@ recherche_completion:
 	    {
 		/* c'est une sous-categ, on la met dans la liste avec un espace devant */
 
-		/* cration de l'event_box */
+		/* création de l'event_box */
 
 		event_box = gtk_event_box_new ();
 		gtk_widget_set_style ( event_box,
@@ -1192,19 +1192,19 @@ recherche_completion:
 
     if ( entree && completion )
     {
-	/* on affiche maintenant la compltion dans le combofix */
+	/* on affiche maintenant la complétion dans le combofix */
 
 	gtk_combofix_set_text ( combofix,
 				completion );
 
-	/*  l'affichage de la slection se fera plus tard ( une fois l'objet dessin ) */
+	/*  l'affichage de la sélection se fera plus tard ( une fois l'objet dessiné ) */
 
 	rafraichir_selection = 1;
     }
 
 
-    /*la liste est maintenant cre ; si la popup tait dj faite, on remplace l'ancienne liste, sinon, on cre la popup */
-    /* la position et la taille de la popup seront calcules quand la taille sera alloue */
+    /*la liste est maintenant créée ; si la popup était déjà faite, on remplace l'ancienne liste, sinon, on crée la popup */
+    /* la position et la taille de la popup seront calculées quand la taille sera allouée */
 
     combofix -> label_selectionne = -1;
 
@@ -1298,7 +1298,7 @@ static gboolean realize_scrolled_window ( GtkWidget *vbox,
 				    combofix );
 
 
-    /* rcupre la position de l'entry pour dfinir x et y du placement de la fentre */
+    /* récupère la position de l'entry pour définir x et y du placement de la fenêtre */
 
     gdk_window_get_origin ( GTK_WIDGET ( combofix->entry )->window,
 			    &x,
@@ -1306,7 +1306,7 @@ static gboolean realize_scrolled_window ( GtkWidget *vbox,
 
     hauteur = vbox -> requisition.height + 10;
 
-    /*   si la largeur de la liste est >  celle du combofix, une scrollbar sera affiche en bas, on augment la hauteur */
+    /*   si la largeur de la liste est > à celle du combofix, une scrollbar sera affichée en bas, on augment la hauteur */
 
     if ( vbox -> requisition.width > GTK_WIDGET ( combofix -> entry ) -> allocation.width )
 	hauteur = hauteur + GTK_SCROLLED_WINDOW  ( combofix->box ) -> hscrollbar -> requisition.height + 5;
@@ -1314,13 +1314,13 @@ static gboolean realize_scrolled_window ( GtkWidget *vbox,
 
 
     /*   si la popup est trop petite pour contenir toute la liste et que la place vers le haut est 2 fois plus grande que vers le bas, */
-    /*     on affiche la popup au dessus de l'entre */
+    /*     on affiche la popup au dessus de l'entrée */
 
     if ( (( gdk_screen_height () - y - GTK_WIDGET ( combofix ) -> allocation.height ) < hauteur )
 	 &&
 	 ( ( ( gdk_screen_height () - y ) * 3 ) < y ) )
     {
-	/* on met la popup au dessus de l'entre */
+	/* on met la popup au dessus de l'entrée */
 
 	if ( y > hauteur )
 	    y = y - hauteur;
@@ -1332,7 +1332,7 @@ static gboolean realize_scrolled_window ( GtkWidget *vbox,
     }
     else
     {
-	/* on met la popup en dessous de l'entre */
+	/* on met la popup en dessous de l'entrée */
 
 	y = y + GTK_WIDGET ( combofix ) -> requisition.height;
 
@@ -1358,16 +1358,16 @@ static gboolean realize_scrolled_window ( GtkWidget *vbox,
 
 
 /* **************************************************************************************************** */
-/* fonction appele lorsque la popup reoit un vnement button_press */
-/* rsultat : on vire la popup */
-/* une autre fonction se charge de rcuprer le label si c'est un click sur la popup */
+/* fonction appelée lorsque la popup reçoit un évènement button_press */
+/* résultat : on vire la popup */
+/* une autre fonction se charge de récupérer le label si c'est un click sur la popup */
 /* **************************************************************************************************** */
 
 static gboolean gtk_combofix_button_press ( GtkWidget *widget,
 					    GdkEventButton *ev,
 					    GtkComboFix *combofix )
 {
-    /*   si le click est sur la popup ( pour viter que la popup vire si on click sur les barres de dfilement ), on fait rien */
+    /*   si le click est sur la popup ( pour éviter que la popup vire si on click sur les barres de défilement ), on fait rien */
 
     if ( ( ev -> x_root > ( GTK_WIDGET ( combofix->popup ) -> allocation.x ))
 	 &&
@@ -1399,7 +1399,7 @@ static gboolean met_en_prelight ( GtkWidget *event_box,
 	return TRUE;
     }
 
-    /* efface l'ancienne slection */
+    /* efface l'ancienne sélection */
 
     if ( combofix -> label_selectionne != -1 )
 	gtk_widget_set_state ( GTK_WIDGET ( g_slist_nth_data ( combofix->event_box, combofix -> label_selectionne ) ),
@@ -1408,7 +1408,7 @@ static gboolean met_en_prelight ( GtkWidget *event_box,
     gtk_widget_set_state ( GTK_WIDGET ( event_box ),
 			   GTK_STATE_PRELIGHT );
 
-    /* met  jour la variable label_selectionne */
+    /* met à jour la variable label_selectionne */
 
     combofix -> label_selectionne  = g_slist_index ( combofix -> event_box,
 						     event_box );
@@ -1453,7 +1453,7 @@ static gboolean focus_out_combofix ( GtkWidget *widget,
 			     &x,
 			     &y );
 
-    /*   si la popup tait affiche, on la cache et on libre le grab pointer */
+    /*   si la popup était affichée, on la cache et on libère le grab pointer */
 
     if ( GTK_WIDGET_VISIBLE ( combofix -> popup ) )
     {
@@ -1465,7 +1465,7 @@ static gboolean focus_out_combofix ( GtkWidget *widget,
 	    gtk_widget_hide ( combofix->popup );
     }
 
-    /*   si force_text est mis, il faut que le texte corresponde, sinon, met le 1er trouv */
+    /*   si force_text est mis, il faut que le texte corresponde, sinon, met le 1er trouvé */
 
     if ( combofix -> force_text )
     {
@@ -1479,7 +1479,7 @@ static gboolean focus_out_combofix ( GtkWidget *widget,
 
 	liste_tmp = combofix->liste_completion;
 
-	/* recherche de la chaine tape dans la liste et remplit l'entre de la 1re*/
+	/* recherche de la chaine tapée dans la liste et remplit l'entrée de la 1ère*/
 
 	do
 	    if ( !g_strncasecmp ( chaine,
@@ -1525,7 +1525,7 @@ static gboolean met_selection ( GtkWidget *entry,
 
 
 /* **************************************************************************************************** */
-/* vrifie avant d'effacer une partie du texte si force_text est mis, que le rsultat fait partit de la liste */
+/* vérifie avant d'effacer une partie du texte si force_text est mis, que le résultat fait partit de la liste */
 /* **************************************************************************************************** */
 static gboolean verifie_efface_texte ( GtkWidget *entree,
 				       gint start,
@@ -1547,7 +1547,7 @@ static gboolean verifie_efface_texte ( GtkWidget *entree,
     if ( !combofix -> liste )
 	return TRUE;
 
-    /* cre la future chaine */
+    /* crée la future chaine */
 
     chaine = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( combofix -> entry ) ));
     longueur = strlen ( chaine );
@@ -1558,7 +1558,7 @@ static gboolean verifie_efface_texte ( GtkWidget *entree,
     memmove ( chaine + start, chaine + end, longueur - end );
     chaine [longueur - end + start] = 0;
 
-    /* vrifie que la chaine fait partie de la liste */
+    /* vérifie que la chaine fait partie de la liste */
 
     liste_tmp = combofix->liste_completion;
 
@@ -1570,12 +1570,12 @@ static gboolean verifie_efface_texte ( GtkWidget *entree,
 	    return TRUE;
     while ( ( liste_tmp = liste_tmp -> next ) );
 
-    /*   pas trouv dans la liste -> stoppe le signal */
+    /*   pas trouvé dans la liste -> stoppe le signal */
 
     gtk_signal_emit_stop_by_name ( GTK_OBJECT ( combofix -> entry ),
 				   "delete_text" );
 
-    /*   la position du curseur a dj t modifie, on le remet  sa place */
+    /*   la position du curseur a déjà été modifiée, on le remet à sa place */
 
     if( gtk_editable_get_position ( GTK_EDITABLE ( combofix -> entry ) ) == start )
 	gtk_editable_set_position ( GTK_EDITABLE ( combofix -> entry ),
@@ -1591,8 +1591,8 @@ static gboolean verifie_efface_texte ( GtkWidget *entree,
 
 
 /* **************************************************************************************************** */
-/* lorsque du texte est effac, on recre la popup mais plus de slection */
-/* en mettant le 1er arg de affiche_proposition  NULL */
+/* lorsque du texte est effacé, on recrée la popup mais plus de sélection */
+/* en mettant le 1er arg de affiche_proposition à NULL */
 /* **************************************************************************************************** */
 
 static gboolean efface_texte ( GtkWidget *entree,
@@ -1624,7 +1624,7 @@ static gboolean efface_texte ( GtkWidget *entree,
 
 /* **************************************************************************************************** */
 /* fonction gtk_combofix_set_text */
-/* fonction externe qui prend comme argument le combofix et le texte  mettre dedans */
+/* fonction externe qui prend comme argument le combofix et le texte à mettre dedans */
 /* **************************************************************************************************** */
 
 void gtk_combofix_set_text ( GtkComboFix *combofix,
@@ -1678,7 +1678,7 @@ void gtk_combofix_view_list ( GtkComboFix *combofix,
     g_return_if_fail (GTK_IS_COMBOFIX (combofix));
 
 
-    /* si pas de changement par rapport  ce qui est affich -> dgage */
+    /* si pas de changement par rapport à ce qui est affiché -> dégage */
 
     if ( ( valeur == FALSE && combofix->affiche_liste == 0 ) || ( valeur != FALSE && combofix->affiche_liste == 1 ))
 	return;
@@ -1721,8 +1721,8 @@ static gboolean touche_pressee ( GtkWidget *entry,
     switch ( ev -> keyval )
     {
 
-	/* touche gauche ou droite presse s'il y a une slection, vire la
-	   slection et place le curseur  la fin de cette slection */
+	/* touche gauche ou droite pressée s'il y a une sélection, vire la
+	   sélection et place le curseur à la fin de cette sélection */
 	case GDK_Left :
 	case GDK_KP_Left:
 	case GDK_Right :
@@ -1734,7 +1734,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 	    gtk_widget_hide ( combofix->popup );
 	    return FALSE;
 
-	    /* touche entre : prend le label slectionn puis vire la popup */
+	    /* touche entrée : prend le label sélectionné puis vire la popup */
 	case GDK_KP_Enter :
 	case GDK_Return :
 
@@ -1746,7 +1746,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 					       "key-press-event" );
 	    }
 
-	    /* touches chap  : vire la popup et  la slection */
+	    /* touches échap  : vire la popup et  la sélection */
 	case GDK_Escape:
 
 	    if ( GTK_WIDGET_VISIBLE ( combofix -> popup ))
@@ -1763,12 +1763,12 @@ static gboolean touche_pressee ( GtkWidget *entry,
 	    }
 	    break;
 
-	case GDK_Down :		/* touches flche bas */
+	case GDK_Down :		/* touches flèche bas */
 	case GDK_KP_Down :
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( combofix -> entry ),
 					   "key-press-event" );
-	    /*     si la popup n'est pas affiche  cause de l'arrow, descend l'arrow, affiche la liste */
+	    /*     si la popup n'est pas affichée à cause de l'arrow, descend l'arrow, affiche la liste */
 	    if ( combofix -> affiche_liste == 0 || !GTK_WIDGET_VISIBLE ( combofix->popup ) )
 	    {
 		gtk_widget_grab_focus ( GTK_WIDGET ( combofix -> arrow ));
@@ -1776,7 +1776,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 			       combofix );
 		gtk_widget_grab_focus ( GTK_WIDGET ( combofix -> entry ));
 	    }
-	    /*       si la popup est affiche, on descend dans la liste, sinon, c'est qu'il n'y avait aucune slection possible */
+	    /*       si la popup est affichée, on descend dans la liste, sinon, c'est qu'il n'y avait aucune sélection possible */
 
 	    if ( GTK_WIDGET_VISIBLE ( combofix->popup ) )
 	    {
@@ -1793,7 +1793,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 		    ajustement = gtk_scrolled_window_get_vadjustment ( GTK_SCROLLED_WINDOW ( combofix -> box ));
 
-		    /* 	  si on est en dessous de la liste, on la dcale vers le bas */
+		    /* 	  si on est en dessous de la liste, on la décale vers le bas */
 
 		    while ( ( combofix -> label_selectionne + 1 )* ( GTK_WIDGET ( g_slist_nth_data ( combofix->event_box, combofix -> label_selectionne ) )) -> allocation.height > ajustement -> value + ajustement -> page_size )
 			gtk_adjustment_set_value ( ajustement,
@@ -1805,7 +1805,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 	    }
 	    break;
 
-	case GDK_Up :		/* touches flche haut */
+	case GDK_Up :		/* touches flèche haut */
 	case GDK_KP_Up :
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( combofix -> entry ),
@@ -1824,7 +1824,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 		ajustement = gtk_scrolled_window_get_vadjustment ( GTK_SCROLLED_WINDOW ( combofix -> box ));
 
-		/* 	  si on est au dessus de la liste, on la dcale vers le haut */
+		/* 	  si on est au dessus de la liste, on la décale vers le haut */
 
 		while ( combofix -> label_selectionne* ( GTK_WIDGET ( g_slist_nth_data ( combofix->event_box, combofix -> label_selectionne ) )) -> allocation.height < ajustement -> value )
 		    gtk_adjustment_set_value ( ajustement,
@@ -1862,7 +1862,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 		ajustement = gtk_scrolled_window_get_vadjustment ( GTK_SCROLLED_WINDOW ( combofix -> box ));
 
-		/* 	  si on est au dessus de la liste, on la dcale vers le haut */
+		/* 	  si on est au dessus de la liste, on la décale vers le haut */
 
 		while ( combofix -> label_selectionne* ( GTK_WIDGET ( g_slist_nth_data ( combofix->event_box, combofix -> label_selectionne ) )) -> allocation.height < ajustement -> value )
 		    gtk_adjustment_set_value ( ajustement,
@@ -1879,7 +1879,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( combofix -> entry ),
 					   "key-press-event" );
-	    /*     si la popup n'est pas affiche  cause de l'arrow, descend l'arrow, affiche la liste */
+	    /*     si la popup n'est pas affichée à cause de l'arrow, descend l'arrow, affiche la liste */
 	    if ( combofix -> affiche_liste == 0 || !GTK_WIDGET_VISIBLE ( combofix->popup ) )
 	    {
 		gtk_widget_grab_focus ( GTK_WIDGET ( combofix -> arrow ));
@@ -1887,7 +1887,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 			       combofix );
 		gtk_widget_grab_focus ( GTK_WIDGET ( combofix -> entry ));
 	    }
-	    /*       si la popup est affiche, on descend dans la liste, sinon, c'est qu'il n'y avait aucune slection possible */
+	    /*       si la popup est affichée, on descend dans la liste, sinon, c'est qu'il n'y avait aucune sélection possible */
 
 	    if ( GTK_WIDGET_VISIBLE ( combofix->popup ) )
 	    {
@@ -1917,7 +1917,7 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 		    ajustement = gtk_scrolled_window_get_vadjustment ( GTK_SCROLLED_WINDOW ( combofix -> box ));
 
-		    /* 	  si on est en dessous de la liste, on la dcale vers le bas */
+		    /* 	  si on est en dessous de la liste, on la décale vers le bas */
 
 		    while ( ( combofix -> label_selectionne + 1 )* ( GTK_WIDGET ( g_slist_nth_data ( combofix->event_box, combofix -> label_selectionne ) )) -> allocation.height > ajustement -> value + ajustement -> page_size )
 			gtk_adjustment_set_value ( ajustement,
@@ -1936,9 +1936,9 @@ static gboolean touche_pressee ( GtkWidget *entry,
 
 /* **************************************************************************************************** */
 /* Fonction gtk_combofix_show_arrow : */
-/* affiche ou non la flche permettant d'afficher la liste */
+/* affiche ou non la flèche permettant d'afficher la liste */
 /* argument : la combofix */
-/*                     booleen TRUE ( affiche la flche ) / FALSE */
+/*                     booleen TRUE ( affiche la flèche ) / FALSE */
 /* **************************************************************************************************** */
 
 void gtk_combofix_show_arrow ( GtkComboFix *combofix,
@@ -1961,7 +1961,7 @@ void gtk_combofix_show_arrow ( GtkComboFix *combofix,
 
 /* **************************************************************************************************** */
 /* Fonction gtk_combofix_sort : */
-/* classe la liste en respectant les diffrentes listes si c'est un complex, et en respectant les catg / sous-categ  */
+/* classe la liste en respectant les différentes listes si c'est un complex, et en respectant les catég / sous-categ  */
 /* argument : la combofix */
 /* **************************************************************************************************** */
 
@@ -2001,7 +2001,7 @@ static GSList *classe_combofix ( GSList *liste )
     gchar *string;
 
 
-    /* on recre d'abord la liste sous la forme categ : sous-categ */
+    /* on recrée d'abord la liste sous la forme categ : sous-categ */
 
     pointeur = liste;
     categ = "";
@@ -2025,7 +2025,7 @@ static GSList *classe_combofix ( GSList *liste )
     liste = g_slist_sort ( liste,
 			   ( GCompareFunc ) classe_alphabetique );
 
-    /*       on retire les catgories des sous-categ */
+    /*       on retire les catégories des sous-categ */
 
     pointeur = liste;
 
@@ -2116,12 +2116,12 @@ void gtk_combofix_set_list ( GtkComboFix *combofix,
     combofix -> auto_sort = classement_auto;
 
 
-    /* cration de la liste des compltions : systme de catgories - sous catgories */
-    /* toutes catgorie est mise dans la liste */
-    /*   les sous-catg sont mises sous la forme catg : sous-catg */
-    /* on trie  la fin la liste par ordre alphabtique pour que lors d'une compltion, c'est le 1er qui sorte */
+    /* création de la liste des complétions : système de catégories - sous catégories */
+    /* toutes catégorie est mise dans la liste */
+    /*   les sous-catég sont mises sous la forme catég : sous-catég */
+    /* on trie à la fin la liste par ordre alphabétique pour que lors d'une complétion, c'est le 1er qui sorte */
 
-    /* protge de l'erreur si on met une sous categ en 1er */
+    /* protège de l'erreur si on met une sous categ en 1er */
 
     derniere_categ = "";
 
@@ -2198,8 +2198,8 @@ static gboolean touche_pressee_dans_popup ( GtkWidget *popup,
 
 /* **************************************************************************************************** */
 /* Fonction gtk_combofix_set_lignes_max : */
-/* permet de choisir le nombre maximal de lignes affiches dans la liste  */
-/* s'il vaut 0, toutes les lignes seront affiches */
+/* permet de choisir le nombre maximal de lignes affichées dans la liste  */
+/* s'il vaut 0, toutes les lignes seront affichées */
 /* arguments :                           */
 /*       combofix : la combofix          */
 /*       liste : une gslist              */
