@@ -1,6 +1,6 @@
 /* Fichier help.c */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2003 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
 
@@ -44,8 +44,8 @@ void a_propos ( GtkWidget *bouton,
     const gchar *generalites = _("Grisbi is a personnal accounting application for Linux\nSuch a program allows you to sort your financial transactions, whatever they are, in a convenient and intuitive way.  Thus, you will be able to manage them as to fit your needs the more you can.\nGrisbi aims both at simplicty and efficiency for common use, and at a powerful use for power users.  We will always try to respect this as features will come.");
 
     const gchar *auteurs[] = { 
-      _("Alain Pichon (alain.pichon[at]grisbi.org): Fedora and RHEL packaging"),
-      _("Alain Portal <dionysos[at]grisbi.org>: Programming, manual, RedHat packaging"),
+      _("Alain Pichon (alain.pichon[at]grisbi.org): RHEL packaging"),
+      _("Alain Portal <dionysos[at]grisbi.org>: Programming, manual, Fedora and RedHat packaging"),
       _("Andre Pascual (andre[at]linuxgraphic.org) : Logo"),
       _("Axel Rousseau (axel584[at]axel584.org): contributor"),
       _("Benjamin Drieu (bdrieu[at]april.org) : Programming, Debian packaging"),
@@ -63,6 +63,7 @@ void a_propos ( GtkWidget *bouton,
       _("Alain Portal (dionysos[at]grisbi.org) : English"),
       _("Benjamin Drieu (bdrieu[at]april.org) : English"),
       _("Daniel Cartron (cartron[at]grisbi.org) : English"),
+      _("Flavio Henrique Somensi (flavio[at]opens.com.br): Brazilian Portuguese"),
       _("Giorgio Mandolfo (giorgio[at]pollycoke.org) : Italian"),
       _("Martin Stromberger (Fabiolla[at]aon.at): German"),
       NULL };
@@ -101,7 +102,7 @@ void a_propos ( GtkWidget *bouton,
 		gtk_widget_show ( notebook );
 
 
-		/* mise en forme de l'onglet de gnralits */
+		/* mise en forme de l'onglet de généralités */
 
 		vbox = gtk_vbox_new ( FALSE, 5 );
 		gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 10 );
