@@ -2,7 +2,7 @@
 /* fichier qui s'occupe de l'onglet de gestion des imputations                */
 /* 			imputation_budgetaire.c                               */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
 /*			2004 Alain Portal (dionysos@grisbi.org) 	      */
 /*			http://www.grisbi.org   			      */
@@ -55,7 +55,7 @@ extern GtkWidget *widget_formulaire_echeancier[SCHEDULER_FORM_TOTAL_WIDGET];
 
 /* **************************************************************************************************** */
 /* Fonction onglet_imputations : */
-/* cre et renvoie le widget contenu dans l'onglet */
+/* crée et renvoie le widget contenu dans l'onglet */
 /* **************************************************************************************************** */
 
 GtkWidget *onglet_imputations ( void )
@@ -78,7 +78,7 @@ GtkWidget *onglet_imputations ( void )
     GtkWidget *bouton;
 
 
-    /* cration de la fentre qui sera renvoye */
+    /* création de la fenêtre qui sera renvoyée */
 
     onglet = gtk_hbox_new ( FALSE,
 			    5 );
@@ -90,7 +90,7 @@ GtkWidget *onglet_imputations ( void )
 
     /* mise en place de la partie de gauche */
 
-    /*   cration de la frame de gauche */
+    /*   création de la frame de gauche */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -142,7 +142,7 @@ GtkWidget *onglet_imputations ( void )
     gtk_widget_show ( entree_nom_imputation );
 
 
-    /* cration des radio bouton dbit/crdit */
+    /* création des radio bouton débit/crédit */
 
     separateur = gtk_hseparator_new ();
     gtk_box_pack_start ( GTK_BOX ( vbox_frame ),
@@ -200,7 +200,7 @@ GtkWidget *onglet_imputations ( void )
 
 
 
-    /*   cration des boutons modifier et annuler */
+    /*   création des boutons modifier et annuler */
 
     hbox = gtk_hbox_new ( TRUE,
 			  5 );
@@ -298,7 +298,7 @@ GtkWidget *onglet_imputations ( void )
 			 0 );
     gtk_widget_show ( bouton_ajouter_sous_imputation );
 
-    /* sparation */
+    /* séparation */
 
     separateur = gtk_hseparator_new ();
     gtk_box_pack_start ( GTK_BOX ( vbox ),
@@ -308,7 +308,7 @@ GtkWidget *onglet_imputations ( void )
 			 5 );
     gtk_widget_show ( separateur );
 
-    /* mise en place du bouton fusionner avec les catgories */
+    /* mise en place du bouton fusionner avec les catégories */
 
     bouton = gtk_button_new_with_label ( _("Merge categories") );
     gtk_button_set_relief ( GTK_BUTTON ( bouton ),
@@ -325,7 +325,7 @@ GtkWidget *onglet_imputations ( void )
     gtk_widget_show ( bouton );
 
 
-    /* sparation */
+    /* séparation */
 
     separateur = gtk_hseparator_new ();
     gtk_box_pack_start ( GTK_BOX ( vbox ),
@@ -368,7 +368,7 @@ GtkWidget *onglet_imputations ( void )
     gtk_widget_show ( bouton );
 
 
-    /*   cration de la frame de droite */
+    /*   création de la frame de droite */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -396,7 +396,7 @@ GtkWidget *onglet_imputations ( void )
 			 FALSE,
 			 0 );
 
-    /* cration de l'arbre principal */
+    /* création de l'arbre principal */
 
     scroll_window = gtk_scrolled_window_new ( NULL,
 					      NULL );
@@ -446,7 +446,7 @@ GtkWidget *onglet_imputations ( void )
 				      3,
 				      FALSE );
 
-    /* on met la fontion de tri alphabtique en prenant en compte les accents */
+    /* on met la fontion de tri alphabétique en prenant en compte les accents */
 
     gtk_clist_set_compare_func ( GTK_CLIST ( arbre_imputation ),
 				 (GtkCListCompareFunc) classement_alphabetique_tree );
@@ -483,7 +483,7 @@ GtkWidget *onglet_imputations ( void )
     gtk_clist_set_compare_func ( GTK_CLIST ( arbre_imputation ),
 				 (GtkCListCompareFunc) classement_alphabetique_tree );
 
-    /* la 1re fois qu'on affichera les catg, il faudra remplir la liste */
+    /* la 1ère fois qu'on affichera les catég, il faudra remplir la liste */
 
     modif_imputation = 1;
 
@@ -510,7 +510,7 @@ void remplit_arbre_imputation ( void )
 
     gtk_clist_freeze ( GTK_CLIST ( arbre_imputation ));
 
-    /* retire la slection */
+    /* retire la sélection */
 
     gtk_clist_unselect_all ( GTK_CLIST ( arbre_imputation ));
 
@@ -519,15 +519,15 @@ void remplit_arbre_imputation ( void )
     gtk_clist_clear ( GTK_CLIST ( arbre_imputation ));
 
 
-    /* rcupration de la devise des paramtres */
+    /* récupération de la devise des paramètres */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
     if ( !devise_compte
 	 ||
-	 devise_compte -> no_devise != no_devise_totaux_tiers )
+	 devise_compte -> no_devise != no_devise_totaux_ib )
 	devise_compte = g_slist_find_custom ( liste_struct_devises,
-					      GINT_TO_POINTER ( no_devise_totaux_tiers ),
+					      GINT_TO_POINTER ( no_devise_totaux_ib ),
 					      ( GCompareFunc ) recherche_devise_par_no) -> data;
 
     /* calcule les montants des imputations et sous imputations */
@@ -582,7 +582,7 @@ void remplit_arbre_imputation ( void )
 					FALSE,
 					FALSE );
 
-	/* on associe  ce imputation  l'adr de sa struct */
+	/* on associe à ce imputation à l'adr de sa struct */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 				      ligne,
@@ -641,7 +641,7 @@ void remplit_arbre_imputation ( void )
 							    FALSE,
 							    FALSE );
 
-	    /* on associe cette sous_imputation  l'adr de sa struct */
+	    /* on associe cette sous_imputation à l'adr de sa struct */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 					  ligne_sous_imputation,
@@ -662,7 +662,7 @@ void remplit_arbre_imputation ( void )
 							    FALSE,
 							    FALSE );
 
-	    /* on associe le fils bidon  -1 */
+	    /* on associe le fils bidon à -1 */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 					  ligne_sous_imputation,
@@ -672,7 +672,7 @@ void remplit_arbre_imputation ( void )
 	    liste_sous_imputation_tmp = liste_sous_imputation_tmp -> next;
 	}
 
-	/*       on a fini de saisir les sous catgories, s'il y avait des ops sans sous catg, on les mets ici */
+	/*       on a fini de saisir les sous catégories, s'il y avait des opés sans sous catég, on les mets ici */
 
 	if ( tab_montant_sous_imputation[place_imputation]
 	     &&
@@ -721,7 +721,7 @@ void remplit_arbre_imputation ( void )
 							    FALSE,
 							    FALSE );
 
-	    /* on associe le fils bidon  -1 */
+	    /* on associe le fils bidon à -1 */
 
 	    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 					  ligne_sous_imputation,
@@ -732,7 +732,7 @@ void remplit_arbre_imputation ( void )
 	liste_imputation_tmp = liste_imputation_tmp -> next;
     }
 
-    /*   on a fini de mettre les catgories, on met ici les ops sans catg */
+    /*   on a fini de mettre les catégories, on met ici les opés sans catég */
 
     if ( tab_montant_imputation[0] )
     {
@@ -806,7 +806,7 @@ void remplit_arbre_imputation ( void )
 					FALSE,
 					FALSE );
 
-	/* on associe le fils bidon  -1 */
+	/* on associe le fils bidon à -1 */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 				      ligne,
@@ -845,8 +845,8 @@ void remplit_arbre_imputation ( void )
 
 /* **************************************************************************************************** */
 /* Fonction ouverture_node_imputation */
-/* appel lorsqu'on ouvre une imputation, sous imputation ou le compte d'une imputation */
-/* remplit ce qui doit tre affich */
+/* appeléé lorsqu'on ouvre une imputation, sous imputation ou le compte d'une imputation */
+/* remplit ce qui doit être affiché */
 /* **************************************************************************************************** */
 
 void ouverture_node_imputation ( GtkWidget *arbre,
@@ -864,7 +864,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
     if ( row->level == 1 )
 	return;
 
-    /*   si le fiston = -1, c'est qu'il n'a pas encore t cr */
+    /*   si le fiston = -1, c'est qu'il n'a pas encore été créé */
     /* dans le cas contraire, on vire */
 
     if ( GPOINTER_TO_INT ( gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
@@ -877,16 +877,16 @@ void ouverture_node_imputation ( GtkWidget *arbre,
     gtk_clist_freeze ( GTK_CLIST ( arbre_imputation ));
 
 
-    /* on commence par virer la ligne bidon qui tait attache  ce noeud */
+    /* on commence par virer la ligne bidon qui était attachée à ce noeud */
 
     gtk_ctree_remove_node ( GTK_CTREE ( arbre_imputation ),
 			    row -> children );
 
-    /* sparation entre ouverture de sous-imputation ( 2 ) et ouverture de compte ( 3 ) */
+    /* séparation entre ouverture de sous-imputation ( 2 ) et ouverture de compte ( 3 ) */
 
     if ( row -> level == 2 )
     {
-	/* c'est une ouverture de sous imputation, on rcupre sa structure  */
+	/* c'est une ouverture de sous imputation, on récupère sa structure  */
 
 	struct struct_imputation *imputation;
 	struct struct_sous_imputation *sous_imputation;
@@ -911,7 +911,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
 	    no_sous_imputation = 0;
 	}
 
-	/* on va scanner tous les comptes, ds qu'une imputation correspondant  l'imput slectionne est trouv */
+	/* on va scanner tous les comptes, dès qu'une imputation correspondant à l'imput sélectionnée est trouvé */
 	/* on affiche le nom du compte */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -966,7 +966,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
 							     FALSE,
 							     FALSE );
 
-		    /* associe le no de compte  la ligne du compte */
+		    /* associe le no de compte à la ligne du compte */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 						  node_insertion,
@@ -986,7 +986,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
 							     FALSE,
 							     FALSE );
 
-		    /* on associe le fils bidon  -1 */
+		    /* on associe le fils bidon à -1 */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 						  node_insertion,
@@ -1005,7 +1005,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
     else
     {
 	/* c'est une ouverture d'un compte */
-	/*       cette fois, on fait le tour de toutes les ops du compte pour afficher celles qui correspondent  la imputation */
+	/*       cette fois, on fait le tour de toutes les opés du compte pour afficher celles qui correspondent à la imputation */
 
 	struct struct_imputation *imputation;
 	struct struct_sous_imputation *sous_imputation;
@@ -1107,7 +1107,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
 							 FALSE,
 							 FALSE );
 
-		/* on associe  cette op l'adr de sa struct */
+		/* on associe à cette opé l'adr de sa struct */
 
 		gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 					      node_insertion,
@@ -1283,15 +1283,15 @@ gboolean expand_selected_ib (  )
 	   ||
 	   ( GTK_CTREE_ROW ( ( GTK_CLIST ( arbre_imputation ) -> selection ) -> data ) -> level == 3
 	     &&
-	     !gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
-					    GTK_CTREE_ROW ( GTK_CTREE_ROW (( GTK_CLIST ( arbre_imputation ) -> selection ) -> data ) -> parent ) -> parent ))))
+	     gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
+					   GTK_CTREE_ROW ( GTK_CTREE_ROW (( GTK_CLIST ( arbre_imputation ) -> selection ) -> data ) -> parent ) -> parent ) > 0)))
     {
-	/* passage sur le compte concern */
+	/* passage sur le compte concerné */
 
 	operation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
 						  GTK_CTREE_NODE ( ( GTK_CLIST ( arbre_imputation ) -> selection ) -> data ) );
 
-	/* si c'est une op de ventilation, on se place sur l'op ventile correspondante */
+	/* si c'est une opé de ventilation, on se place sur l'opé ventilée correspondante */
 
 	if ( operation -> no_operation_ventilee_associee )
 	{
@@ -1380,8 +1380,8 @@ void clique_sur_modifier_imputation ( void )
     GtkCTreeNode *node;
 
 
-    /* si c'est une imputation et si c'est une modif du nom, on doit rafficher la liste des imputation et les listes des ops, sinon, on change juste la imputation et */
-    /* met  jour les listes de imputations */
+    /* si c'est une imputation et si c'est une modif du nom, on doit réafficher la liste des imputation et les listes des opés, sinon, on change juste la imputation et */
+    /* met à jour les listes de imputations */
     /* si c'est une sous imputation, c'est obligmy_atoirement un changement de nom */
 
     if ( gtk_object_get_data ( GTK_OBJECT (  entree_nom_imputation ),
@@ -1536,7 +1536,7 @@ void supprimer_imputation ( void )
     imputation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
 					       node );
 
-    /* fait le tour des ops pour en trouver une qui a cette catgorie */
+    /* fait le tour des opés pour en trouver une qui a cette catégorie */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
     ope_trouvee = 0;
@@ -1675,7 +1675,7 @@ void supprimer_imputation ( void )
 	    pointeur = pointeur -> next;
 	}
 
-	/*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+	/*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
 	liste_combofix = g_slist_append ( liste_combofix,
 					  liste_imputation_debit );
@@ -1765,7 +1765,7 @@ retour_dialogue:
 	}
 
 
-	/* on fait le tour des ops pour mettre le nouveau numro de imputation et sous_imputation */
+	/* on fait le tour des opés pour mettre le nouveau numéro de imputation et sous_imputation */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -1791,7 +1791,7 @@ retour_dialogue:
 	    p_tab_nom_de_compte_variable++;
 	}
 
-	/* fait le tour des chances pour mettre le nouveau numro de imputation et sous_imputation  */
+	/* fait le tour des échéances pour mettre le nouveau numéro de imputation et sous_imputation  */
 
 	liste_tmp = gsliste_echeances;
 
@@ -1825,6 +1825,7 @@ retour_dialogue:
 
     liste_struct_imputation = g_slist_remove ( liste_struct_imputation,
 					       imputation );
+    free ( imputation );
     nb_enregistrements_imputations--;
 
     enleve_selection_ligne_imputation();
@@ -1864,7 +1865,7 @@ void supprimer_sous_imputation ( void )
     imputation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
 					       node );
 
-    /* fait le tour des ops pour en trouver une qui a cette sous-catgorie */
+    /* fait le tour des opés pour en trouver une qui a cette sous-catégorie */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
     ope_trouvee = 0;
@@ -2004,7 +2005,7 @@ void supprimer_sous_imputation ( void )
 	    pointeur = pointeur -> next;
 	}
 
-	/*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+	/*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
 	liste_combofix = g_slist_append ( liste_combofix,
 					  liste_imputation_debit );
@@ -2064,7 +2065,7 @@ retour_dialogue:
 		goto retour_dialogue;
 	    }
 
-	    /* rcupre les no de imputation et sous imputation */
+	    /* récupère les no de imputation et sous imputation */
 
 	    split_imputation = g_strsplit ( gtk_combofix_get_text ( GTK_COMBOFIX ( combofix )),
 					    " : ",
@@ -2094,7 +2095,7 @@ retour_dialogue:
 	}
 
 
-	/* on fait le tour des ops pour mettre le nouveau numro de imputation et sous_imputation */
+	/* on fait le tour des opés pour mettre le nouveau numéro de imputation et sous_imputation */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -2122,7 +2123,7 @@ retour_dialogue:
 	    p_tab_nom_de_compte_variable++;
 	}
 
-	/* fait le tour des chances pour mettre le nouveau numro de imputation et sous_imputation  */
+	/* fait le tour des échéances pour mettre le nouveau numéro de imputation et sous_imputation  */
 
 	liste_tmp = gsliste_echeances;
 
@@ -2158,7 +2159,7 @@ retour_dialogue:
 
     imputation -> liste_sous_imputation = g_slist_remove ( imputation -> liste_sous_imputation,
 							   sous_imputation );
-
+    free ( sous_imputation );
 
     enleve_selection_ligne_imputation();
 
@@ -2174,8 +2175,8 @@ retour_dialogue:
 
 /***********************************************************************************************************/
 /* Routine creation_liste_imputations */
-/* appele lors d'un nouveau fichier */
-/* cre la liste des catgories  partir de la liste ci dessus */
+/* appelée lors d'un nouveau fichier */
+/* crée la liste des catégories à partir de la liste ci dessus */
 /* en fait, merge la liste de base avec rien */
 /***********************************************************************************************************/
 
@@ -2193,12 +2194,12 @@ void creation_liste_imputations ( void )
 
 
 /***********************************************************************************************************/
-/*  Routine qui cre la liste des catgories pour les combofix du formulaire et de la ventilation */
-/* c'est  dire 3 listes dans 1 liste : */
-/* la premire contient les catgories de dbit */
-/* la seconde contient les catgories de crdit */
-/* la troisime contient les catgories spciales ( virement, retrait, ventilation ) */
-/* la ventilation n'apparait pas dans les chances ( et dans la ventilation ) */
+/*  Routine qui crée la liste des catégories pour les combofix du formulaire et de la ventilation */
+/* c'est à dire 3 listes dans 1 liste : */
+/* la première contient les catégories de débit */
+/* la seconde contient les catégories de crédit */
+/* la troisième contient les catégories spéciales ( virement, retrait, ventilation ) */
+/* la ventilation n'apparait pas dans les échéances ( et dans la ventilation ) */
 /***********************************************************************************************************/
 
 void creation_liste_imputation_combofix ( void )
@@ -2252,7 +2253,7 @@ void creation_liste_imputation_combofix ( void )
     }
 
 
-    /*   on ajoute les listes des crdits / dbits  la liste du combofix du formulaire */
+    /*   on ajoute les listes des crédits / débits à la liste du combofix du formulaire */
 
     liste_imputations_combofix = g_slist_append ( liste_imputations_combofix,
 						  liste_imputation_debit );
@@ -2266,8 +2267,8 @@ void creation_liste_imputation_combofix ( void )
 
 /***********************************************************************************************************/
 /* Fonction mise_a_jour_imputation */
-/* recre les listes de catgories des combofix */
-/* et remet les combofix  jour */
+/* recrée les listes de catégories des combofix */
+/* et remet les combofix à jour */
 /***********************************************************************************************************/
 
 void mise_a_jour_imputation ( void )
@@ -2302,8 +2303,8 @@ void mise_a_jour_imputation ( void )
 
 /***********************************************************************************************************/
 /* Fonction ajoute_nouvelle_imputation */
-/* appele pour ajouter une nouvelle catg  la liste des catg */
-/* entre : la nouvelle catg */
+/* appelée pour ajouter une nouvelle catég à la liste des catég */
+/* entrée : la nouvelle catég */
 /* retour : l'adr de la struct */
 /***********************************************************************************************************/
 
@@ -2339,8 +2340,8 @@ struct struct_imputation *ajoute_nouvelle_imputation ( gchar *imputation )
 
 /***********************************************************************************************************/
 /* Fonction ajoute_nouvelle_sous_imputation */
-/* appele pour ajouter une nouvelle sous catg  une catg */
-/* entre : la nouvelle sous catg et l'adr de la struct de la catg correspondante */
+/* appelée pour ajouter une nouvelle sous catég à une catég */
+/* entrée : la nouvelle sous catég et l'adr de la struct de la catég correspondante */
 /* retour : l'adr de la struct */
 /***********************************************************************************************************/
 
@@ -2376,7 +2377,7 @@ struct struct_sous_imputation *ajoute_nouvelle_sous_imputation ( gchar *sous_imp
 /***************************************************************************************************/
 void fusion_categories_imputation ( void )
 {
-    /* on fait le tour des catgories et on ajoute aux imputations celles qui n'existent pas */
+    /* on fait le tour des catégories et on ajoute aux imputations celles qui n'existent pas */
 
     GSList *liste_tmp;
 
@@ -2394,25 +2395,25 @@ void fusion_categories_imputation ( void )
 
 	categorie = liste_tmp -> data;
 
-	/* vrifie si une imputation du nom de la catgorie existe */
+	/* vérifie si une imputation du nom de la catégorie existe */
 
 	result = g_slist_find_custom ( liste_struct_imputation,
 				       categorie -> nom_categ,
 				       (GCompareFunc) recherche_imputation_par_nom );
 
 	if ( result )
-	    /* l'imputation existe, on la rcupre */
+	    /* l'imputation existe, on la récupère */
 	    imputation = result -> data;
 	else
 	{
-	    /* 	  l'imputation n'existe pas, on la cre */
+	    /* 	  l'imputation n'existe pas, on la crée */
 
 	    imputation = ajoute_nouvelle_imputation ( categorie -> nom_categ );
 	    if ( imputation )
 	      imputation -> type_imputation = categorie -> type_categ;
 	}
 
-	/* on fait maintenant la comparaison avec les sous catg et les sous imputations */
+	/* on fait maintenant la comparaison avec les sous catég et les sous imputations */
 
 	liste_sous_tmp = categorie -> liste_sous_categ;
 
@@ -2427,7 +2428,7 @@ void fusion_categories_imputation ( void )
 					   (GCompareFunc) recherche_sous_imputation_par_nom );
 
 	    if ( !result )
-		/* 	  la sous imputation n'existe pas, on la cre */
+		/* 	  la sous imputation n'existe pas, on la crée */
 		ajoute_nouvelle_sous_imputation ( sous_categ -> nom_sous_categ,
 						  imputation );
 
@@ -2436,7 +2437,7 @@ void fusion_categories_imputation ( void )
 	liste_tmp = liste_tmp -> next;
     }
 
-    /* on met  jour les listes */
+    /* on met à jour les listes */
 
     mise_a_jour_imputation ();
     remplit_arbre_imputation ();
@@ -2449,7 +2450,7 @@ void fusion_categories_imputation ( void )
 
 
 /* **************************************************************************************************** */
-/* cre un tableau de imputation et de sous imputation aussi gds que le nb de tiers */
+/* crée un tableau de imputation et de sous imputation aussi gds que le nb de tiers */
 /* et les renvoie dans un tab de 2 pointeurs */
 /* **************************************************************************************************** */
 
@@ -2457,9 +2458,9 @@ void calcule_total_montant_imputation ( void )
 {
     gint i;
 
-    /* on cre les tableaux de montant */
+    /* on crée les tableaux de montant */
 
-    /* le +1 pour reserver le [0] pour aucune catgorie */
+    /* le +1 pour reserver le [0] pour aucune catégorie */
 
     tab_montant_imputation = calloc ( nb_enregistrements_imputations + 1,
 				      sizeof ( gfloat ));
@@ -2489,23 +2490,23 @@ void calcule_total_montant_imputation ( void )
 
 	    operation = liste_tmp -> data;
 
-	    /* on commence par calculer le montant dans la devise demande */
+	    /* on commence par calculer le montant dans la devise demandée */
 
 	    montant = calcule_montant_devise_renvoi ( operation -> montant,
-						      no_devise_totaux_tiers,
+						      no_devise_totaux_ib,
 						      operation -> devise,
 						      operation -> une_devise_compte_egale_x_devise_ope,
 						      operation -> taux_change,
 						      operation -> frais_change );
 
-	    /* on traite ensuite l'opration */
+	    /* on traite ensuite l'opération */
 
 	    if ( operation -> imputation )
 	    {
 		struct struct_imputation *imputation;
 		GSList * occurence;
 
-		/* il y a une catgorie */
+		/* il y a une catégorie */
 
 		occurence = g_slist_find_custom ( liste_struct_imputation,
 						  GINT_TO_POINTER ( operation -> imputation ),
@@ -2519,7 +2520,7 @@ void calcule_total_montant_imputation ( void )
 		    place_imputation = g_slist_index ( liste_struct_imputation,
 						       imputation );
 
-		    /* cre la place pour les sous catg de cette imputation si ce n'est dj fait */
+		    /* crée la place pour les sous catég de cette imputation si ce n'est déjà fait */
 
 		    if ( !tab_montant_sous_imputation[place_imputation] )
 		    {
@@ -2527,7 +2528,7 @@ void calcule_total_montant_imputation ( void )
 
 			nb_sous_imputation = g_slist_length ( imputation -> liste_sous_imputation );
 
-			/* on rserve nb_sous_imputation + 1 pour aucune sous imputation qui sera en [0] */
+			/* on réserve nb_sous_imputation + 1 pour aucune sous imputation qui sera en [0] */
 
 			tab_montant_sous_imputation[place_imputation] = calloc ( nb_sous_imputation + 1,
 										 sizeof ( float ));
@@ -2538,7 +2539,7 @@ void calcule_total_montant_imputation ( void )
 		    tab_montant_imputation[place_imputation+1] = tab_montant_imputation[place_imputation+1] + montant;
 		    nb_ecritures_par_imputation[place_imputation+1]++;
 
-		    /* on ajoute maintenant le montant  la sous imputation si elle existe */
+		    /* on ajoute maintenant le montant à la sous imputation si elle existe */
 
 		    if ( operation -> sous_imputation )
 		    {
@@ -2608,7 +2609,7 @@ gchar *calcule_total_montant_imputation_par_compte ( gint imputation, gint sous_
 	    gdouble montant;
 
 	    montant = calcule_montant_devise_renvoi ( operation -> montant,
-						      no_devise_totaux_tiers,
+						      no_devise_totaux_ib,
 						      operation -> devise,
 						      operation -> une_devise_compte_egale_x_devise_ope,
 						      operation -> taux_change,
@@ -2623,7 +2624,7 @@ gchar *calcule_total_montant_imputation_par_compte ( gint imputation, gint sous_
     if ( retour_int )
 	return ( g_strdup_printf ( _("%4.2f %s"),
 				   retour_int,
-				   devise_name_by_no ( no_devise_totaux_tiers ) ));
+				   devise_name_by_no ( no_devise_totaux_ib ) ));
     else
 	return ( NULL );
 }
@@ -2642,14 +2643,14 @@ void appui_sur_ajout_imputation ( void )
 					     COLON(_("Enter the name of the new budgetary line")) )))
 	return;
 
-    /* on l'ajoute  la liste des ops */
+    /* on l'ajoute à la liste des opés */
 
     nouvelle_imputation = ajoute_nouvelle_imputation ( nom_imputation );
 
     if ( ! nouvelle_imputation )
       return;
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour éviter de toute la réafficher */
 
     text[0] = nouvelle_imputation -> nom_imputation;
     text[1] = NULL;
@@ -2668,7 +2669,7 @@ void appui_sur_ajout_imputation ( void )
 				    FALSE,
 				    FALSE );
 
-    /* on associe  ce imputation  l'adr de sa struct */
+    /* on associe à ce imputation à l'adr de sa struct */
 
     gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 				  ligne,
@@ -2699,19 +2700,19 @@ void appui_sur_ajout_sous_imputation ( void )
 						  COLON(_("Enter the name of the new sub-budgetary line")) )))
 	return;
 
-    /* rcupre le node parent */
+    /* récupère le node parent */
 
     node_parent = GTK_CLIST ( arbre_imputation ) -> selection -> data;
 
     while ( GTK_CTREE_ROW ( node_parent ) -> level != 1 )
 	node_parent = GTK_CTREE_ROW ( node_parent ) -> parent;
 
-    /* on rcupre l'imputation parente */
+    /* on récupère l'imputation parente */
 
     imputation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_imputation ),
 					       node_parent );
 
-    /* on l'ajoute  la liste des ops */
+    /* on l'ajoute à la liste des opés */
 
     nouvelle_sous_imputation = ajoute_nouvelle_sous_imputation ( nom_sous_imputation,
 								 imputation );
@@ -2719,8 +2720,8 @@ void appui_sur_ajout_sous_imputation ( void )
     if ( ! nouvelle_sous_imputation )
       return;
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter
-       de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour éviter
+       de toute la réafficher */
 
     text[0] = nouvelle_sous_imputation -> nom_sous_imputation;
     text[1] = NULL;
@@ -2739,7 +2740,7 @@ void appui_sur_ajout_sous_imputation ( void )
 				    FALSE,
 				    FALSE );
 
-    /* on associe  ce imputation  l'adr de sa struct */
+    /* on associe à ce imputation à l'adr de sa struct */
 
     gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_imputation ),
 				  ligne,
@@ -2778,7 +2779,7 @@ void exporter_ib ( void )
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
-	    /* vrification que c'est possible */
+	    /* vérification que c'est possible */
 
 	    if ( !strlen ( nom_ib ))
 		return;
@@ -2847,7 +2848,7 @@ void importer_ib ( void )
 
     gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
-    /* vrification que c'est possible */
+    /* vérification que c'est possible */
 
     if ( !strlen ( nom_ib ))
 	return;
@@ -2865,13 +2866,13 @@ void importer_ib ( void )
 			 GTK_SIGNAL_FUNC ( gtk_signal_emit_stop_by_name ),
 			 "destroy" );
 
-    /* pour viter un warning lors de la compil */
+    /* pour éviter un warning lors de la compil */
 
     bouton_merge_remplace = NULL;
 
     if ( no_derniere_operation )
     {
-	/*       il y a dj des oprations dans le fichier, on ne peut que fusionner */
+	/*       il y a déjà des opérations dans le fichier, on ne peut que fusionner */
 
 	label = gtk_label_new ( _("File already contains transactions, the two budgetary lines lists will be merged." ));
 	gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ),
