@@ -1,12 +1,12 @@
 /* *******************************************************************************/
 /*                                 GRISBI                                        */
-/* Programme de gestion financire personnelle                                   */
+/* Programme de gestion financière personnelle                                   */
 /*           	  license : GPL                                                  */
 /*                                                                               */
-/*     Copyright (C)    2000-2003 Cdric Auger (cedric@grisbi.org)               */
+/*     Copyright (C)    2000-2003 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003 Benjamin Drieu (bdrieu@april.org)                   */
 /*                      http://www.grisbi.org                                    */
-/*      Version : 0.5.0                                                           */
+/*      Version : 0.5.5                                                           */
 /*                                                                               */
 /* *******************************************************************************/
 
@@ -30,7 +30,7 @@
 
 
 
-/* Fichier de base contenant la procdure main */
+/* Fichier de base contenant la procédure main */
 
 
 #include "include.h"
@@ -50,10 +50,16 @@
 #include "traitement_variables.h"
 #include "utils.h"
 
+#ifdef _WIN32
+// Special include for Windows only
+#include "win32utils.h"
+#include "win32gtkutils.h"
+#endif
 
 
 
-/* vbox ajoute dans la fenetre de base, contient le menu et la fenetre d'utilisation */
+
+/* vbox ajoutée dans la fenetre de base, contient le menu et la fenetre d'utilisation */
 
 GtkWidget *window_vbox_principale;
 GtkWidget *menu_general;
@@ -61,7 +67,7 @@ GtkItemFactory *item_factory_menu_general;
 
 
 /***********************************************************************************************
- ** Dbut de la procdure principale **
+ ** Début de la procédure principale **
  ***********************************************************************************************/
 
 /**                                                                              
@@ -79,35 +85,37 @@ int main (int argc, char *argv[])
 #endif
     gint demande_page;
 
-    /* on ajoute la possibilit de mettre l'option --onglet dans la ligne de commande */
-    /* Permet d'ouvrir le fichier demand sur l'onglet dsir  */
-    /* w=-1 : fentre de configuration */
-    /*    x=numro de l'onglet de configuration (0-9) */
+    /* on ajoute la possibilité de mettre l'option --onglet dans la ligne de commande */
+    /* Permet d'ouvrir le fichier demandé sur l'onglet désiré  */
+    /* w=-1 : fenêtre de configuration */
+    /*    x=numéro de l'onglet de configuration (0-9) */
     /* w=0 : onglet d'accueil (identique sans argument) */
-    /* w=1 : onglet des oprations */
-    /* w=2 : onglet de l'chancier */
+    /* w=1 : onglet des opérations */
+    /* w=2 : onglet de l'échéancier */
     /* w=3 : onglet des comptes */
     /* w=4 : onglet des tiers */
-    /* w=5 : onglet des catgories */
-    /* w=6 : onglet des imputations budgtaires */
-    /* w=7 : onglet des tats */
-    /*   x=numro de l'tat  afficher */
-    /*   y=absent pour rester sur l'tat, numro de l'onglet principal de personnalisation sinon */
-    /*   z=numro de l'onglet secondaire de la personnalisation */
+    /* w=5 : onglet des catégories */
+    /* w=6 : onglet des imputations budgétaires */
+    /* w=7 : onglet des états */
+    /*   x=numéro de l'état à afficher */
+    /*   y=absent pour rester sur l'état, numéro de l'onglet principal de personnalisation sinon */
+    /*   z=numéro de l'onglet secondaire de la personnalisation */
 
     /*   Exemples : */
     /* grisbi --onglet=3 mes_comptes */
-    /* place grisbi directement sur l'chancier du fichier mes_comptes */
+    /* place grisbi directement sur l'échéancier du fichier mes_comptes */
     /* grisbi --onglet=-1,3 mes_comptes */
     /* affiche la configuration de grisbi et la place sur Affichage */
     /* grisbi --onglet=7,2 mes_comptes */
-    /* affiche le 3me tat */
+    /* affiche le 3ème état */
     /* grisbi --onglet=7,2,2,2 mes_comptes */
-    /* affiche l'onglet opration de l'onglet Affichage des donnes du 3me tat */
+    /* affiche l'onglet opération de l'onglet Affichage des données du 3ème état */
 
 #ifdef _WIN32
     /* we store the path of the running file to use it for pixmaps, help and locales .... */
     win32_set_app_path(argv[0]);
+    /* needed to be able to use the "common" installation of GTK libraries */
+    win32_make_sure_the_gtk2_dlls_path_is_in_PATH(); 
 #endif
 
 	/*   setlocale (LC_ALL, ""); */
@@ -120,7 +128,7 @@ int main (int argc, char *argv[])
 
 	gtk_init ( &argc, &argv );
 
-	/* on commence par dtourner le signal SIGSEGV */
+	/* on commence par détourner le signal SIGSEGV */
 #ifndef _WIN32
     /* sauf sous Windows*/
 	memset ( &sig_sev, 0, sizeof ( struct sigaction ));
@@ -132,7 +140,7 @@ int main (int argc, char *argv[])
 	    printf (_("Error on sigaction: SIGSEGV won't be trapped\n"));
 #endif
 
-	/*  Cration de la fentre principale */
+	/*  Création de la fenêtre principale */
 
 	window = gtk_window_new ( GTK_WINDOW_TOPLEVEL );
 
@@ -150,7 +158,7 @@ int main (int argc, char *argv[])
 				TRUE,
 				FALSE );
 
-	/* 	cration de la pixmap du logiciel */
+	/* 	création de la pixmap du logiciel */
 
 	gtk_window_set_default_icon_from_file ( g_strconcat(PIXMAPS_DIR,
                                                             C_DIRECTORY_SEPARATOR,
@@ -164,7 +172,7 @@ int main (int argc, char *argv[])
 			    window_vbox_principale );
 	gtk_widget_show ( window_vbox_principale );
 
-	/*   cration des menus */
+	/*   création des menus */
 
 	menu_general = init_menus ( window_vbox_principale );
 	gtk_box_pack_start ( GTK_BOX ( window_vbox_principale ),
@@ -173,7 +181,7 @@ int main (int argc, char *argv[])
 			     FALSE,
 			     0 );
 
-	/* on grise les fonctions inutiles au dpart */
+	/* on grise les fonctions inutiles au départ */
 
 	init_variables ( FALSE );
 	style_label_nom_compte = NULL;
@@ -185,7 +193,7 @@ int main (int argc, char *argv[])
 
 	affiche_derniers_fichiers_ouverts ();
 
-	/*   si la taille avait dj t sauve, on remet l'ancienne taille 
+	/*   si la taille avait déjà été sauvée, on remet l'ancienne taille à
 	     la fenetre */
 	if ( largeur_window && hauteur_window )
 	    gtk_window_set_default_size ( GTK_WINDOW ( window ),
@@ -198,7 +206,7 @@ int main (int argc, char *argv[])
 
 	gtk_widget_show ( window );
 
-	/*   on applique la fonte aux listes si ncessaire */
+	/*   on applique la fonte aux listes si nécessaire */
 
 	initialisation_couleurs_listes ();
 
@@ -223,7 +231,7 @@ int main (int argc, char *argv[])
 	    gtk_style_set_font (style_gris, NULL);
 	}
 
-	/* on vrifie les arguments de ligne de commande */
+	/* on vérifie les arguments de ligne de commande */
 
 	demande_page = 0;
 
@@ -232,7 +240,7 @@ int main (int argc, char *argv[])
 	    case 1:
 		/* il n'y a aucun argument */
 
-		/* ouvre le dernier fichier s'il existe et si c'est demand */
+		/* ouvre le dernier fichier s'il existe et si c'est demandé */
 
 		if ( etat.dernier_fichier_auto
 		     &&
@@ -243,7 +251,7 @@ int main (int argc, char *argv[])
 		break;
 
 	    case 2:
-		/* l'argument peut tre soit --onglet, soit le fichier  ouvrir */
+		/* l'argument peut être soit --onglet, soit le fichier à ouvrir */
 
 		if ( !strncmp ( argv[1],
 				"--",
@@ -251,7 +259,7 @@ int main (int argc, char *argv[])
 		{
 		    demande_page = 1;
 
-		    /* ouvre le dernier fichier s'il existe et si c'est demand */
+		    /* ouvre le dernier fichier s'il existe et si c'est demandé */
 
 		    if ( etat.dernier_fichier_auto
 			 &&
@@ -269,8 +277,8 @@ int main (int argc, char *argv[])
 
 	    case 3:
 		/* il y a --onglet et un nom de fichier */
-		/*       il faut que argv[1] commence par -- sinon on considre que c'est le nom de fichier */
-		/* et on oublie le 2me argument */
+		/*       il faut que argv[1] commence par -- sinon on considère que c'est le nom de fichier */
+		/* et on oublie le 2ème argument */
 
 		if ( !strncmp ( argv[1],
 				"--",
@@ -278,7 +286,7 @@ int main (int argc, char *argv[])
 		{
 		    demande_page = 1;
 
-		    /* ouvre le fichier demand */
+		    /* ouvre le fichier demandé */
 
 		    nom_fichier_comptes = argv[2];
 		    ouverture_confirmee();
@@ -291,7 +299,7 @@ int main (int argc, char *argv[])
 		break;
 	}
 
-	/*    ce niveau, le fichier doit tre charg, on met sur l'onglet demand si ncessaire */
+	/*   à ce niveau, le fichier doit être chargé, on met sur l'onglet demandé si nécessaire */
 
 	if ( nb_comptes
 	     &&
@@ -303,7 +311,7 @@ int main (int argc, char *argv[])
 					  "=",
 					  2 );
 
-	    /*       si le 2me argument retourn est null, c'est qu'on avait marqu --onglet= */
+	    /*       si le 2ème argument retourné est null, c'est qu'on avait marqué --onglet= */
 	    /* et dans ce cas on fait rien */
 
 	    if ( split_argument[1] )
@@ -321,7 +329,7 @@ int main (int argc, char *argv[])
 		    case -1:
 			/* on demande l'onglet de configuration */
 
-			/* on affiche l'onglet du 2me argument s'il existe */
+			/* on affiche l'onglet du 2ème argument s'il existe */
 
 			if ( split_chiffres[1] )
 			    preferences ( my_atoi ( split_chiffres[1] ));
@@ -343,12 +351,12 @@ int main (int argc, char *argv[])
 			break;
 
 		    case 7:
-			/* on demande l'onglet des tats  */
+			/* on demande l'onglet des états  */
 
 			gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general ),
 						my_atoi ( split_chiffres[0] ));
 
-			/* s'il y a un chiffre ensuite, on ouvre l'tat correspondant  ce chiffre */
+			/* s'il y a un chiffre ensuite, on ouvre l'état correspondant à ce chiffre */
 
 			if ( split_chiffres[1]
 			     &&
@@ -359,7 +367,7 @@ int main (int argc, char *argv[])
 			    liste_tmp = g_slist_nth ( liste_struct_etats,
 						      my_atoi ( split_chiffres[1] ));
 
-			    /* si on a slectionn un tat qui n'existait pas, on ouvre le 1er */
+			    /* si on a sélectionné un état qui n'existait pas, on ouvre le 1er */
 
 			    if ( !liste_tmp )
 				liste_tmp = liste_struct_etats;
@@ -414,8 +422,10 @@ int main (int argc, char *argv[])
 			    }
 			}
 			break;
-		}
+		    }
+		g_strfreev( split_chiffres );
 	    }
+	    g_strfreev( split_argument );
 	}
 
 
