@@ -1,6 +1,6 @@
 /* permet la configuration du logiciel */
 
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org) */
 /* 			http://www.grisbi.org */
 
@@ -260,6 +260,14 @@ void preferences ( gint page )
 			-1);
     gtk_notebook_append_page (preference_frame, tab_display_reconciliation(), NULL);
 
+    gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter2, &iter);
+    gtk_tree_store_set (GTK_TREE_STORE (preference_tree_model),
+			&iter2,
+			0, _("Totals currencies"),
+			1, TOTALS_PAGE,
+			-1);
+    gtk_notebook_append_page (preference_frame, tab_display_totals(), NULL);
+
 
     /* Resources subtree */
     gtk_tree_store_append (GTK_TREE_STORE (preference_tree_model), &iter, NULL);
@@ -333,7 +341,7 @@ void preferences ( gint page )
 
 
 /* ************************************************************************************************************** */
-/* callback appel quand on slectionne un membre de la liste */
+/* callback appelé quand on sélectionne un membre de la liste */
 /* ************************************************************************************************************** */
 gboolean selectionne_liste_preference ( GtkTreeSelection *selection,
 					GtkTreeModel *model )
@@ -408,9 +416,9 @@ GtkWidget *onglet_messages_and_warnings ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0 );
 
-    entree_jours = new_spin_button ( &(decalage_echeance),
-				     /* Limit to one year */
-				     0, 365, 1, 5, 1, 1, 0, NULL ); 
+    entree_jours = new_int_spin_button ( &(decalage_echeance),
+					 /* Limit to one year */
+					 0, 365, 1, 5, 1, 1, 0, NULL ); 
     gtk_box_pack_start ( GTK_BOX ( hbox ), entree_jours,
 			 FALSE, FALSE, 0 );
 
@@ -497,8 +505,8 @@ GtkWidget *onglet_fichier ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0 );
     spin_button_compression_fichier = 
-	new_spin_button ( &(compression_fichier),
-			  0.0, 9.0, 1.0, 5.0, 1.0, 1.0, 0, NULL );
+	new_int_spin_button ( &(compression_fichier),
+			      0.0, 9.0, 1.0, 5.0, 1.0, 1.0, 0, NULL );
 
     gtk_box_pack_start ( GTK_BOX ( hbox ), spin_button_compression_fichier,
 			 FALSE, FALSE, 0 );
@@ -511,8 +519,8 @@ GtkWidget *onglet_fichier ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0 );
     spin_button_derniers_fichiers_ouverts = 
-	new_spin_button ( &(nb_max_derniers_fichiers_ouverts),
-			  0.0, 20.0, 1.0, 5.0, 1.0, 1.0, 0, NULL );
+	new_int_spin_button ( &(nb_max_derniers_fichiers_ouverts),
+			      0.0, 20.0, 1.0, 5.0, 1.0, 1.0, 0, NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), spin_button_derniers_fichiers_ouverts,
 			 FALSE, FALSE, 0 );
 
@@ -540,7 +548,7 @@ GtkWidget *onglet_fichier ( void )
 	/* Ugly dance ... */
 	checkbox_set_value ( bouton_demande_backup, &dummy, FALSE );
 
-	/* Mise en forme de l'entre du chemin de la backup */
+	/* Mise en forme de l'entrée du chemin de la backup */
 	hbox = gtk_hbox_new ( FALSE, 5 );
 	gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox,
 			     FALSE, FALSE, 0 );
@@ -588,8 +596,8 @@ GtkWidget *onglet_fichier ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label,
 			 FALSE, FALSE, 0 );
 
-    spin_button_compression_backup = new_spin_button ( &(compression_backup),
-						       0, 9, 1, 5, 1, 1, 0, NULL );
+    spin_button_compression_backup = new_int_spin_button ( &(compression_backup),
+							   0, 9, 1, 5, 1, 1, 0, NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), spin_button_compression_backup,
 			 FALSE, FALSE, 0 );
 
@@ -630,7 +638,7 @@ void changement_choix_backup ( GtkWidget *bouton,
 
 
 /* **************************************************************************************************************************** */
-/* fonction qui ferme la fentre prfrences */
+/* fonction qui ferme la fenêtre préférences */
 /* **************************************************************************************************************************** */
 void fermeture_preferences ( GtkWidget *button,
 			     gint page,
