@@ -1,7 +1,7 @@
 /* ce fichier de la gestion du format qif */
 
 
-/*     Copyright (C) 2000-2003  Cdric Auger */
+/*     Copyright (C) 2000-2003  Cédric Auger */
 /* 			cedric@grisbi.org */
 /* 			http://www.grisbi.org */
 
@@ -49,7 +49,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
     gint pas_le_premier_compte = 0;
     gchar *type;
 
-    /* fichier pointe sur le fichier qui a t reconnu comme qif */
+    /* fichier pointe sur le fichier qui a été reconnu comme qif */
 
     rewind ( fichier );
     
@@ -60,8 +60,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
     {
 	do
 	{
-/* 	    si ce n'est pas le premier compte du fichier, pointeur_char est dj sur la ligne du nouveau compte */
-/* 	    tans que pas_le_premier_compte = 1 ; du coup on le met  2 s'il tait  1 */
+/* 	    si ce n'est pas le premier compte du fichier, pointeur_char est déjà sur la ligne du nouveau compte */
+/* 	    tans que pas_le_premier_compte = 1 ; du coup on le met à 2 s'il était à 1 */
 
 	    if ( pas_le_premier_compte != 1 )
 	    {
@@ -83,8 +83,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 				   "!Type",
 				   5 ))
 	    {
-		/* 	     ce niveau on est sur un !type ou !Type, on vrifie maintenant qu'on supporte */
-		/* 		bien ce type ; si c'est le cas, on met retour  -1 */
+		/* 	    à ce niveau on est sur un !type ou !Type, on vérifie maintenant qu'on supporte */
+		/* 		bien ce type ; si c'est le cas, on met retour à -1 */
 
 		tab = g_strsplit ( pointeur_char,
 				   ":",
@@ -122,7 +122,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		&&
 		retour != -2 );
 
-	/*     si on est dj  la fin du fichier,on se barre */
+	/*     si on est déjà à la fin du fichier,on se barre */
 
 	if ( retour == EOF )
 	{
@@ -135,7 +135,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		return TRUE;
 	}
 
-	/*     on est sur le dbut d'oprations d'un compte, on cre un nouveau compte */
+	/*     on est sur le début d'opérations d'un compte, on crée un nouveau compte */
 	/* 	si on est ici, la variable type contient le type de compte */
 
 	compte = calloc ( 1,
@@ -145,7 +145,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 
 	compte -> origine = 0;
 
-	/* rcupration du type de compte */
+	/* récupération du type de compte */
 
 	if ( !my_strcasecmp ( type,
 			      "bank" ))
@@ -155,8 +155,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	    if ( !my_strcasecmp ( type,
 				  "invst" ))
 	    {
-/* 		on considre le compte d'investissement comme un compte bancaire mais met un */
-/* 		    warning car pas implment ; aucune ide si a passe ou pas... */
+/* 		on considère le compte d'investissement comme un compte bancaire mais met un */
+/* 		    warning car pas implémenté ; aucune idée si ça passe ou pas... */
 		compte -> type_de_compte = 0;
 		dialogue_warning ( _("Grisbi found an investment account, which is not implemented yet.  Nevertheless, Grisbi will try to import it as a bank account." ));
 	    }
@@ -185,16 +185,16 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 
 
 
-	/* rcupre les autres donnes du compte */
+	/* récupère les autres données du compte */
 
-	/*       pour un type CCard, le qif commence directement une op sans donner les */
-	/* 	caractristiques de dpart du compte, on cre donc un compte du nom */
-	/* "carte de crdit" avec un solde init de 0 */
+	/*       pour un type CCard, le qif commence directement une opé sans donner les */
+	/* 	caractéristiques de départ du compte, on crée donc un compte du nom */
+	/* "carte de crédit" avec un solde init de 0 */
 
 	if ( my_strcasecmp ( type,
 			      "ccard" ))
 	{
-	    /* ce n'est pas une ccard, on rcupre les infos */
+	    /* ce n'est pas une ccard, on récupère les infos */
 
 	    do
 	    {
@@ -204,7 +204,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 					      &pointeur_char );
 
 
-		/* rcupration du solde initial ( on doit virer la , que money met pour sparer les milliers ) */
+		/* récupération du solde initial ( on doit virer la , que money met pour séparer les milliers ) */
 		/* on ne vire la , que s'il y a un . */
 
 		if ( pointeur_char[0] == 'T' )
@@ -234,7 +234,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		}
 
 
-		/* rcupration du nom du compte */
+		/* récupération du nom du compte */
 		/* 	      parfois, le nom est entre crochet et parfois non ... */
 
 		if ( pointeur_char[0] == 'L' )
@@ -266,7 +266,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    }
 		}
 
-		/* on rcupre la date du fichier */
+		/* on récupère la date du fichier */
 		/*  on ne la traite pas maintenant mais quand on traitera toutes les dates */
 
 		if ( pointeur_char[0] == 'D' )
@@ -304,7 +304,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	}
 
 
-	/* rcupration des oprations en brut, on les traitera ensuite */
+	/* récupération des opérations en brut, on les traitera ensuite */
 
 	do
 	{
@@ -327,20 +327,20 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		     &&
 		     pointeur_char[0] != '!' )
 		{
-		    /* on vire le 0d  la fin de la chane s'il y est  */
+		    /* on vire le 0d à la fin de la chaîne s'il y est  */
 
 		    if ( pointeur_char [ strlen (pointeur_char)-1 ] == 13 )
 			pointeur_char [ strlen (pointeur_char)-1 ] = 0;
 
-		    /* rcupration de la date */
-		    /* on la met pour l'instant dans date_tmp, et aprs avoir rcupr toutes */
-		    /* les ops on transformera les dates en gdate */
+		    /* récupération de la date */
+		    /* on la met pour l'instant dans date_tmp, et après avoir récupéré toutes */
+		    /* les opés on transformera les dates en gdate */
 
 		    if ( pointeur_char[0] == 'D' )
 			operation -> date_tmp = g_strdup ( pointeur_char + 1 );
 
 
-		    /* rcupration du pointage */
+		    /* récupération du pointage */
 
 		    if ( pointeur_char[0] == 'C' )
 		    {
@@ -351,7 +351,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    }
 
 
-		    /* rcupration de la note */
+		    /* récupération de la note */
 
 		    if ( pointeur_char[0] == 'M' )
 		    {
@@ -367,7 +367,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    }
 
 
-		    /* rcupration du montant ( on doit virer la , que money met pour sparer les milliers ) */
+		    /* récupération du montant ( on doit virer la , que money met pour séparer les milliers ) */
 		    /* on ne vire la , que s'il y a un . */
 
 		    if ( pointeur_char[0] == 'T' )
@@ -397,7 +397,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			g_strfreev ( tab );
 		    }
 
-		    /* rcupration du chque */
+		    /* récupération du chèque */
 
 		    if ( pointeur_char[0] == 'N' )
 			operation -> cheque = my_strtod ( pointeur_char + 1,
@@ -405,7 +405,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 
 
 
-		    /* rcupration du tiers */
+		    /* récupération du tiers */
 
 		    if ( pointeur_char[0] == 'P' )
 		    {
@@ -418,7 +418,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    }
 
 
-		    /* rcupration des catg */
+		    /* récupération des catég */
 
 		    if ( pointeur_char[0] == 'L' )
 		    {
@@ -432,11 +432,11 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 
 
 
-		    /* rcupration de la ventilation et de sa categ */
+		    /* récupération de la ventilation et de sa categ */
 
 		    if ( pointeur_char[0] == 'S' )
 		    {
-			/* on commence une ventilation, si une op tait en cours, on l'enregistre */
+			/* on commence une ventilation, si une opé était en cours, on l'enregistre */
 
 			if ( retour != EOF && operation && operation -> date_tmp )
 			{
@@ -446,7 +446,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			}
 			else
 			{
-			    /*c'est la fin du fichier ou l'op n'est pas valide, donc les ventils ne sont pas valides non plus */
+			    /*c'est la fin du fichier ou l'opé n'est pas valide, donc les ventils ne sont pas valides non plus */
 
 			    free ( operation );
 
@@ -457,7 +457,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			    ventilation = NULL;
 			}
 
-			/* si une ventilation tait en cours, on l'enregistre */
+			/* si une ventilation était en cours, on l'enregistre */
 
 			if ( ventilation )
 			    compte -> operations_importees = g_slist_append ( compte -> operations_importees,
@@ -470,7 +470,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			{
 			    operation -> operation_ventilee = 1;
 
-			    /* rcupration des donnes de l'opration en cours */
+			    /* récupération des données de l'opération en cours */
 
 			    ventilation -> date_tmp = g_strdup ( operation -> date_tmp );
 			    ventilation -> tiers = operation -> tiers;
@@ -490,7 +490,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    }
 
 
-		    /* rcupration de la note de ventilation */
+		    /* récupération de la note de ventilation */
 
 		    if ( pointeur_char[0] == 'E'
 			 &&
@@ -507,8 +507,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			    ventilation -> notes = NULL;
 		    }
 
-		    /* rcupration du montant de la ventilation */
-		    /* rcupration du montant ( on doit virer la , que money met pour sparer les milliers ) */
+		    /* récupération du montant de la ventilation */
+		    /* récupération du montant ( on doit virer la , que money met pour séparer les milliers ) */
 		    /* on ne vire la , que s'il y a un . */
 
 		    if ( pointeur_char[0] == '$'
@@ -548,10 +548,10 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		    &&
 		    pointeur_char[0] != '!' );
 
-	    /* 	 ce stade, soit on est  la fin d'une opration, soit  la fin du fichier */
+	    /* 	à ce stade, soit on est à la fin d'une opération, soit à la fin du fichier */
 
-	    /* 	    en thorie, on a toujours ^  la fin d'une opration */
-	    /* 		donc si on en est  eof ou !, on n'enregistre pas l'op */
+	    /* 	    en théorie, on a toujours ^ à la fin d'une opération */
+	    /* 		donc si on en est à eof ou !, on n'enregistre pas l'opé */
 
 	    if ( retour != EOF
 		 &&
@@ -569,8 +569,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 			   && 
 			   strlen ( g_strstrip (operation -> date_tmp ))))
 		    {
-			/* 	l'opration n'a pas de date, c'est pas normal. pour viter de la perdre, on va lui */
-			/* 	 donner la date 01/01/1970 et on ajoute au tiers [opration sans date] */
+			/* 	l'opération n'a pas de date, c'est pas normal. pour éviter de la perdre, on va lui */
+			/* 	 donner la date 01/01/1970 et on ajoute au tiers [opération sans date] */
 
 			operation -> date_tmp = g_strdup ( "01/01/1970" );
 			if ( operation -> tiers )
@@ -585,12 +585,12 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		}
 	    }
 	}
-	/*     on continue  enregistrer les ops jusqu' la fin du fichier ou jusqu' un changement de compte */
+	/*     on continue à enregistrer les opés jusqu'à la fin du fichier ou jusqu'à un changement de compte */
 	while ( retour != EOF
 		&&
 		pointeur_char[0] != '!' );
 
-	/* toutes les oprations du compte ont t rcupres */
+	/* toutes les opérations du compte ont été récupérées */
 	/* on peut maintenant transformer la date_tmp en gdate */
 
 	format_date = 0;
@@ -607,11 +607,11 @@ changement_format_date:
 
 	    operation = liste_tmp -> data;
 
-	    /*   vrification qu'il y a une date, sinon on vire l'op de toute manire */
+	    /*   vérification qu'il y a une date, sinon on vire l'opé de toute manière */
 
 	    if ( operation -> date_tmp)
 	    {	      
-		/* rcupration de la date qui est du format jj/mm/aaaa ou jj/mm/aa ou jj/mm'aa  partir de 2000 */
+		/* récupération de la date qui est du format jj/mm/aaaa ou jj/mm/aa ou jj/mm'aa à partir de 2000 */
 		/* 	      si format_date = 0, c'est sous la forme jjmm sinon mmjj */
 
 
@@ -678,7 +678,7 @@ changement_format_date:
 					       NULL );
 			}
 
-			/* si on avait 'xx, en fait a peut tre 'xx ou 'xxxx ... */
+			/* si on avait 'xx, en fait ça peut être 'xx ou 'xxxx ... */
 
 			if ( strlen ( tab_str2[1] ) == 2 )
 			    annee = my_strtod ( tab_str2[1],
@@ -740,16 +740,17 @@ changement_format_date:
 	    }
 	    else
 	    {
-		/* il n'y a pas de date, on vire l'op de la liste */
+		/* il n'y a pas de date, on vire l'opé de la liste */
 
 		compte -> operations_importees = g_slist_remove ( compte -> operations_importees,
 								  liste_tmp -> data );
+		free ( liste_tmp -> data );
 	    }
 	    liste_tmp = liste_tmp -> next;
 	}
 
 
-	/* rcupration de la date du fichier  */
+	/* récupération de la date du fichier  */
 	/* si format_date = 0, c'est sous la forme jjmm sinon mmjj */
 
 	if ( compte -> date_solde_qif )
@@ -820,7 +821,7 @@ changement_format_date:
 					   NULL );
 		    }
 
-		    /* si on avait 'xx, en fait a peut tre 'xx ou 'xxxx ... */
+		    /* si on avait 'xx, en fait ça peut être 'xx ou 'xxxx ... */
 
 		    if ( strlen ( tab_str2[1] ) == 2 )
 			annee = my_strtod ( tab_str2[1],
@@ -869,12 +870,12 @@ changement_format_date:
 	}
 
 
-	/* ajoute ce compte aux autres comptes imports */
+	/* ajoute ce compte aux autres comptes importés */
 
 	liste_comptes_importes = g_slist_append ( liste_comptes_importes,
 						  compte );
 
-	/*     si  la fin des oprations c'tait un changement de compte et pas la fin du fichier, */
+	/*     si à la fin des opérations c'était un changement de compte et pas la fin du fichier, */
 	/*     on y retourne !!! */
 
 	pas_le_premier_compte = 1;
@@ -891,7 +892,7 @@ changement_format_date:
 
 
 /* *******************************************************************************/
-/* Affiche la fentre de slection de fichier pour exporter en qif */
+/* Affiche la fenêtre de sélection de fichier pour exporter en qif */
 /* *******************************************************************************/
 
 void exporter_fichier_qif ( void )
@@ -971,7 +972,7 @@ void exporter_fichier_qif ( void )
 	gtk_widget_show ( entree );
 
 
-	/*       si on clique sur le check bouton, a rend ditable l'entre */
+	/*       si on clique sur le check bouton, ça rend éditable l'entrée */
 
 	gtk_signal_connect ( GTK_OBJECT ( check_button ),
 			     "toggled",
@@ -996,7 +997,7 @@ choix_liste_fichier:
 	return;
     }
 
-    /* vrification que tous les fichiers sont enregistrables */
+    /* vérification que tous les fichiers sont enregistrables */
 
     liste_tmp = liste_entrees_exportation;
 
@@ -1031,7 +1032,7 @@ choix_liste_fichier:
 
 
 
-    /* on est sr de l'enregistrement, c'est parti ... */
+    /* on est sûr de l'enregistrement, c'est parti ... */
 
 
     liste_tmp = liste_entrees_exportation;
@@ -1076,7 +1077,7 @@ choix_liste_fichier:
 
 	    if ( LISTE_OPERATIONS )
 	    {
-		/* met la date de la 1re opration comme dte d'ouverture de compte */
+		/* met la date de la 1ère opération comme dâte d'ouverture de compte */
 
 		operation = LISTE_OPERATIONS -> data;
 
@@ -1113,7 +1114,7 @@ choix_liste_fichier:
 					"]",
 					NULL ) );
 
-		/* on met toutes les oprations */
+		/* on met toutes les opérations */
 
 		pointeur_tmp = LISTE_OPERATIONS;
 
@@ -1126,8 +1127,8 @@ choix_liste_fichier:
 		    operation = pointeur_tmp -> data;
 
 
-		    /* si c'est une op de ventilation, on la saute pas elle sera recherche quand */
-		    /* son op ventile sera exporte */
+		    /* si c'est une opé de ventilation, on la saute pas elle sera recherchée quand */
+		    /* son opé ventilée sera exportée */
 
 		    if ( !operation -> no_operation_ventilee_associee )
 		    {
@@ -1181,7 +1182,7 @@ choix_liste_fichier:
 				  montant_tmp );
 
 
-			/* met le chque si c'est un type  numrotation automatique */
+			/* met le chèque si c'est un type à numérotation automatique */
 
 			pointeur = g_slist_find_custom ( TYPES_OPES,
 							 GINT_TO_POINTER ( operation -> type_ope ),
@@ -1210,11 +1211,11 @@ choix_liste_fichier:
 
 
 
-			/*  on met soit un virement, soit une ventilation, soit les catgories */
+			/*  on met soit un virement, soit une ventilation, soit les catégories */
 
-			/* si c'est une ventilation, on recherche toutes les ops de cette ventilation */
-			/* et les met  la suite */
-			/* la catgorie de l'op sera celle de la premire op de ventilation */
+			/* si c'est une ventilation, on recherche toutes les opés de cette ventilation */
+			/* et les met à la suite */
+			/* la catégorie de l'opé sera celle de la première opé de ventilation */
 
 			if ( operation -> operation_ventilee )
 			{
@@ -1236,7 +1237,7 @@ choix_liste_fichier:
 				       ||
 				       ope_test -> relation_no_operation ))
 				{
-				    /* on commence par mettre la catg et sous categ de l'op et de l'op de ventilation */
+				    /* on commence par mettre la catég et sous categ de l'opé et de l'opé de ventilation */
 
 				    if ( ope_test -> relation_no_operation )
 				    {
@@ -1357,7 +1358,7 @@ choix_liste_fichier:
 			}
 			else
 			{
-			    /* si c'est un virement vers un compte supprim, a sera pris comme categ normale vide */
+			    /* si c'est un virement vers un compte supprimé, ça sera pris comme categ normale vide */
 
 			    if ( operation -> relation_no_operation
 				 &&
@@ -1422,7 +1423,7 @@ choix_liste_fichier:
 	    }
 	    else
 	    {
-		/* le compte n'a aucune opration enregistre : on ne met pas de date, mais on fait l'ouverture du compte */
+		/* le compte n'a aucune opération enregistrée : on ne met pas de date, mais on fait l'ouverture du compte */
 
 		/* met le solde initial */
 
@@ -1480,6 +1481,7 @@ void click_compte_export_qif ( GtkWidget *bouton,
 				   FALSE );
 	liste_entrees_exportation = g_slist_remove ( liste_entrees_exportation,
 						     entree);
+	free ( entree );
     }
 
 }
@@ -1534,7 +1536,7 @@ void export_qif (GSList* export_entries_list )
 
 	    if ( LISTE_OPERATIONS )
 	    {
-		/* met la date de la 1re opration comme dte d'ouverture de compte */
+		/* met la date de la 1ère opération comme dâte d'ouverture de compte */
 
 		operation = LISTE_OPERATIONS -> data;
 
@@ -1571,7 +1573,7 @@ void export_qif (GSList* export_entries_list )
 					"]",
 					NULL ) );
 
-		/* on met toutes les oprations */
+		/* on met toutes les opérations */
 
 		pointeur_tmp = LISTE_OPERATIONS;
 
@@ -1584,8 +1586,8 @@ void export_qif (GSList* export_entries_list )
 		    operation = pointeur_tmp -> data;
 
 
-		    /* si c'est une op de ventilation, on la saute pas elle sera recherche quand */
-		    /* son op ventile sera exporte */
+		    /* si c'est une opé de ventilation, on la saute pas elle sera recherchée quand */
+		    /* son opé ventilée sera exportée */
 
 		    if ( !operation -> no_operation_ventilee_associee )
 		    {
@@ -1639,7 +1641,7 @@ void export_qif (GSList* export_entries_list )
 				  montant_tmp );
 
 
-			/* met le chque si c'est un type  numrotation automatique */
+			/* met le chèque si c'est un type à numérotation automatique */
 
 			pointeur = g_slist_find_custom ( TYPES_OPES,
 							 GINT_TO_POINTER ( operation -> type_ope ),
@@ -1668,11 +1670,11 @@ void export_qif (GSList* export_entries_list )
 
 
 
-			/*  on met soit un virement, soit une ventilation, soit les catgories */
+			/*  on met soit un virement, soit une ventilation, soit les catégories */
 
-			/* si c'est une ventilation, on recherche toutes les ops de cette ventilation */
-			/* et les met  la suite */
-			/* la catgorie de l'op sera celle de la premire op de ventilation */
+			/* si c'est une ventilation, on recherche toutes les opés de cette ventilation */
+			/* et les met à la suite */
+			/* la catégorie de l'opé sera celle de la première opé de ventilation */
 
 			if ( operation -> operation_ventilee )
 			{
@@ -1694,7 +1696,7 @@ void export_qif (GSList* export_entries_list )
 				       ||
 				       ope_test -> relation_no_operation ))
 				{
-				    /* on commence par mettre la catg et sous categ de l'op et de l'op de ventilation */
+				    /* on commence par mettre la catég et sous categ de l'opé et de l'opé de ventilation */
 
 				    if ( ope_test -> relation_no_operation )
 				    {
@@ -1815,7 +1817,7 @@ void export_qif (GSList* export_entries_list )
 			}
 			else
 			{
-			    /* si c'est un virement vers un compte supprim, a sera pris comme categ normale vide */
+			    /* si c'est un virement vers un compte supprimé, ça sera pris comme categ normale vide */
 
 			    if ( operation -> relation_no_operation
 				 &&
@@ -1880,7 +1882,7 @@ void export_qif (GSList* export_entries_list )
 	    }
 	    else
 	    {
-		/* le compte n'a aucune opration enregistre : on ne met pas de date, mais on fait l'ouverture du compte */
+		/* le compte n'a aucune opération enregistrée : on ne met pas de date, mais on fait l'ouverture du compte */
 
 		/* met le solde initial */
 
