@@ -1,7 +1,7 @@
 /* fichier qui s'occupe de l'onglet de gestion du tiers */
 /*           tiers_onglet.c */
 
-/*     Copyright (C) 2000-2003  Cdric Auger */
+/*     Copyright (C) 2000-2003  Cédric Auger */
 /* 			cedric@grisbi.org */
 /* 			http://www.grisbi.org */
 
@@ -53,7 +53,7 @@ extern GSList *gsliste_echeances;
 
 /* **************************************************************************************************** */
 /* Fonction onglet_tiers : */
-/* cre et renvoie le widget contenu dans l'onglet */
+/* crée et renvoie le widget contenu dans l'onglet */
 /* **************************************************************************************************** */
 
 GtkWidget *onglet_tiers ( void )
@@ -73,7 +73,7 @@ GtkWidget *onglet_tiers ( void )
     GtkWidget *hbox;
     GtkWidget *scrolled_window_text;
 
-    /* cration des pixmaps pour la liste */
+    /* création des pixmaps pour la liste */
     pixmap_ouvre = gdk_pixmap_create_from_xpm_d ( GTK_WIDGET(window) -> window,
 						  &masque_ouvre, NULL, 
 						  (gchar **) book_open_xpm );
@@ -81,7 +81,7 @@ GtkWidget *onglet_tiers ( void )
 						  &masque_ferme, NULL, 
 						  (gchar **) book_closed_xpm );
 
-    /* cration de la fentre qui sera renvoye */
+    /* création de la fenêtre qui sera renvoyée */
 
     onglet = gtk_hbox_new ( FALSE,
 			    5 );
@@ -90,7 +90,7 @@ GtkWidget *onglet_tiers ( void )
     gtk_widget_show ( onglet );
 
 
-    /*   cration de la frame de gauche */
+    /*   création de la frame de gauche */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -167,7 +167,7 @@ GtkWidget *onglet_tiers ( void )
 
     gtk_widget_show_all ( scrolled_window_text );
 
-    /*   cration des boutons modifier et annuler */
+    /*   création des boutons modifier et annuler */
 
     hbox = gtk_hbox_new ( TRUE,
 			  5 );
@@ -249,7 +249,7 @@ GtkWidget *onglet_tiers ( void )
     gtk_widget_show ( bouton_ajouter_tiers );
 
 
-    /*   cration de la frame de droite */
+    /*   création de la frame de droite */
 
     frame = gtk_frame_new ( NULL );
     gtk_frame_set_shadow_type ( GTK_FRAME ( frame ),
@@ -277,7 +277,7 @@ GtkWidget *onglet_tiers ( void )
 			 FALSE,
 			 0 );
 
-    /* cration de l'arbre principal */
+    /* création de l'arbre principal */
 
     scroll_window = gtk_scrolled_window_new ( NULL,
 					      NULL );
@@ -332,7 +332,7 @@ GtkWidget *onglet_tiers ( void )
 				      4,
 				      FALSE );
 
-    /* on met la fontion de tri alphabtique en prenant en compte les accents */
+    /* on met la fontion de tri alphabétique en prenant en compte les accents */
 
     gtk_clist_set_compare_func ( GTK_CLIST ( arbre_tiers ),
 				 (GtkCListCompareFunc) classement_alphabetique_tree );
@@ -367,12 +367,12 @@ GtkWidget *onglet_tiers ( void )
     gtk_widget_show ( arbre_tiers );
 
 
-    /* on met la fontion de tri alphabtique en prenant en compte les accents */
+    /* on met la fontion de tri alphabétique en prenant en compte les accents */
 
     gtk_clist_set_compare_func ( GTK_CLIST ( arbre_tiers ),
 				 (GtkCListCompareFunc) classement_alphabetique_tree );
 
-    /* la 1re fois qu'on affichera les tiers, il faudra remplir la liste */
+    /* la 1ère fois qu'on affichera les tiers, il faudra remplir la liste */
 
     modif_tiers = 1;
 
@@ -412,7 +412,7 @@ void remplit_arbre_tiers ( void )
 					      GINT_TO_POINTER ( no_devise_totaux_tiers ),
 					      ( GCompareFunc ) recherche_devise_par_no) -> data;
 
-    /* rcupre les montants des tiers */
+    /* récupère les montants des tiers */
 
     tab_montant = calcule_total_montant_tiers ();
 
@@ -437,7 +437,7 @@ void remplit_arbre_tiers ( void )
 	else
 	    text[1] = NULL;
 
-	/* nb_ecritures_par_tiers a t calcul dans cacule_total_montant_tiers */
+	/* nb_ecritures_par_tiers a été calculé dans cacule_total_montant_tiers */
 
 	if ( etat.affiche_nb_ecritures_listes
 	     &&
@@ -475,7 +475,7 @@ void remplit_arbre_tiers ( void )
 					FALSE,
 					FALSE );
 
-	/* on associe  ce tiers  l'adr de sa struct */
+	/* on associe à ce tiers à l'adr de sa struct */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 				      ligne,
@@ -496,7 +496,7 @@ void remplit_arbre_tiers ( void )
 					FALSE,
 					FALSE );
 
-	/* on associe le fils bidon  -1 */
+	/* on associe le fils bidon à -1 */
 
 	gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 				      ligne,
@@ -508,13 +508,13 @@ void remplit_arbre_tiers ( void )
 	liste_tiers_tmp = liste_tiers_tmp -> next;
     }
 
-    /* on efface les libre les tableaux */
+    /* on efface les libère les tableaux */
 
     free ( tab_montant );
     free ( date_dernier_tiers );
     free ( nb_ecritures_par_tiers );
 
-    /* on trie par ordre alphabtique */
+    /* on trie par ordre alphabétique */
 
     gtk_ctree_sort_node ( GTK_CTREE ( arbre_tiers ),
 			  NULL );
@@ -544,8 +544,8 @@ gint classement_alphabetique_tree ( GtkWidget *tree,
 
 /* **************************************************************************************************** */
 /* Fonction ouverture_node_tiers */
-/* appel lorsqu'on ouvre un tiers ou le compte d'un tiers */
-/* remplit ce qui doit tre affich */
+/* appeléé lorsqu'on ouvre un tiers ou le compte d'un tiers */
+/* remplit ce qui doit être affiché */
 /* **************************************************************************************************** */
 
 void ouverture_node_tiers ( GtkWidget *arbre,
@@ -560,7 +560,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 
     row = GTK_CTREE_ROW ( node );
 
-    /*   si le fiston = -1, c'est qu'il n'a pas encore t cr */
+    /*   si le fiston = -1, c'est qu'il n'a pas encore été créé */
     /* dans le cas contraire, on vire */
 
     if ( GPOINTER_TO_INT ( gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_tiers ),
@@ -571,12 +571,12 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 
     gtk_clist_freeze ( GTK_CLIST ( arbre_tiers ));
 
-    /* on commence par virer la ligne bidon qui tait attache  ce noeud */
+    /* on commence par virer la ligne bidon qui était attachée à ce noeud */
 
     gtk_ctree_remove_node ( GTK_CTREE ( arbre_tiers ),
 			    row -> children );
 
-    /* sparation entre ouverture de tiers ( 0 ) et ouverture de compte ( 1 ) */
+    /* séparation entre ouverture de tiers ( 0 ) et ouverture de compte ( 1 ) */
 
     if ( row -> level == 1)
     {
@@ -590,7 +590,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 										       node ))) -> no_tiers;
 
 
-	/* on va scanner tous les comptes, ds qu'un tiers correspondant au tiers slectionn est trouv */
+	/* on va scanner tous les comptes, dès qu'un tiers correspondant au tiers sélectionné est trouvé */
 	/* on affiche le nom du compte */
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -639,7 +639,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 							     FALSE,
 							     FALSE );
 
-		    /* associe le no de compte  la ligne du compte */
+		    /* associe le no de compte à la ligne du compte */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 						  node_insertion,
@@ -659,7 +659,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 							     FALSE,
 							     FALSE );
 
-		    /* associe le no de compte  la ligne du compte */
+		    /* associe le no de compte à la ligne du compte */
 
 		    gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 						  node_insertion,
@@ -677,7 +677,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
     else
     {
 	/* c'est une ouverture d'un compte */
-	/*       cette fois, on fait le tour de toutes les ops du compte pour afficher celles qui correspondent au tiers */
+	/*       cette fois, on fait le tour de toutes les opés du compte pour afficher celles qui correspondent au tiers */
 
 	guint no_tiers_selectionne;
 	GSList *pointeur_ope;
@@ -737,7 +737,7 @@ void ouverture_node_tiers ( GtkWidget *arbre,
 							 FALSE,
 							 FALSE );
 
-		/* on associe  cette op l'adr de sa struct */
+		/* on associe à cette opé l'adr de sa struct */
 
 		gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 					      node_insertion,
@@ -866,7 +866,7 @@ gboolean expand_selected_tiers ( GtkWidget *liste, GdkEventButton *ev, gpointer
 	 GTK_CTREE_ROW ( ( GTK_CLIST ( arbre_tiers ) -> selection ) -> data ) -> level != 3 )
 	return FALSE;
 
-    /* passage sur le compte concern */
+    /* passage sur le compte concerné */
 
     operation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_tiers ),
 					      GTK_CTREE_NODE ( ( GTK_CLIST ( arbre_tiers ) -> selection ) -> data ) );
@@ -874,7 +874,7 @@ gboolean expand_selected_tiers ( GtkWidget *liste, GdkEventButton *ev, gpointer
     changement_compte ( GINT_TO_POINTER ( operation -> no_compte ));
 
 
-    /* rcupration de la ligne de l'op dans la liste ; affichage de toutes les op si ncessaire */
+    /* récupération de la ligne de l'opé dans la liste ; affichage de toutes les opé si nécessaire */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
@@ -960,7 +960,7 @@ void clique_sur_modifier_tiers ( GtkWidget *bouton_modifier,
     tiers =  gtk_object_get_data ( GTK_OBJECT (  text_box ),
 				   "adr_struct_tiers" );
 
-    /* si c'est une modif du nom, on doit rafficher la liste des tiers et les listes des ops, sinon, on change juste le texte */
+    /* si c'est une modif du nom, on doit réafficher la liste des tiers et les listes des opés, sinon, on change juste le texte */
 
     if ( strcmp ( g_strstrip ( (gchar *) gtk_entry_get_text ( GTK_ENTRY ( entree_nom_tiers ))),
 		  tiers -> nom_tiers ))
@@ -987,8 +987,8 @@ void clique_sur_modifier_tiers ( GtkWidget *bouton_modifier,
 					 0,
 					 tiers -> nom_tiers,
 					 16,
-					 masque_ferme,
-					 pixmap_ferme );
+					 pixmap_ferme,
+					 masque_ferme );
 	else
 	    gtk_ctree_node_set_pixtext ( GTK_CTREE ( arbre_tiers ),
 					 node,
@@ -1065,8 +1065,8 @@ void clique_sur_annuler_tiers ( GtkWidget *bouton_annuler,
 
 /***********************************************************************************************************/
 /* Fonction ajoute_nouveau_tiers */
-/* appele pour ajouter un nouveau tiers  la liste des tiers */
-/* entre : le nouveau tiers */
+/* appelée pour ajouter un nouveau tiers à la liste des tiers */
+/* entrée : le nouveau tiers */
 /* retour : le no de tiers */
 /***********************************************************************************************************/
 
@@ -1110,7 +1110,7 @@ void supprimer_tiers ( GtkWidget *bouton,
     tiers = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_tiers ),
 					  node );
 
-    /* on fait le tour de tous les comptes pour vrifier s'il reste une op  ce tiers */
+    /* on fait le tour de tous les comptes pour vérifier s'il reste une opé à ce tiers */
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
 
@@ -1128,7 +1128,7 @@ void supprimer_tiers ( GtkWidget *bouton,
 
 	    if ( operation -> tiers == tiers -> no_tiers )
 	    {
-		/* une opration associe  ce tiers a t trouve  = > on sort de la recherche */
+		/* une opération associée à ce tiers a été trouvée  = > on sort de la recherche */
 
 		pointeur_ope = NULL;
 		i = nb_comptes;
@@ -1140,7 +1140,7 @@ void supprimer_tiers ( GtkWidget *bouton,
 	p_tab_nom_de_compte_variable++;
     }
 
-    /* fait le tour des chances pour vrifier s'il reste une op  ce tiers */
+    /* fait le tour des échéances pour vérifier s'il reste une opé à ce tiers */
 
     if ( !ope_trouvee )
     {
@@ -1285,7 +1285,7 @@ retour_dialogue:
 		goto retour_dialogue;
 	    }
 
-	    /* recherche du nouveau numro de tiers */
+	    /* recherche du nouveau numéro de tiers */
 
 	    tmp = g_slist_find_custom ( liste_struct_tiers,
 					gtk_combofix_get_text ( GTK_COMBOFIX ( combofix ) ),
@@ -1306,7 +1306,7 @@ retour_dialogue:
 	    nouveau_no = 0;
 
 
-	/* on fait le tour des ops pour mettre le nouveau numro de tiers */
+	/* on fait le tour des opés pour mettre le nouveau numéro de tiers */
 
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -1330,7 +1330,7 @@ retour_dialogue:
 	}
 
 
-	/* fait le tour des chances pour mettre le nouveau numro de tiers */
+	/* fait le tour des échéances pour mettre le nouveau numéro de tiers */
 
 	pointeur_ope = gsliste_echeances;
 
@@ -1359,6 +1359,7 @@ retour_dialogue:
 
     liste_struct_tiers = g_slist_remove ( liste_struct_tiers,
 					  tiers );
+    free ( tiers );
     nb_enregistrements_tiers--;
 
 
@@ -1381,9 +1382,9 @@ void creation_liste_tiers_combofix ( void )
     GSList *pointeur;
     GSList *liste_tmp;
 
-    /* on commence  crer les 2 listes semblables de tous les tiers */
+    /* on commence à créer les 2 listes semblables de tous les tiers */
     /*   celle du formulaire est de type complex, cad qu'elle contiendra 2 listes : */
-    /* les tiers et les tats slectionns */
+    /* les tiers et les états sélectionnés */
 
     pointeur = liste_struct_tiers;
     liste_tiers_combofix = NULL;
@@ -1399,12 +1400,12 @@ void creation_liste_tiers_combofix ( void )
 	pointeur = pointeur -> next;
     }
 
-    /* on ajoute liste tmp  liste_tiers_combofix */
+    /* on ajoute liste tmp à liste_tiers_combofix */
 
     liste_tiers_combofix = g_slist_append ( liste_tiers_combofix,
 					    liste_tmp );
 
-    /* on fait maintenant le tour des tats pour rajouter ceux qui ont t slectionns */
+    /* on fait maintenant le tour des états pour rajouter ceux qui ont été sélectionnés */
 
     liste_tmp = NULL;
     pointeur = liste_struct_etats;
@@ -1435,7 +1436,7 @@ void creation_liste_tiers_combofix ( void )
 	pointeur = pointeur -> next;
     }
 
-    /* on ajoute liste tmp  liste_tiers_combofix */
+    /* on ajoute liste tmp à liste_tiers_combofix */
 
     liste_tiers_combofix = g_slist_append ( liste_tiers_combofix,
 					    liste_tmp );
@@ -1448,8 +1449,8 @@ void creation_liste_tiers_combofix ( void )
 
 /* ***************************************************************************************************** */
 /* Fonction changement_taille_liste_tiers */
-/* appele ds que la taille de la clist a chang ( fait aussi les catg et l'ib ) */
-/* pour mettre la taille des diffrentes colonnes */
+/* appelée dès que la taille de la clist a changé ( fait aussi les catég et l'ib ) */
+/* pour mettre la taille des différentes colonnes */
 /* ***************************************************************************************************** */
 
 gboolean changement_taille_liste_tiers ( GtkWidget *clist,
@@ -1486,7 +1487,7 @@ gboolean changement_taille_liste_tiers ( GtkWidget *clist,
 
 /* ***************************************************************************************************** */
 /* Fonction mise_a_jour_tiers */
-/* recre la liste des combofix et l'applique  tous les combofix du tiers */
+/* recrée la liste des combofix et l'applique à tous les combofix du tiers */
 /* ***************************************************************************************************** */
 
 void mise_a_jour_tiers ( void )
@@ -1514,7 +1515,7 @@ void mise_a_jour_tiers ( void )
 
 
 /* **************************************************************************************************** */
-/* cre un tableau de gint aussi gd que le nb de tiers */
+/* crée un tableau de gint aussi gd que le nb de tiers */
 /* et le renvoie */
 /* **************************************************************************************************** */
 
@@ -1523,7 +1524,7 @@ gfloat *calcule_total_montant_tiers ( void )
     gint i;
     gfloat *tab_retour;
 
-    /* on cre le tableau de retour */
+    /* on crée le tableau de retour */
 
     tab_retour = calloc ( nb_enregistrements_tiers,
 			  sizeof ( gfloat ));
@@ -1659,12 +1660,12 @@ void appui_sur_ajout_tiers ( void )
 	return;
       }
 
-    /* on l'ajoute  la liste des ops */
+    /* on l'ajoute à la liste des opés */
 
     nouveau_tiers = ajoute_nouveau_tiers ( nom_tiers );
 
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour éviter de toute la réafficher */
 
     text[0] = nouveau_tiers -> nom_tiers;
     text[1] = NULL;
@@ -1683,7 +1684,7 @@ void appui_sur_ajout_tiers ( void )
 				    FALSE,
 				    FALSE );
 
-    /* on associe  ce tiers  l'adr de sa struct */
+    /* on associe à ce tiers à l'adr de sa struct */
 
     gtk_ctree_node_set_row_data ( GTK_CTREE ( arbre_tiers ),
 				  ligne,
