@@ -1,7 +1,7 @@
 /* Fichier traitement_variables.c */
-/* Contient toutes les procdures relatives au traitement des variables */
+/* Contient toutes les procédures relatives au traitement des variables */
 
-/*     Copyright (C) 2000-2003  Cdric Auger */
+/*     Copyright (C) 2000-2003  Cédric Auger */
 /* 			cedric@grisbi.org */
 /* 			http://www.grisbi.org */
 
@@ -42,8 +42,8 @@ extern GSList *echeances_saisies;
 extern gint noname_account_number;
 
 /*****************************************************************************************************/
-/* fonction appele lors de modification ou non de fichier */
-/* TRUE indique que le fichier a t modifi */
+/* fonction appelée lors de modification ou non de fichier */
+/* TRUE indique que le fichier a été modifié */
 /* FALSE non */
 /* ajuste la sensitive des menus en fonction */
 /*****************************************************************************************************/
@@ -72,9 +72,9 @@ void modification_fichier ( gboolean modif )
 
 
 /*****************************************************************************************************/
-/* fonction appele  chaque ouverture de fichier et qui initialise les variables globales */
-/* si ouverture = TRUE, la fonction considre qu'on est en train d'ouvrir un fichier et ajuste les menus */
-/* en consquence */
+/* fonction appelée à chaque ouverture de fichier et qui initialise les variables globales */
+/* si ouverture = TRUE, la fonction considère qu'on est en train d'ouvrir un fichier et ajuste les menus */
+/* en conséquence */
 /* sinon, suppose que fermeture de fichier */
 /*****************************************************************************************************/
 
@@ -92,12 +92,18 @@ void init_variables ( gboolean ouverture )
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("File"), _("Close"), NULL)),
 				   TRUE );
+	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							       menu_name(_("File"), _("Debug file"), NULL)),
+				   TRUE );
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Accounts"), _("Remove an account"), NULL)),
 				   TRUE );
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Edit"), _("New transaction"), NULL)),
 				   TRUE );
+	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							       menu_name(_("Edit"), _("Use selected transaction as a template"), NULL)),
+				   TRUE );
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Edit"), _("Remove transaction"), NULL)),
 				   TRUE );
@@ -188,6 +194,8 @@ void init_variables ( gboolean ouverture )
 	devise_nulle = calloc ( 1,
 				sizeof ( struct struct_devise ));
 	no_devise_totaux_tiers = 1;
+	no_devise_totaux_categ = 1;
+	no_devise_totaux_ib = 1;
 	devise_compte = NULL;
 	devise_operation = NULL;
 
@@ -207,6 +215,9 @@ void init_variables ( gboolean ouverture )
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("File"), _("Close"), NULL)),
 				   FALSE );
+	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							       menu_name(_("File"), _("Debug file"), NULL)),
+				   FALSE );
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Accounts"), _("Remove an account"), NULL)),
 				   FALSE );
@@ -216,6 +227,9 @@ void init_variables ( gboolean ouverture )
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Edit"), _("New transaction"), NULL)),
 				   FALSE );
+	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							       menu_name(_("Edit"), _("Use selected transaction as a template"), NULL)),
+				   FALSE );
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							       menu_name(_("Edit"), _("Remove transaction"), NULL)),
 				   FALSE );
@@ -278,7 +292,7 @@ void init_variables ( gboolean ouverture )
 	etat.fichier_deja_ouvert = 0;
 	valeur_echelle_recherche_date_import = 2;
 
-	/* 	initialise a car eu crash non reproductible  cause de cette */
+	/* 	initialise ça car eu crash non reproductible à cause de cette */
 	/* 	    variable / FIXME: initialiser toutes les variables globales ? */
 
 	bouton_supprimer_banque = NULL;
@@ -354,7 +368,7 @@ void initialisation_couleurs_listes ( void )
     couleur_grise.green = COULEUR_GRISE_GREEN;
     couleur_grise.blue = COULEUR_GRISE_BLUE;
 
-    /* initialise la couleur de la slection */
+    /* initialise la couleur de la sélection */
 
     couleur_selection.red= COULEUR_SELECTION_RED;
     couleur_selection.green= COULEUR_SELECTION_GREEN ;
@@ -362,7 +376,7 @@ void initialisation_couleurs_listes ( void )
 
 
     /* initialise les variables style_couleur_1 et style_couleur_2 qui serviront */
-    /*  mettre la couleur de fond */
+    /* à mettre la couleur de fond */
 
     style_couleur [0] = gtk_style_copy ( gtk_widget_get_style (GTK_WIDGET (window)) );
     style_couleur [0]->fg[GTK_STATE_NORMAL] = style_couleur [0]->black;
@@ -378,7 +392,7 @@ void initialisation_couleurs_listes ( void )
 
 
     /* initialise les variables style_rouge_couleur [1] et style_rouge_couleur [2] qui serviront */
-    /*  mettre en rouge le solde quand il est ngatif */
+    /* à mettre en rouge le solde quand il est négatif */
 
     style_rouge_couleur [0] = gtk_style_copy ( gtk_widget_get_style (GTK_WIDGET (window)) );
     style_rouge_couleur [0] ->fg[GTK_STATE_NORMAL] = couleur_rouge;
