@@ -1,7 +1,7 @@
 /* ************************************************************************** */
-/* Ce fichier s'occupe de la gestion des types d'oprations		      */
+/* Ce fichier s'occupe de la gestion des types d'opérations		      */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
@@ -81,9 +81,9 @@ void payment_method_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte + type_ope -> no_compte;
 
-    if (type_ope -> signe_type == 1) /* Dbit */
+    if (type_ope -> signe_type == 1) /* Débit */
 	TYPE_DEFAUT_DEBIT = type_ope -> no_type;
-    else if  (type_ope -> signe_type == 2) /* Crdit */
+    else if  (type_ope -> signe_type == 2) /* Crédit */
 	TYPE_DEFAUT_CREDIT = type_ope -> no_type;
 
     if (! toggle_item)
@@ -126,13 +126,15 @@ void payment_method_toggled ( GtkCellRendererToggle *cell, gchar *path_str,
 void fill_payment_method_tree ()
 {
     GtkTreeIter account_iter, debit_iter, credit_iter;
-    gint i;
+    GSList *pUserAccountsList = NULL;
+
+    pUserAccountsList = g_slist_copy ( ordre_comptes );
 
     /* Fill tree, iter over with accounts */
-    p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
-
-    for ( i=0 ; i<nb_comptes ; i++ )
+    do
     {
+	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( pUserAccountsList -> data );
+
 	GSList *liste_tmp;
 
 	gtk_tree_store_append (model, &account_iter, NULL);
@@ -141,7 +143,7 @@ void fill_payment_method_tree ()
 			    PAYMENT_METHODS_NUMBERING_COLUMN, "",
 			    /* This is a hack: account number is put in 
 			       Debit/Credit nodes */
-			    PAYMENT_METHODS_TYPE_COLUMN, i,
+			    PAYMENT_METHODS_TYPE_COLUMN, GPOINTER_TO_INT ( pUserAccountsList -> data ),
 			    PAYMENT_METHODS_DEFAULT_COLUMN, FALSE,
 			    PAYMENT_METHODS_ACTIVABLE_COLUMN, FALSE, 
 			    PAYMENT_METHODS_VISIBLE_COLUMN, FALSE, 
@@ -155,7 +157,7 @@ void fill_payment_method_tree ()
 			    PAYMENT_METHODS_NUMBERING_COLUMN, "",
 			    /* This is a hack: account number is put in 
 			       Debit/Credit nodes */
-			    PAYMENT_METHODS_TYPE_COLUMN, i,
+			    PAYMENT_METHODS_TYPE_COLUMN, GPOINTER_TO_INT ( pUserAccountsList -> data ),
 			    PAYMENT_METHODS_DEFAULT_COLUMN, FALSE,
 			    PAYMENT_METHODS_ACTIVABLE_COLUMN, FALSE, 
 			    PAYMENT_METHODS_VISIBLE_COLUMN, FALSE, 
@@ -169,7 +171,7 @@ void fill_payment_method_tree ()
 			    PAYMENT_METHODS_NUMBERING_COLUMN, "",
 			    /* This is a hack: account number is put in 
 			       Debit/Credit nodes */
-			    PAYMENT_METHODS_TYPE_COLUMN, i,
+			    PAYMENT_METHODS_TYPE_COLUMN, GPOINTER_TO_INT ( pUserAccountsList -> data ),
 			    PAYMENT_METHODS_DEFAULT_COLUMN, FALSE,
 			    PAYMENT_METHODS_ACTIVABLE_COLUMN, FALSE, 
 			    PAYMENT_METHODS_VISIBLE_COLUMN, FALSE, 
@@ -228,9 +230,9 @@ void fill_payment_method_tree ()
 
 	    liste_tmp = liste_tmp -> next;
 	}
-
-	p_tab_nom_de_compte_variable++;
     }
+    while ( (  pUserAccountsList = pUserAccountsList -> next ) );
+    g_slist_free ( pUserAccountsList );
 }
 
 
@@ -392,10 +394,10 @@ GtkWidget *onglet_types_operations ( void )
 		       label, 0, 1, 1, 2,
 		       GTK_SHRINK | GTK_FILL, 0,
 		       0, 0 );
-    entree_type_dernier_no = new_spin_button (NULL,
-					      0, G_MAXDOUBLE, 
-					      1, 5, 5, 
-					      2, 0, (GCallback) modification_entree_type_dernier_no );
+    entree_type_dernier_no = new_int_spin_button (NULL,
+						  0, G_MAXDOUBLE, 
+						  1, 5, 5, 
+						  2, 0, (GCallback) modification_entree_type_dernier_no );
     gtk_table_attach ( GTK_TABLE ( table ),
 		       entree_type_dernier_no, 1, 2, 1, 2,
 		       GTK_EXPAND | GTK_FILL, 0,
@@ -479,7 +481,7 @@ select_payment_method ( GtkTreeSelection *selection, GtkTreeModel *model )
     {
 	/* Blanking entries */
 	entry_set_value ( entree_type_nom, NULL );
-	spin_button_set_value ( entree_type_dernier_no, NULL );
+	spin_button_set_value ( entree_type_dernier_no, (gint *) NULL );
 	gtk_entry_set_text ( GTK_ENTRY ( entree_type_dernier_no ), "" );
 	checkbox_set_value ( entree_automatic_numbering, NULL, TRUE );
 	/* Some widgets are useless */
@@ -499,7 +501,7 @@ select_payment_method ( GtkTreeSelection *selection, GtkTreeModel *model )
 	/* Filling entries */
 	entry_set_value ( entree_type_nom, &(type_ope -> nom_type) );
 	spin_button_set_value ( entree_type_dernier_no, 
-				(gdouble *) &(type_ope -> no_en_cours) );
+				(gint *) &(type_ope -> no_en_cours) );
 	checkbox_set_value ( entree_automatic_numbering, 
 			     &(type_ope -> numerotation_auto), TRUE );
 	gtk_option_menu_set_history ( GTK_OPTION_MENU ( bouton_signe_type ),
@@ -567,7 +569,7 @@ void modification_entree_nom_type ( void )
 		TYPE_DEFAUT_DEBIT = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_operations[TRANSACTION_FORM_TYPE] ) -> menu_item ),
 									  "no_type" ));
 
-		/* on affiche l'entre des chques si ncessaire */
+		/* on affiche l'entrée des chèques si nécessaire */
 		type = g_object_get_data ( G_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_operations[TRANSACTION_FORM_TYPE] ) -> menu_item ),
 					   "adr_type" );
 
@@ -939,12 +941,12 @@ void ajouter_type_operation ( void )
     modification_fichier ( TRUE );
 
     /* FIXME: implement that */
-    /*       /\* on ajoute ce type  la liste des tris *\/ */
+    /*       /\* on ajoute ce type à la liste des tris *\/ */
 
     /*       liste_tri_tmp[no_compte] = g_slist_append ( liste_tri_tmp[no_compte],	/\* FIXME *\/ */
     /* 						  GINT_TO_POINTER ( type_ope -> no_type )); */
 
-    /*       /\*   si les neutres doivent tre intgrs dans les dbits crdits, on ajoute son oppos *\/ */
+    /*       /\*   si les neutres doivent être intégrés dans les débits crédits, on ajoute son opposé *\/ */
 
     /*       if ( neutres_inclus_tmp[no_compte] ) */
     /* 	liste_tri_tmp[no_compte] = g_slist_append ( liste_tri_tmp[no_compte], */
@@ -1133,7 +1135,7 @@ void supprimer_type_operation ( void )
 
 	modification_fichier ( TRUE );
 
-	/* on retire le no de type dans la liste de tri et on raffiche la liste */
+	/* on retire le no de type dans la liste de tri et on réaffiche la liste */
 	/*       liste_tri_tmp[type_ope->no_compte] = g_slist_remove ( liste_tri_tmp[type_ope->no_compte], */
 	/* 							    GINT_TO_POINTER ( type_ope -> no_type )); */
 
@@ -1143,7 +1145,7 @@ void supprimer_type_operation ( void )
 
 	/*       remplit_liste_tri_par_type ( type_ope->no_compte ); */
 
-	/*   si le type tait par dfaut, on met le dfaut  0 */
+	/*   si le type était par défaut, on met le défaut à 0 */
     }
 }
 /* ************************************************************************************************************** */
@@ -1162,9 +1164,9 @@ void inclut_exclut_les_neutres ( void )
 
     if ( (neutres_inclus_tmp[no_compte] = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( bouton_type_neutre_inclut ))))
     {
-	/* on inclut les neutres dans les dbits et crdits */
+	/* on inclut les neutres dans les débits et crédits */
 	/*   on fait le tour de tous les types du compte, et pour chaque type neutre, */
-	/* on rajoute son numro en ngatif ngatif  la liste */
+	/* on rajoute son numéro en négatif négatif à la liste */
 
 	liste_tmp = liste_tri_tmp[no_compte];
 
@@ -1188,7 +1190,7 @@ void inclut_exclut_les_neutres ( void )
     }
     else
     {
-	/* on efface tous les nombres ngatifs de la liste */
+	/* on efface tous les nombres négatifs de la liste */
 
 	liste_tmp = liste_tri_tmp[no_compte];
 
@@ -1198,6 +1200,7 @@ void inclut_exclut_les_neutres ( void )
 	    {
 		liste_tri_tmp[no_compte] = g_slist_remove ( liste_tri_tmp[no_compte],
 							    liste_tmp -> data );
+		free ( liste_tmp -> data );
 		liste_tmp = liste_tri_tmp[no_compte];
 	    }
 	    else
@@ -1250,7 +1253,7 @@ void remplit_liste_tri_par_type ( gint no_compte )
 		else
 		    if ( neutres_inclus_tmp[no_compte] )
 		    {
-			/* si c'est un type neutre et qu'ils sont inclus, celui-ci est soit positif soit ngatif */
+			/* si c'est un type neutre et qu'ils sont inclus, celui-ci est soit positif soit négatif */
 
 			if ( GPOINTER_TO_INT ( liste_tmp -> data ) < 0 )
 			    texte[0] = g_strconcat ( texte[0],
@@ -1282,7 +1285,7 @@ void remplit_liste_tri_par_type ( gint no_compte )
 void selection_type_liste_tri ( void )
 {
 
-    /* on rend sensible les boutons de dplacement */
+    /* on rend sensible les boutons de déplacement */
 
     gtk_widget_set_sensitive ( vbox_fleches_tri,
 			       TRUE );
@@ -1295,7 +1298,7 @@ void selection_type_liste_tri ( void )
 void deselection_type_liste_tri ( void )
 {
 
-    /* on rend non sensible les boutons de dplacement */
+    /* on rend non sensible les boutons de déplacement */
 
     gtk_widget_set_sensitive ( vbox_fleches_tri,
 			       FALSE );
@@ -1307,10 +1310,10 @@ void deselection_type_liste_tri ( void )
 
 /* ************************************************************************************************************** */
 /* Fonction creation_menu_types */
-/* argument : 1 : renvoie un menu de dbits */
-/* 2 : renvoie un menu de crdits */
-/* ou renvoie le tout si c'est dsir dans les paramtres */
-/* l'origine est 0 si vient des oprations, 1 si vient des chances, 2 pour ne pas mettre de signal quand il y a un chgt */
+/* argument : 1 : renvoie un menu de débits */
+/* 2 : renvoie un menu de crédits */
+/* ou renvoie le tout si c'est désiré dans les paramètres */
+/* l'origine est 0 si vient des opérations, 1 si vient des échéances, 2 pour ne pas mettre de signal quand il y a un chgt */
 /* ************************************************************************************************************** */
 
 GtkWidget *creation_menu_types ( gint demande,
@@ -1349,16 +1352,16 @@ GtkWidget *creation_menu_types ( gint demande,
 	{
 	    GtkWidget *item;
 
-	    /* avant de mettre l'item, on cre le menu si ncessaire */
+	    /* avant de mettre l'item, on crée le menu si nécessaire */
 	    /* le faire ici permet de retourner null si il n'y a rien */
-	    /*   dans le menu (sinon, si rien dans les crdits, mais qque */
-	    /* chose dans les dbits, renvoie un menu vide qui sera affich */
+	    /*   dans le menu (sinon, si rien dans les crédits, mais qque */
+	    /* chose dans les débits, renvoie un menu vide qui sera affiché */
 
 	    if ( !menu )
 	    {
 		menu = gtk_menu_new();
 
-		/* on associe au menu la valeur 1 pour menu de dbit et 2 pour menu de crdit */
+		/* on associe au menu la valeur 1 pour menu de débit et 2 pour menu de crédit */
 
 		gtk_object_set_data ( GTK_OBJECT ( menu ),
 				      "signe_menu",
@@ -1410,10 +1413,10 @@ GtkWidget *creation_menu_types ( gint demande,
 
 /* ************************************************************************************************************** */
 /* Fonction cherche_no_menu_type */
-/*   argument : le numro du type demand */
-/* renvoie la place demande dans l'option menu du formulaire */
-/* pour mettre l'history et affiche l'entre du chq si ncessaire */
-/* retourne -1 si pas trouv */
+/*   argument : le numéro du type demandé */
+/* renvoie la place demandée dans l'option menu du formulaire */
+/* pour mettre l'history et affiche l'entrée du chq si nécessaire */
+/* retourne -1 si pas trouvé */
 /* ************************************************************************************************************** */
 
 gint cherche_no_menu_type ( gint demande )
@@ -1438,7 +1441,7 @@ gint cherche_no_menu_type ( gint demande )
 
 	    retour = i;
 
-	    /* affiche l'entre chq du formulaire si ncessaire */
+	    /* affiche l'entrée chq du formulaire si nécessaire */
 
 	    type = gtk_object_get_data ( GTK_OBJECT ( liste_tmp -> data ),
 					 "adr_type");
@@ -1463,10 +1466,10 @@ gint cherche_no_menu_type ( gint demande )
 
 /* ************************************************************************************************************** */
 /* Fonction cherche_no_menu_type_associe */
-/*   argument : le numro du type demand */
-/* renvoie la place demande dans l'option menu du formulaire du type associ */
-/* retourne -1 si pas trouv */
-/* origine = 0 pour les oprations */
+/*   argument : le numéro du type demandé */
+/* renvoie la place demandée dans l'option menu du formulaire du type associé */
+/* retourne -1 si pas trouvé */
+/* origine = 0 pour les opérations */
 /* origine = 1 pour les ventilations */
 /* ************************************************************************************************************** */
 
@@ -1516,10 +1519,10 @@ gint cherche_no_menu_type_associe ( gint demande,
 
 /* ************************************************************************************************************** */
 /* Fonction cherche_no_menu_type_echeancier */
-/*   argument : le numro du type demand */
-/* renvoie la place demande dans l'option menu du formulaire */
-/* pour mettre l'history et affiche l'entre du chq si ncessaire */
-/* retourne -1 si pas trouv */
+/*   argument : le numéro du type demandé */
+/* renvoie la place demandée dans l'option menu du formulaire */
+/* pour mettre l'history et affiche l'entrée du chq si nécessaire */
+/* retourne -1 si pas trouvé */
 /* ************************************************************************************************************** */
 
 gint cherche_no_menu_type_echeancier ( gint demande )
@@ -1545,20 +1548,20 @@ gint cherche_no_menu_type_echeancier ( gint demande )
 
 	    retour = i;
 
-	    /* affiche l'entre chq du formulaire si ncessaire */
+	    /* affiche l'entrée chq du formulaire si nécessaire */
 
 	    type = gtk_object_get_data ( GTK_OBJECT ( liste_tmp -> data ),
 					 "adr_type");
 
-	    /* soit c'est un type qui affiche l'entre et qui n'est pas numrot automatiquement */
-	    /* soit c'est un type numrot auto et c'est une saisie */
+	    /* soit c'est un type qui affiche l'entrée et qui n'est pas numéroté automatiquement */
+	    /* soit c'est un type numéroté auto et c'est une saisie */
 
 	    if ( ( type -> affiche_entree && !type -> numerotation_auto)
 		 ||
 		 ( type -> numerotation_auto && !strcmp ( GTK_LABEL ( label_saisie_modif ) -> label,
 							  _("Input") )))
 	    {
-		/* si c'est une saisie, mais le numro de chq */
+		/* si c'est une saisie, mais le numéro de chq */
 
 		if ( type -> numerotation_auto )
 		{
@@ -1588,13 +1591,13 @@ gint cherche_no_menu_type_echeancier ( gint demande )
 void changement_choix_type_formulaire ( struct struct_type_ope *type )
 {
 
-    /* affiche l'entre de chque si ncessaire */
+    /* affiche l'entrée de chèque si nécessaire */
 
     if ( type -> affiche_entree )
     {
 	gtk_widget_show ( widget_formulaire_operations[TRANSACTION_FORM_CHEQUE] );
 
-	/* met le no suivant si ncessaire */
+	/* met le no suivant si nécessaire */
 
 	if ( type -> numerotation_auto )
 	{
@@ -1622,14 +1625,14 @@ void changement_choix_type_formulaire ( struct struct_type_ope *type )
 void changement_choix_type_echeancier ( struct struct_type_ope *type )
 {
 
-    /* affiche l'entre de chque si ncessaire */
+    /* affiche l'entrée de chèque si nécessaire */
 
     if ( ( type -> affiche_entree && !type -> numerotation_auto )
 	 ||
 	 ( type -> numerotation_auto && !strcmp ( GTK_LABEL ( label_saisie_modif ) -> label,
 						  _("Input") )))
     {
-	/* si c'est une saisie, met le numro de chq */
+	/* si c'est une saisie, met le numéro de chq */
 
 	if ( type -> numerotation_auto )
 	{
