@@ -4,7 +4,7 @@
 /*                                                                            */
 /*                                  fonctions_utiles.c                        */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
 /*			2003-2004 Alain Portal (dionysos@grisbi.org)	      */
 /*			2003-2004 Francois Terrot (francois.terrot@grisbi.org)*/
@@ -98,9 +98,9 @@ GDate *gdate_today ( void )
 
 /******************************************************************************/
 /* Fonction modifie_date                                                      */
-/* prend en argument une entre contenant une date                            */
-/* vrifie la validit et la modifie si seulement une partie est donne       */
-/* met la date du jour si l'entre est vide                                   */
+/* prend en argument une entrée contenant une date                            */
+/* vérifie la validité et la modifie si seulement une partie est donnée       */
+/* met la date du jour si l'entrée est vide                                   */
 /* renvoie TRUE si la date est correcte                                       */
 /******************************************************************************/
 gboolean modifie_date ( GtkWidget *entree )
@@ -110,7 +110,7 @@ gboolean modifie_date ( GtkWidget *entree )
     GDate *date;
     gchar **tab_date;
 
-    /* si l'entre est grise, on se barre */
+    /* si l'entrée est grise, on se barre */
 
     if (( gtk_widget_get_style ( entree ) == style_entree_formulaire[ENGRIS] ))
 	return ( FALSE );
@@ -119,7 +119,7 @@ gboolean modifie_date ( GtkWidget *entree )
 
     if ( !strlen ( pointeur_entry ))
     {
-	/* si on est dans la conf des tats, on ne met pas la date du jour, on */
+	/* si on est dans la conf des états, on ne met pas la date du jour, on */
 	/* laisse vide */
 
 	if ( entree != entree_date_init_etat &&
@@ -136,7 +136,7 @@ gboolean modifie_date ( GtkWidget *entree )
 
 	if ( tab_date[2] && tab_date[1] )
 	{
-	    /*       on a rentr les 3 chiffres de la date */
+	    /*       on a rentré les 3 chiffres de la date */
 
 	    jour = my_strtod ( tab_date[0],  NULL );
 	    mois = my_strtod ( tab_date[1], NULL );
@@ -151,7 +151,7 @@ gboolean modifie_date ( GtkWidget *entree )
 	else
 	    if ( tab_date[1] )
 	    {
-		/* 	on a rentr la date sous la forme xx/xx , il suffit de mettre l'anne courante */
+		/* 	on a rentré la date sous la forme xx/xx , il suffit de mettre l'année courante */
 
 		jour = my_strtod ( tab_date[0], NULL );
 		mois = my_strtod ( tab_date[1], NULL );
@@ -160,8 +160,8 @@ gboolean modifie_date ( GtkWidget *entree )
 	    }
 	    else
 	    {
-		/* 	on a rentr que le jour de la date, il faut mettre le mois et l'anne courante */
-		/* ou bien on a rentr la date sous forme jjmm ou jjmmaa ou jjmmaaaa */
+		/* 	on a rentré que le jour de la date, il faut mettre le mois et l'année courante */
+		/* ou bien on a rentré la date sous forme jjmm ou jjmmaa ou jjmmaaaa */
 
 		gchar buffer[3];
 
@@ -241,9 +241,9 @@ gboolean modifie_date ( GtkWidget *entree )
 
 /******************************************************************************/
 /* Fonction format_date                                                       */
-/* Prend en argument une entre contenant une date                            */
-/* Vrifie la validit et la modifie si seulement une partie est donne       */
-/* Met la date du jour si l'entre est vide                                   */
+/* Prend en argument une entrée contenant une date                            */
+/* Vérifie la validité et la modifie si seulement une partie est donnée       */
+/* Met la date du jour si l'entrée est vide                                   */
 /* Renvoie TRUE si la date est correcte                                       */
 /******************************************************************************/
 gboolean format_date ( GtkWidget *entree )
@@ -271,7 +271,7 @@ gboolean format_date ( GtkWidget *entree )
 
 	if ( tab_date[2] && tab_date[1] )
 	{
-	    /* on a rentr les 3 chiffres de la date */
+	    /* on a rentré les 3 chiffres de la date */
 	    jour = gsb_strtod ( tab_date[0],  NULL );
 	    mois = gsb_strtod ( tab_date[1], NULL );
 	    annee = gsb_strtod ( tab_date[2], NULL );
@@ -288,17 +288,17 @@ gboolean format_date ( GtkWidget *entree )
 	{
 	    if ( tab_date[1] )
 	    {
-		/* on a rentr la date sous la forme xx/xx,
-		   il suffit de mettre l'anne courante */
+		/* on a rentré la date sous la forme xx/xx,
+		   il suffit de mettre l'année courante */
 		jour = gsb_strtod ( tab_date[0], NULL );
 		mois = gsb_strtod ( tab_date[1], NULL );
 		annee = g_date_year ( date );
 	    }
 	    else
 	    {
-		/* on a rentr que le jour de la date,
-		   il faut mettre le mois et l'anne courante
-		   ou bien on a rentr la date sous forme
+		/* on a rentré que le jour de la date,
+		   il faut mettre le mois et l'année courante
+		   ou bien on a rentré la date sous forme
 		   jjmm ou jjmmaa ou jjmmaaaa */
 		gchar buffer[3];
 
@@ -376,17 +376,17 @@ gboolean format_date ( GtkWidget *entree )
 
 /******************************************************************************/
 /* Fonction gsb_strtod (string to decimal)                                    */
-/* Convertie une chaine de caractres en un nombre                            */
-/* Paramtres d'entre :                                                      */
-/*   - nptr : pointeur sur la chaine de caractres  convertir                */
-/*   - endptr : n'est pas utilis, alors  quoi peut-il bien servir ?         */
+/* Convertie une chaine de caractères en un nombre                            */
+/* Paramètres d'entrée :                                                      */
+/*   - nptr : pointeur sur la chaine de caractères à convertir                */
+/*   - endptr : n'est pas utilisé, alors à quoi peut-il bien servir ?         */
 /* Valeur de retour :                                                         */
-/*   - resultat : le rsultat de la conversion                                */
+/*   - resultat : le résultat de la conversion                                */
 /* Variables locales :                                                        */
-/*   - entier : la partie entire du rsultat                                 */
-/*   - mantisse : la partie dcimale du rsultat                              */
-/*   - invert : le signe du rsultat (0 -> positif, 1 -> ngatif)             */
-/*   - p, m : pointeurs locaux sur la chaine de caractres  convertir        */
+/*   - entier : la partie entière du résultat                                 */
+/*   - mantisse : la partie décimale du résultat                              */
+/*   - invert : le signe du résultat (0 -> positif, 1 -> négatif)             */
+/*   - p, m : pointeurs locaux sur la chaine de caractères à convertir        */
 /******************************************************************************/
 double gsb_strtod ( char *nptr, char **endptr )
 {
@@ -397,16 +397,16 @@ double gsb_strtod ( char *nptr, char **endptr )
     if (!nptr)
 	return 0;
 
-    /* Pour chacun des caractres de la chaine, du dbut  la fin de la chaine,
+    /* Pour chacun des caractères de la chaine, du début à la fin de la chaine,
 faire : */
     for ( p = nptr; p < nptr + strlen(nptr); p++ )
     {
-	/* si c'est un espace ou le signe +, on passe au caractre suivant */
+	/* si c'est un espace ou le signe +, on passe au caractère suivant */
 	if ( g_ascii_isspace(*p) || *p == '+' )
 	    continue;
 
-	/* si c'est le signe -, on positionne invert  1 et on passe
-	   au caractre suivant */
+	/* si c'est le signe -, on positionne invert à 1 et on passe
+	   au caractère suivant */
 	if ( *p == '-' )
 	{
 	    invert = 1;
@@ -417,35 +417,35 @@ faire : */
 	if ( *p == ',' || *p == '.' )
 	{
 	    char *m;
-	    /* aller  la fin de la chaine */
+	    /* aller à la fin de la chaine */
 	    for ( m = p+1; m <= nptr+strlen(nptr) &&
 		    (isdigit(*m) || isspace(*m)); m++)
 	      ;
-		/* de la fin de la chaine au dernier caractre avant le point
+		/* de la fin de la chaine au dernier caractère avant le point
 		   ou la virgule, faire : */
 		for ( --m; m > p; m-- )
 		{
 		    /* si c'est un chiffre, alors : */
 		    if (isdigit(*m))
 		    {
-			/* "dcalage"  droite de la variable mantisse */
+			/* "décalage" à droite de la variable mantisse */
 			mantisse /= 10;
-			/* ajout  la variable mantisse de la valeur dcimale
-			   du caractre point par m */
+			/* ajout à la variable mantisse de la valeur décimale
+			   du caractère pointé par m */
 			mantisse += (*m - '0');
 		    }
 		}
-	    /* "dcalage"  droite de la variable mantisse */
+	    /* "décalage" à droite de la variable mantisse */
 	    mantisse /= 10;
 	}
 
 	/* si c'est un chiffre, alors : */
 	if ( isdigit(*p) )
 	{
-	    /* "dcalage"  gauche de la variable entier */
+	    /* "décalage" à gauche de la variable entier */
 	    entier = entier * 10;
-	    /* ajout  la variable entier de la valeur dcimale
-	       du caractre point par p */
+	    /* ajout à la variable entier de la valeur décimale
+	       du caractère pointé par p */
 	    entier += (*p - '0');
 	}
 	else
@@ -530,7 +530,7 @@ gchar *itoa ( gint integer )
 /***********************************************************************************************************/
 
 /***********************************************************************************************************/
-/* cette fonction protge atoi qui plante quand on lui envoie un null */
+/* cette fonction protège atoi qui plante quand on lui envoie un null */
 /***********************************************************************************************************/
 
 gint my_atoi ( gchar *chaine )
@@ -689,7 +689,7 @@ GtkWidget *cree_bouton_url ( const gchar *adr,
 gboolean lance_navigateur_web ( const gchar *url )
 {
 /*     si la commande du navigateur contient %s, on le remplace par url, */
-/*     sinon on ajoute l'url  la fin et & */
+/*     sinon on ajoute l'url à la fin et & */
 /*     sous Windows si la commande est vide ou equale a la valeur par defaut on lance le butineur par defaut (open) */
 
     gchar **split;
@@ -745,6 +745,8 @@ gboolean lance_navigateur_web ( const gchar *url )
 			      _("Cannot run web browser") );
     }
 
+    g_strfreev( split );    
+
 #ifdef _WIN32
     }
     else
@@ -766,8 +768,8 @@ gchar *my_strdelimit ( gchar *string,
 		       gchar *delimiters,
 		       gchar *new_delimiters )
 {
-    /* fonction identique  g_strdelimit, sauf que new_delimiters n'est pas limit  1 caractre */
-    /*     et la chaine renvoye est une copie, pas l'original */
+    /* fonction identique à g_strdelimit, sauf que new_delimiters n'est pas limité à 1 caractère */
+    /*     et la chaine renvoyée est une copie, pas l'original */
 
     gchar **tab_str;
     gchar *retour;
@@ -1568,7 +1570,55 @@ GtkWidget * get_entry_from_date_entry (GtkWidget * hbox)
  * \param hook An optional function to execute as a handler if the
  * textview's contents are modified.
  */
-GtkWidget * new_spin_button ( gint * value, 
+GtkWidget * new_int_spin_button ( gint * value, 
+				  gdouble lower, gdouble upper, 
+				  gdouble step_increment, gdouble page_increment, 
+				  gdouble page_size, 
+				  gdouble climb_rate, guint digits,
+				  GCallback hook )
+{
+    GtkWidget * spin;
+    GtkAdjustment * adjustment;
+    gint initial = 0;
+
+    if ( value )  /* Sanity check */
+	initial = *value;
+
+    adjustment = GTK_ADJUSTMENT( gtk_adjustment_new ( initial, lower, upper, 
+						      step_increment, page_increment,
+						      page_size ));
+    spin = gtk_spin_button_new ( adjustment, climb_rate, digits );
+    gtk_spin_button_set_numeric ( GTK_SPIN_BUTTON (spin), TRUE );
+    g_object_set_data ( G_OBJECT (spin), "pointer", value);
+    g_object_set_data ( G_OBJECT (spin), "adj", adjustment);
+
+    g_object_set_data ( G_OBJECT (spin), "value-changed",
+			(gpointer) g_signal_connect_swapped ( GTK_OBJECT (adjustment),
+							      "value-changed", 
+							      (GCallback) set_int_from_spin, 
+							      spin));
+    if ( hook )
+    {
+	g_object_set_data ( G_OBJECT (spin), "hook",
+			    (gpointer) g_signal_connect_swapped ( GTK_OBJECT (adjustment), 
+								  "value-changed", 
+								  (GCallback) hook, spin ));
+    }
+
+    return spin;
+}
+
+
+
+/**
+ * Creates a new GtkSpinButton with a pointer to a string that will be
+ * modified according to the spin's value.
+ *
+ * \param value A pointer to a string
+ * \param hook An optional function to execute as a handler if the
+ * textview's contents are modified.
+ */
+GtkWidget * new_spin_button ( gdouble * value, 
 			      gdouble lower, gdouble upper, 
 			      gdouble step_increment, gdouble page_increment, 
 			      gdouble page_size, 
@@ -1593,7 +1643,8 @@ GtkWidget * new_spin_button ( gint * value,
     g_object_set_data ( G_OBJECT (spin), "value-changed",
 			(gpointer) g_signal_connect_swapped ( GTK_OBJECT (adjustment),
 							      "value-changed", 
-							      (GCallback) set_double, spin));
+							      (GCallback) set_double_from_spin, 
+							      spin));
     if ( hook )
     {
 	g_object_set_data ( G_OBJECT (spin), "hook",
@@ -1611,7 +1662,7 @@ GtkWidget * new_spin_button ( gint * value,
  *  TODO: document
  *
  */
-void spin_button_set_value ( GtkWidget * spin, gdouble * value )
+void spin_button_set_value ( GtkWidget * spin, gint * value )
 {
     GtkAdjustment * adjustment;
 
@@ -1648,16 +1699,56 @@ void spin_button_set_value ( GtkWidget * spin, gdouble * value )
 
 
 /**
- * Set an integer to the value of a spin button.  Normally called via
+ *  TODO: document
+ *
+ */
+void spin_button_set_value_double ( GtkWidget * spin, gdouble * value )
+{
+    GtkAdjustment * adjustment;
+
+    adjustment = g_object_get_data ( G_OBJECT(spin), "adj" );
+    if (!adjustment)
+	return;
+
+    /* Block everything */
+    if ( g_object_get_data ((GObject*) spin, "value-changed") > 0 )
+	g_signal_handler_block ( GTK_OBJECT(adjustment),
+				 (gulong) g_object_get_data ((GObject*) spin, 
+							     "value-changed"));
+    if ( g_object_get_data ((GObject*) spin, "hook") > 0 )
+	g_signal_handler_block ( GTK_OBJECT(adjustment),
+				 (gulong) g_object_get_data ((GObject*) spin, "hook"));
+
+    if (value)
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON(spin), *value);
+    else
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON(spin), 0);
+
+    g_object_set_data ( G_OBJECT(spin), "pointer", value);
+
+    /* Unblock everything */
+    if ( g_object_get_data ((GObject*) spin, "value-changed") > 0 )
+	g_signal_handler_unblock ( GTK_OBJECT(adjustment),
+				   (gulong) g_object_get_data ((GObject*) spin, 
+							       "value-changed"));
+    if ( g_object_get_data ((GObject*) spin, "hook") > 0 )
+	g_signal_handler_unblock ( GTK_OBJECT(adjustment),
+				   (gulong) g_object_get_data ((GObject*) spin, "hook"));
+}
+
+
+
+/**
+ * Set an int to the value of a spin button.  Normally called via
  * a GTK "changed" signal handler.
  * 
  * \param spin a pointer to a spinbutton widget.
  * \param dummy unused
  */
-gboolean set_double ( GtkWidget * spin, gdouble * dummy)
+gboolean set_int_from_spin ( GtkWidget * spin, gint * dummy)
 {
-   gint *data;
-
+    gint *data;
+    
     data = g_object_get_data ( G_OBJECT(spin), "pointer" );
 
     if ( data )
@@ -1672,9 +1763,54 @@ gboolean set_double ( GtkWidget * spin, gdouble * dummy)
 
 
 
+/**
+ * Set an double to the value of a spin button.  Normally called via
+ * a GTK "changed" signal handler.
+ * 
+ * \param spin a pointer to a spinbutton widget.
+ * \param dummy unused
+ */
+gboolean set_double_from_spin ( GtkWidget * spin, gdouble * dummy)
+{
+    gdouble *data;
+    
+    data = g_object_get_data ( G_OBJECT(spin), "pointer" );
+
+    if ( data )
+    {
+	*data = gtk_spin_button_get_value ( GTK_SPIN_BUTTON(spin) );
+    }
+
+	/* Mark file as modified */
+    modification_fichier ( TRUE );
+    return (FALSE);
+}
 
 
 
+/**
+ * Set an integer to the value of a menu.  Normally called via a GTK
+ * "changed" signal handler.
+ * 
+ * \param menu a pointer to a menu widget.
+ * \param dummy unused
+ */
+gboolean set_int_from_menu ( GtkWidget * menu, gint * dummy)
+{
+    gint *data;
+    
+    data = g_object_get_data ( G_OBJECT(menu), "pointer" );
+
+    if ( data )
+    {
+	*data = (gtk_option_menu_get_history ( GTK_OPTION_MENU ( menu )) + 1);
+    }
+
+    /* Mark file as modified */
+    modification_fichier ( TRUE );
+    return (FALSE);
+}
+
 
 
 /* ******************************************************************************* */
@@ -1761,8 +1897,8 @@ gint my_strncasecmp ( gchar *chaine_1,
 
 
 /* ******************************************************************************* */
-/* fonction qui rcupre une ligne de charactre dans une chaine */
-/* elle alloue la mmoire ncessaire et n'incorpore pas le \n final */
+/* fonction qui récupère une ligne de charactère dans une chaine */
+/* elle alloue la mémoire nécessaire et n'incorpore pas le \n final */
 /* renvoie NULL en cas de pb */
 /* ******************************************************************************* */
 gchar *get_line_from_string ( gchar *string )
