@@ -1,9 +1,9 @@
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
 /* 			http://www.grisbi.org				      */
 
-/* Ce fichier contient toutes les variables globales dfinies */
-/* ainsi que toutes les dfinitions diverses */
+/* Ce fichier contient toutes les variables globales définies */
+/* ainsi que toutes les définitions diverses */
 
 #include "constants.h"
 
@@ -33,19 +33,19 @@ GtkWidget *vbox_liste_comptes_onglet;
 /***********************************/ 
 
 GtkWidget *label_compte_courant;
-int compte_courant;                      /*  n de compte en cours de visualisation */
+int compte_courant;                      /*  n° de compte en cours de visualisation */
 GtkWidget *vbox_liste_comptes;             /* adresse de la vbox contenant les icones de comptes */
-GtkWidget *label_releve;                    /* adr du label du dernier relev */
+GtkWidget *label_releve;                    /* adr du label du dernier relevé */
 
 
 /***********************************/ 
 /* fichier operations_liste.c */
 /***********************************/ 
 
-GtkWidget *notebook_listes_operations;          /*  adr du notebook qui contient les ops de chaque compte */
+GtkWidget *notebook_listes_operations;          /*  adr du notebook qui contient les opés de chaque compte */
 GtkWidget *bouton_affiche_cache_formulaire;
-GtkWidget *fleche_haut;                        /* adr de l'icone de la flche vers le haut  */
-GtkWidget *fleche_bas;                        /* adr de l'icone de la flche vers le bas  */
+GtkWidget *fleche_haut;                        /* adr de l'icone de la flèche vers le haut  */
+GtkWidget *fleche_bas;                        /* adr de l'icone de la flèche vers le bas  */
 GtkWidget *frame_droite_bas;                  /* adr de la frame contenant le formulaire */
 GtkWidget *barre_outils;                           /* adr de la barre d'outils */
 gdouble solde_courant_affichage_liste;   /* valable uniquement pendant l'affichage de la liste */
@@ -72,7 +72,7 @@ gchar *buffer_dernier_fichier;
 gchar *nom_fichier_backup;
 gchar *dernier_chemin_de_travail;
 gint nb_derniers_fichiers_ouverts;          /* contient le nb de derniers fichiers ouverts */
-gint nb_max_derniers_fichiers_ouverts;        /* contient le nb max que peut contenir nb_derniers_fichiers_ouverts ( rgl dans les paramtres ) */
+gint nb_max_derniers_fichiers_ouverts;        /* contient le nb max que peut contenir nb_derniers_fichiers_ouverts ( réglé dans les paramètres ) */
 gchar **tab_noms_derniers_fichiers_ouverts;
 gint compression_fichier;
 gint compression_backup;
@@ -86,17 +86,17 @@ gint compression_backup;
 
 gchar *nom_fichier_comptes, *ancien_nom_fichier_comptes;
 gchar *buffer_nom_fichier_comptes;
-gchar buffer_en_tete[50];                      /* utilis comme buffer lors de la lecture du fichier */
+gchar buffer_en_tete[50];                      /* utilisé comme buffer lors de la lecture du fichier */
 /* struct stat buffer_stat; */
 gint ancien_mask;
 FILE *pointeur_fichier_comptes;
 FILE *pointeur_fichier_comptes_tmp;
 int nb_comptes;
-gpointer ** p_tab_nom_de_compte = NULL;  /* pointe vers un tableau de pointeurs vers les comptes en mmoire*/
-gpointer ** p_tab_nom_de_compte_variable;  /* idem, mais utilis pour se dplacer */
+gpointer ** p_tab_nom_de_compte = NULL;  /* pointe vers un tableau de pointeurs vers les comptes en mémoire*/
+gpointer ** p_tab_nom_de_compte_variable;  /* idem, mais utilisé pour se déplacer */
 gpointer ** p_tab_nom_de_compte_courant;  /* pointe sur le tableau de pointeurs sur le compte courant*/
-GtkWidget * solde_label;   /*  pointeur vers le label qui contient le solde sous la liste des op */
-GtkWidget * solde_label_pointe;   /*  pointeur vers le label qui contient le solde pointe sous la liste des op */
+GtkWidget * solde_label;   /*  pointeur vers le label qui contient le solde sous la liste des opé */
+GtkWidget * solde_label_pointe;   /*  pointeur vers le label qui contient le solde pointe sous la liste des opé */
 gchar version[10];
 GSList *ordre_comptes;
 gchar *titre_fichier;
@@ -107,7 +107,7 @@ GSList *liste_struct_exercices;
 gint no_derniere_exercice;
 gint nb_exercices;
 
-gint no_derniere_operation;     /* contient le dernier numro d'opration de tous les comptes runis */
+gint no_derniere_operation;     /* contient le dernier numéro d'opération de tous les comptes réunis */
 
 
 /*********************/ 
@@ -117,8 +117,8 @@ gint no_derniere_operation;     /* contient le dernier numro d'opration de tous
 
 GtkWidget *notebook_general;       /* adr du notebook de base */
 GtkWidget *page_accueil;           /* adr de l'onglet accueil */
-GtkWidget *page_operations;        /* adr de l'onglet oprations ( ancien gest_main ) */
-GtkWidget *page_echeancier;        /* adr de l'onglet chances */
+GtkWidget *page_operations;        /* adr de l'onglet opérations ( ancien gest_main ) */
+GtkWidget *page_echeancier;        /* adr de l'onglet échéances */
 GtkWidget *page_comptes;        /* adr de l'onglet comptes */
 GtkWidget *page_tiers;             /* adr de l'onglet tiers */
 GtkWidget *page_categories;             /* adr de l'onglet categories */
@@ -140,7 +140,7 @@ GtkStyle *style_derriere_selection;
 gint ancienne_ligne_selection;
 GtkStyle *style_couleur [2];
 GtkStyle *style_rouge_couleur [2];
-GtkStyle *style_gris;                     /* utilis pour le gris des chances */
+GtkStyle *style_gris;                     /* utilisé pour le grisé des échéances */
 gchar * fonte_liste;
 gchar * list_font_name;
 gchar * list_font_size;
@@ -150,7 +150,7 @@ GtkWidget *pointeur_fenetre_nouveau_compte;
 
 gint *no_operation_formulaire = NULL;
 
-gint operations_affichees;       /* nb d'op affiches ( variable en fonction qu'on affiche les R ou pas  */
+gint operations_affichees;       /* nb d'opé affichées ( variable en fonction qu'on affiche les R ou pas  */
 
 
 /************************/ 
@@ -236,9 +236,9 @@ GtkWidget *entree_jours;
 GtkWidget *bouton_2click_saisie, *bouton_2click_pas_saisie;
 
 
-GSList *liste_struct_exercices_tmp;                 /*  utilise  la place de la liste des exercices pour les paramtres */
-gint no_derniere_exercice_tmp;                            /*  utilis  la place de no_derniere_exercice pour les paramtres */
-gint nb_exercices_tmp;                            /*  utilis  la place de nb_exercices pour les paramtres */
+GSList *liste_struct_exercices_tmp;                 /*  utilisée à la place de la liste des exercices pour les paramètres */
+gint no_derniere_exercice_tmp;                            /*  utilisé à la place de no_derniere_exercice pour les paramètres */
+gint nb_exercices_tmp;                            /*  utilisé à la place de nb_exercices pour les paramètres */
 GtkWidget *clist_exercices_parametres;
 GtkWidget *bouton_supprimer_exercice;
 GtkWidget *nom_exercice;
@@ -289,12 +289,14 @@ GtkWidget *bouton_ajouter_tiers;
 
 gint nb_enregistrements_tiers;
 gint no_dernier_tiers;
-GList tiers_combo;                         /* liste des struct_chaine_completion pour la compltion  */
+GList tiers_combo;                         /* liste des struct_chaine_completion pour la complétion  */
 GSList *liste_struct_tiers;             /* contient la liste des struct liste_tiers de tous les tiers */
 GSList *liste_tiers_combofix;            /* liste des tiers pour le combofix */
-GSList *liste_tiers_combofix_echeancier;            /* liste des tiers pour le combofix de l'chancier */
+GSList *liste_tiers_combofix_echeancier;            /* liste des tiers pour le combofix de l'échéancier */
 GDate **date_dernier_tiers;            /* contient la date du dernier tiers lors de l'affichage de chaque tiers */
 gint no_devise_totaux_tiers;
+gint no_devise_totaux_ib;
+gint no_devise_totaux_categ;
 gint *nb_ecritures_par_tiers;           /* variable tampon */
 gint nb_ecritures_par_comptes;
 
@@ -313,9 +315,9 @@ GtkWidget *bouton_supprimer_categ;
 GtkWidget *bouton_ajouter_categorie;
 GtkWidget *bouton_ajouter_sous_categorie;
 
-GSList *liste_struct_categories;    /* liste des structures de catg */
+GSList *liste_struct_categories;    /* liste des structures de catég */
 GSList *liste_categories_combofix;        /*  liste des noms des categ et sous categ pour le combofix */
-gint nb_enregistrements_categories;        /* nombre de catgories */
+gint nb_enregistrements_categories;        /* nombre de catégories */
 gint no_derniere_categorie;
 gfloat *tab_montant_categ;             /* buffer */
 gfloat **tab_montant_sous_categ;            /* buffer */
@@ -340,15 +342,15 @@ GtkWidget *bouton_supprimer_devise;
 GtkWidget *entree_nom_devise_parametres;
 GtkWidget *entree_iso_code_devise_parametres;
 GtkWidget *entree_code_devise_parametres;
-GtkWidget *check_button_euro;                    /*bouton passera  l'euro */
-GtkWidget *hbox_devise_associee;                  /* ligne contenant l'option menu de la devise associe */
-GtkWidget *label_date_dernier_change;       /* label qui affiche soit aucun change entr, soit la date du dernier change */
+GtkWidget *check_button_euro;                    /*bouton passera à l'euro */
+GtkWidget *hbox_devise_associee;                  /* ligne contenant l'option menu de la devise associée */
+GtkWidget *label_date_dernier_change;       /* label qui affiche soit aucun change entré, soit la date du dernier change */
 GtkWidget *hbox_ligne_change;                  /* hbox contenant le change entre les devises */
 GtkWidget *option_menu_devises;                  /* contient la devise avec laquelle on fait le change */
 GtkWidget *devise_1;                                      /* option menu qui contient la devise 1 */
 GtkWidget *devise_2;                                     /* option menu qui contient la devise 2 */
-GtkWidget *entree_conversion;                       /* entre qui contient le change */
-gint ligne_selection_devise;               /* contient la ligne slectionne dans la liste des devises */
+GtkWidget *entree_conversion;                       /* entrée qui contient le change */
+gint ligne_selection_devise;               /* contient la ligne sélectionnée dans la liste des devises */
 struct struct_devise *devise_compte;
 struct struct_devise *devise_operation;
 
@@ -391,17 +393,17 @@ gint no_derniere_banque;
 
 
 GtkWidget *liste_operations_ventilees;
-gint ancienne_largeur_ventilation;          /* magouille utilise pour bloquer un signal size-allocate qui s'emballe */
+gint ancienne_largeur_ventilation;          /* magouille utilisée pour bloquer un signal size-allocate qui s'emballe */
 GtkWidget *widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_TOTAL_WIDGET];
 GtkWidget *separateur_formulaire_ventilations;
 GtkWidget *hbox_valider_annuler_ventil;
 GtkWidget *label_somme_ventilee;                       /*  label correspondant */
 GtkWidget *label_non_affecte;                       /*  label correspondant */
 GtkWidget *label_montant_operation_ventilee;                       /*  label correspondant */
-struct struct_ope_ventil *ligne_selectionnee_ventilation;              /* struct ope ligne slectionne */
+struct struct_ope_ventil *ligne_selectionnee_ventilation;              /* struct ope ligne sélectionnée */
 gdouble montant_operation_ventilee;
 gdouble somme_ventilee;
-gint enregistre_ope_au_retour;            /*  1 si au click du bouton valider on enregistre l'op */
+gint enregistre_ope_au_retour;            /* à 1 si au click du bouton valider on enregistre l'opé */
 
 
 /***********************************/ 
@@ -479,9 +481,9 @@ gint *neutres_inclus_tmp;
 /***********************************/ 
 
 
-GSList *liste_struct_banques_tmp;                 /*  utilise  la place de la liste des banques pour les paramtres */
-gint no_derniere_banque_tmp;                            /*  utilis  la place de no_derniere_banque pour les paramtres */
-gint nb_banques_tmp;                            /*  utilis  la place de nb_banques pour les paramtres */
+GSList *liste_struct_banques_tmp;                 /*  utilisée à la place de la liste des banques pour les paramètres */
+gint no_derniere_banque_tmp;                            /*  utilisé à la place de no_derniere_banque pour les paramètres */
+gint nb_banques_tmp;                            /*  utilisé à la place de nb_banques pour les paramètres */
 GtkWidget *clist_banques_parametres;
 GtkWidget *bouton_supprimer_banque;
 GtkWidget *nom_banque;
@@ -516,9 +518,9 @@ GtkWidget *bouton_supprimer_imputation;
 GtkWidget *bouton_ajouter_imputation;
 GtkWidget *bouton_ajouter_sous_imputation;
 
-GSList *liste_struct_imputation;    /* liste des structures de catg */
+GSList *liste_struct_imputation;    /* liste des structures de catég */
 GSList *liste_imputations_combofix;        /*  liste des noms des imputation et sous imputation pour le combofix */
-gint nb_enregistrements_imputations;        /* nombre de catgories */
+gint nb_enregistrements_imputations;        /* nombre de catégories */
 gint no_derniere_imputation;
 gfloat *tab_montant_imputation;             /* buffer */
 gfloat **tab_montant_sous_imputation;            /* buffer */
@@ -551,9 +553,9 @@ GtkWidget *bouton_classer_liste_par_date_bancaire;
 GSList *liste_struct_etats;
 gint no_dernier_etat;
 GtkWidget *frame_liste_etats;
-GtkWidget *label_etat_courant;        /* label en haut de la liste des tats */
-GtkWidget *vbox_liste_etats;          /* vbox contenant la liste des tats */
-GtkWidget *bouton_etat_courant;          /* adr du bouton de l'tat en cours, pour le refermer qd change */
+GtkWidget *label_etat_courant;        /* label en haut de la liste des états */
+GtkWidget *vbox_liste_etats;          /* vbox contenant la liste des états */
+GtkWidget *bouton_etat_courant;          /* adr du bouton de l'état en cours, pour le refermer qd change */
 struct struct_etat *etat_courant;
 GtkWidget *bouton_effacer_etat;
 GtkWidget *bouton_personnaliser_etat;
@@ -562,7 +564,7 @@ GtkWidget *bouton_imprimer_etat;
 GtkWidget *bouton_exporter_etat;
 GtkWidget *bouton_importer_etat;
 GtkWidget *bouton_dupliquer_etat;
-GtkWidget *scrolled_window_etat;          /* contient l'tat en cours */
+GtkWidget *scrolled_window_etat;          /* contient l'état en cours */
 gint nb_colonnes;
 gint ligne_debut_partie;
 GtkWidget *notebook_etats;
@@ -736,7 +738,7 @@ GtkWidget *liste_mode_paiement_etat;
 /* fichier etats_io.c */
 /***********************************/ 
 
-gchar *log_message;        /* utilis comme log lors de l'import d'un tat */
+gchar *log_message;        /* utilisé comme log lors de l'import d'un état */
 
 
 /************************/ 
@@ -759,9 +761,9 @@ GtkWidget *bouton_affichage_lignes_trois_lignes_2;
 GtkWidget *bouton_affichage_lignes_trois_lignes_3;
 gint rapport_largeur_colonnes[7];    /* contient le % de chaque colonne */
 gint taille_largeur_colonnes[7];   /* contient la taille de chaque colonne */
-gint ligne_affichage_une_ligne;    /* contient le no de ligne  afficher lorsqu'on n'affiche qu'une ligne */
-GSList *lignes_affichage_deux_lignes;    /* contient les no de lignes  afficher lorsqu'on affiche deux lignes */
-GSList *lignes_affichage_trois_lignes;    /* contient les no de lignes  afficher lorsqu'on affiche trois lignes */
+gint ligne_affichage_une_ligne;    /* contient le no de ligne à afficher lorsqu'on n'affiche qu'une ligne */
+GSList *lignes_affichage_deux_lignes;    /* contient les no de lignes à afficher lorsqu'on affiche deux lignes */
+GSList *lignes_affichage_trois_lignes;    /* contient les no de lignes à afficher lorsqu'on affiche trois lignes */
 
 
 /************************/ 
